# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCompetencyDuplicateCompetencyFrameworkResponse(BaseModel):
    """
    CoreCompetencyDuplicateCompetencyFrameworkResponse
    """ # noqa: E501
    canmanage: StrictBool = Field(description="canmanage")
    competenciescount: StrictInt = Field(description="competenciescount")
    contextid: StrictInt = Field(description="contextid")
    contextname: StrictStr = Field(description="contextname")
    contextnamenoprefix: StrictStr = Field(description="contextnamenoprefix")
    description: StrictStr = Field(description="description")
    descriptionformat: Optional[StrictInt] = Field(default=1, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    id: StrictInt = Field(description="id")
    idnumber: StrictStr = Field(description="idnumber")
    scaleconfiguration: StrictStr = Field(description="scaleconfiguration")
    scaleid: StrictInt = Field(description="scaleid")
    shortname: StrictStr = Field(description="shortname")
    taxonomies: StrictStr = Field(description="taxonomies")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    usermodified: StrictInt = Field(description="usermodified")
    visible: StrictBool = Field(description="visible")
    __properties: ClassVar[List[str]] = ["canmanage", "competenciescount", "contextid", "contextname", "contextnamenoprefix", "description", "descriptionformat", "id", "idnumber", "scaleconfiguration", "scaleid", "shortname", "taxonomies", "timecreated", "timemodified", "usermodified", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCompetencyDuplicateCompetencyFrameworkResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCompetencyDuplicateCompetencyFrameworkResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCompetencyDuplicateCompetencyFrameworkResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "canmanage": obj.get("canmanage") if obj.get("canmanage") is not None else False,
            "competenciescount": obj.get("competenciescount") if obj.get("competenciescount") is not None else 0,
            "contextid": obj.get("contextid") if obj.get("contextid") is not None else 0,
            "contextname": obj.get("contextname") if obj.get("contextname") is not None else '',
            "contextnamenoprefix": obj.get("contextnamenoprefix") if obj.get("contextnamenoprefix") is not None else '',
            "description": obj.get("description") if obj.get("description") is not None else '',
            "descriptionformat": obj.get("descriptionformat") if obj.get("descriptionformat") is not None else 1,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "idnumber": obj.get("idnumber") if obj.get("idnumber") is not None else '',
            "scaleconfiguration": obj.get("scaleconfiguration") if obj.get("scaleconfiguration") is not None else '',
            "scaleid": obj.get("scaleid") if obj.get("scaleid") is not None else 0,
            "shortname": obj.get("shortname") if obj.get("shortname") is not None else '',
            "taxonomies": obj.get("taxonomies") if obj.get("taxonomies") is not None else '',
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0,
            "visible": obj.get("visible") if obj.get("visible") is not None else True
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


