# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModChoiceGetChoiceOptionsResponseOptionsInner(BaseModel):
    """
    ModChoiceGetChoiceOptionsResponseOptionsInner
    """ # noqa: E501
    checked: Optional[StrictBool] = Field(description="we already answered")
    countanswers: Optional[StrictInt] = Field(description="number of answers")
    disabled: Optional[StrictBool] = Field(description="option disabled")
    displaylayout: Optional[StrictBool] = Field(description="true for orizontal, otherwise vertical")
    id: Optional[StrictInt] = Field(description="option id")
    maxanswers: Optional[StrictInt] = Field(description="maximum number of answers")
    text: Optional[StrictStr] = Field(description="text of the choice")
    __properties: ClassVar[List[str]] = ["checked", "countanswers", "disabled", "displaylayout", "id", "maxanswers", "text"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModChoiceGetChoiceOptionsResponseOptionsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if checked (nullable) is None
        # and model_fields_set contains the field
        if self.checked is None and "checked" in self.model_fields_set:
            _dict['checked'] = None

        # set to None if countanswers (nullable) is None
        # and model_fields_set contains the field
        if self.countanswers is None and "countanswers" in self.model_fields_set:
            _dict['countanswers'] = None

        # set to None if disabled (nullable) is None
        # and model_fields_set contains the field
        if self.disabled is None and "disabled" in self.model_fields_set:
            _dict['disabled'] = None

        # set to None if displaylayout (nullable) is None
        # and model_fields_set contains the field
        if self.displaylayout is None and "displaylayout" in self.model_fields_set:
            _dict['displaylayout'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if maxanswers (nullable) is None
        # and model_fields_set contains the field
        if self.maxanswers is None and "maxanswers" in self.model_fields_set:
            _dict['maxanswers'] = None

        # set to None if text (nullable) is None
        # and model_fields_set contains the field
        if self.text is None and "text" in self.model_fields_set:
            _dict['text'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModChoiceGetChoiceOptionsResponseOptionsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModChoiceGetChoiceOptionsResponseOptionsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "checked": obj.get("checked"),
            "countanswers": obj.get("countanswers"),
            "disabled": obj.get("disabled"),
            "displaylayout": obj.get("displaylayout"),
            "id": obj.get("id"),
            "maxanswers": obj.get("maxanswers"),
            "text": obj.get("text")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


