# coding: utf-8

# flake8: noqa

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "5.0.3"

# Define package exports
__all__ = [
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "settings",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AiplacementCourseassistExplainTextResponse",
    "AiplacementCourseassistSummariseTextResponse",
    "AiplacementEditorGenerateImageResponse",
    "AiplacementEditorGenerateTextResponse",
    "AuthEmailGetSignupSettingsResponse",
    "AuthEmailGetSignupSettingsResponseProfilefieldsInner",
    "AuthEmailGetSignupSettingsResponseWarningsInner",
    "AuthEmailSignupUserParameters",
    "AuthEmailSignupUserParametersCustomprofilefieldsInner",
    "AuthEmailSignupUserResponse",
    "BlockAccessreviewGetModuleDataResponseInner",
    "BlockAccessreviewGetSectionDataResponseInner",
    "BlockRecentlyaccesseditemsGetRecentItemsResponseInner",
    "BlockStarredcoursesGetStarredCoursesResponseInner",
    "CoreAiDeleteProviderInstanceResponse",
    "CoreAiGetPolicyStatusResponse",
    "CoreAiSetPolicyStatusResponse",
    "CoreAiSetProviderStatusResponse",
    "CoreAuthConfirmUserParameters",
    "CoreAuthConfirmUserResponse",
    "CoreAuthIsAgeDigitalConsentVerificationEnabledResponse",
    "CoreAuthIsMinorParameters",
    "CoreAuthIsMinorResponse",
    "CoreAuthRequestPasswordResetParameters",
    "CoreAuthRequestPasswordResetResponse",
    "CoreAuthResendConfirmationEmailParameters",
    "CoreAuthResendConfirmationEmailResponse",
    "CoreBackupGetAsyncBackupLinksBackupResponse",
    "CoreBackupGetAsyncBackupLinksRestoreResponse",
    "CoreBackupGetAsyncBackupProgressResponseInner",
    "CoreBackupGetCopyProgressParametersCopiesInner",
    "CoreBackupGetCopyProgressResponseInner",
    "CoreBadgesDisableBadgesResponse",
    "CoreBadgesEnableBadgesResponse",
    "CoreBadgesEnableBadgesResponseResultInner",
    "CoreBadgesGetBadgeResponse",
    "CoreBadgesGetBadgeResponseBadge",
    "CoreBadgesGetBadgeResponseBadgeAlignmentInner",
    "CoreBadgesGetUserBadgeByHashResponse",
    "CoreBadgesGetUserBadgeByHashResponseBadgeInner",
    "CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement",
    "CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner",
    "CoreBadgesGetUserBadgesResponse",
    "CoreBlockFetchAddableBlocksResponseInner",
    "CoreBlockGetCourseBlocksResponse",
    "CoreBlockGetCourseBlocksResponseBlocksInner",
    "CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner",
    "CoreBlockGetCourseBlocksResponseBlocksInnerContents",
    "CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner",
    "CoreBlockGetDashboardBlocksResponse",
    "CoreBlogAddEntryParametersOptionsInner",
    "CoreBlogAddEntryResponse",
    "CoreBlogDeleteEntryResponse",
    "CoreBlogGetAccessInformationResponse",
    "CoreBlogGetEntriesParameters",
    "CoreBlogGetEntriesParametersFiltersInner",
    "CoreBlogGetEntriesResponse",
    "CoreBlogGetEntriesResponseEntriesInner",
    "CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner",
    "CoreBlogGetEntriesResponseEntriesInnerTagsInner",
    "CoreBlogPrepareEntryForEditionResponse",
    "CoreBlogPrepareEntryForEditionResponseAreasInner",
    "CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner",
    "CoreBlogUpdateEntryResponse",
    "CoreBlogViewEntriesParameters",
    "CoreBlogViewEntriesParametersFiltersInner",
    "CoreBlogViewEntriesResponse",
    "CoreCalendarCreateCalendarEventsParametersEventsInner",
    "CoreCalendarCreateCalendarEventsResponse",
    "CoreCalendarCreateCalendarEventsResponseEventsInner",
    "CoreCalendarDeleteCalendarEventsParametersEventsInner",
    "CoreCalendarDeleteSubscriptionResponse",
    "CoreCalendarGetActionEventsByCourseResponse",
    "CoreCalendarGetActionEventsByCourseResponseEventsInner",
    "CoreCalendarGetActionEventsByCourseResponseEventsInnerAction",
    "CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory",
    "CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon",
    "CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription",
    "CoreCalendarGetActionEventsByCoursesResponse",
    "CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner",
    "CoreCalendarGetActionEventsByTimesortResponse",
    "CoreCalendarGetAllowedEventTypesResponse",
    "CoreCalendarGetCalendarAccessInformationResponse",
    "CoreCalendarGetCalendarDayViewResponse",
    "CoreCalendarGetCalendarDayViewResponseDate",
    "CoreCalendarGetCalendarDayViewResponseEventsInner",
    "CoreCalendarGetCalendarEventByIdResponse",
    "CoreCalendarGetCalendarEventsParametersEvents",
    "CoreCalendarGetCalendarEventsParametersOptions",
    "CoreCalendarGetCalendarEventsResponse",
    "CoreCalendarGetCalendarEventsResponseEventsInner",
    "CoreCalendarGetCalendarExportTokenResponse",
    "CoreCalendarGetCalendarMonthlyViewResponse",
    "CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner",
    "CoreCalendarGetCalendarMonthlyViewResponseWeeksInner",
    "CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner",
    "CoreCalendarGetCalendarUpcomingViewResponse",
    "CoreCalendarGetTimestampsParametersDataInner",
    "CoreCalendarGetTimestampsResponse",
    "CoreCalendarGetTimestampsResponseTimestampsInner",
    "CoreCalendarSubmitCreateUpdateFormResponse",
    "CoreCalendarUpdateEventStartDayResponse",
    "CoreChangeEditmodeResponse",
    "CoreCheckGetResultAdmintreeResponse",
    "CoreCohortAddCohortMembersParametersMembersInner",
    "CoreCohortAddCohortMembersParametersMembersInnerCohorttype",
    "CoreCohortAddCohortMembersParametersMembersInnerUsertype",
    "CoreCohortAddCohortMembersResponse",
    "CoreCohortCreateCohortsParametersCohortsInner",
    "CoreCohortCreateCohortsParametersCohortsInnerCategorytype",
    "CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner",
    "CoreCohortCreateCohortsResponseInner",
    "CoreCohortDeleteCohortMembersParametersMembersInner",
    "CoreCohortGetCohortMembersResponseInner",
    "CoreCohortGetCohortsResponseInner",
    "CoreCohortGetCohortsResponseInnerCustomfieldsInner",
    "CoreCohortSearchCohortsParametersContext",
    "CoreCohortSearchCohortsResponse",
    "CoreCohortUpdateCohortsParametersCohortsInner",
    "CoreCommentAddCommentsParametersCommentsInner",
    "CoreCommentAddCommentsResponseInner",
    "CoreCommentGetCommentsResponse",
    "CoreCompetencyCountCompetenciesParametersFiltersInner",
    "CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework",
    "CoreCompetencyCreateCompetencyFrameworkResponse",
    "CoreCompetencyCreateCompetencyParametersCompetency",
    "CoreCompetencyCreateCompetencyResponse",
    "CoreCompetencyCreatePlanParametersPlan",
    "CoreCompetencyCreatePlanResponse",
    "CoreCompetencyCreatePlanResponseCommentarea",
    "CoreCompetencyCreatePlanResponseReviewer",
    "CoreCompetencyCreatePlanResponseTemplate",
    "CoreCompetencyCreateTemplateParametersTemplate",
    "CoreCompetencyCreateTemplateResponse",
    "CoreCompetencyCreateUserEvidenceCompetencyResponse",
    "CoreCompetencyDuplicateCompetencyFrameworkResponse",
    "CoreCompetencyDuplicateTemplateResponse",
    "CoreCompetencyGetScaleValuesResponseInner",
    "CoreCompetencyGradeCompetencyInCourseResponse",
    "CoreCompetencyGradeCompetencyInPlanResponse",
    "CoreCompetencyGradeCompetencyResponse",
    "CoreCompetencyListCompetenciesInTemplateResponseInner",
    "CoreCompetencyListCompetencyFrameworksResponseInner",
    "CoreCompetencyListCourseCompetenciesResponseInner",
    "CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency",
    "CoreCompetencyListCourseModuleCompetenciesResponseInner",
    "CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency",
    "CoreCompetencyListPlanCompetenciesResponseInner",
    "CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency",
    "CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan",
    "CoreCompetencyListUserPlansResponseInner",
    "CoreCompetencyReadCompetencyFrameworkResponse",
    "CoreCompetencyReadCompetencyResponse",
    "CoreCompetencyReadPlanResponse",
    "CoreCompetencyReadTemplateResponse",
    "CoreCompetencyReadUserEvidenceResponse",
    "CoreCompetencyReadUserEvidenceResponseFilesInner",
    "CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework",
    "CoreCompetencyUpdateCompetencyParametersCompetency",
    "CoreCompetencyUpdateCourseCompetencySettingsParametersSettings",
    "CoreCompetencyUpdatePlanParametersPlan",
    "CoreCompetencyUpdatePlanResponse",
    "CoreCompetencyUpdateTemplateParametersTemplate",
    "CoreCompletionGetActivitiesCompletionStatusResponse",
    "CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner",
    "CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner",
    "CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue",
    "CoreCompletionGetCourseCompletionStatusResponse",
    "CoreCompletionGetCourseCompletionStatusResponseCompletionstatus",
    "CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner",
    "CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails",
    "CoreCompletionMarkCourseSelfCompletedResponse",
    "CoreCompletionOverrideActivityCompletionStatusResponse",
    "CoreCompletionUpdateActivityCompletionStatusManuallyResponse",
    "CoreContentbankCopyContentResponse",
    "CoreContentbankDeleteContentResponse",
    "CoreContentbankRenameContentResponse",
    "CoreContentbankSetContentVisibilityResponse",
    "CoreCourseAddContentItemToUserFavouritesResponse",
    "CoreCourseCheckUpdatesParametersTocheckInner",
    "CoreCourseCheckUpdatesResponse",
    "CoreCourseCheckUpdatesResponseInstancesInner",
    "CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner",
    "CoreCourseCreateCategoriesParametersCategoriesInner",
    "CoreCourseCreateCategoriesResponseInner",
    "CoreCourseCreateCoursesParametersCoursesInner",
    "CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner",
    "CoreCourseCreateCoursesResponseInner",
    "CoreCourseDeleteCategoriesParametersCategoriesInner",
    "CoreCourseDeleteCoursesResponse",
    "CoreCourseDuplicateCourseParametersOptionsInner",
    "CoreCourseDuplicateCourseResponse",
    "CoreCourseGetActivityChooserFooterResponse",
    "CoreCourseGetCategoriesParametersCriteriaInner",
    "CoreCourseGetCategoriesResponseInner",
    "CoreCourseGetContentsParametersOptionsInner",
    "CoreCourseGetContentsResponseInner",
    "CoreCourseGetContentsResponseInnerModulesInner",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadge",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondata",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsinfo",
    "CoreCourseGetContentsResponseInnerModulesInnerDatesInner",
    "CoreCourseGetCourseContentItemsResponse",
    "CoreCourseGetCourseContentItemsResponseContentItemsInner",
    "CoreCourseGetCourseModuleByInstanceResponse",
    "CoreCourseGetCourseModuleByInstanceResponseCm",
    "CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner",
    "CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner",
    "CoreCourseGetCourseModuleResponse",
    "CoreCourseGetCoursesByFieldResponse",
    "CoreCourseGetCoursesByFieldResponseCoursesInner",
    "CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner",
    "CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner",
    "CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner",
    "CoreCourseGetCoursesParametersOptions",
    "CoreCourseGetCoursesResponseInner",
    "CoreCourseGetCoursesResponseInnerCustomfieldsInner",
    "CoreCourseGetEnrolledCoursesByTimelineClassificationResponse",
    "CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse",
    "CoreCourseGetEnrolledUsersByCmidResponse",
    "CoreCourseGetEnrolledUsersByCmidResponseUsersInner",
    "CoreCourseGetUpdatesSinceResponse",
    "CoreCourseGetUserAdministrationOptionsResponse",
    "CoreCourseGetUserAdministrationOptionsResponseCoursesInner",
    "CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner",
    "CoreCourseGetUserNavigationOptionsResponse",
    "CoreCourseImportCourseParametersOptionsInner",
    "CoreCourseRemoveContentItemFromUserFavouritesResponse",
    "CoreCourseSearchCoursesResponse",
    "CoreCourseSearchCoursesResponseCoursesInner",
    "CoreCourseSetFavouriteCoursesParametersCoursesInner",
    "CoreCourseSetFavouriteCoursesResponse",
    "CoreCourseToggleActivityRecommendationResponse",
    "CoreCourseUpdateCategoriesParametersCategoriesInner",
    "CoreCourseUpdateCoursesParametersCoursesInner",
    "CoreCourseUpdateCoursesResponse",
    "CoreCourseViewCourseResponse",
    "CoreCourseformatFileHandlersResponseInner",
    "CoreCustomfieldReloadTemplateResponse",
    "CoreCustomfieldReloadTemplateResponseCategoriesInner",
    "CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner",
    "CoreDynamicTabsGetContentResponse",
    "CoreEnrolGetCourseEnrolmentMethodsResponseInner",
    "CoreEnrolGetEnrolledUsersParametersOptionsInner",
    "CoreEnrolGetEnrolledUsersResponseInner",
    "CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner",
    "CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner",
    "CoreEnrolGetEnrolledUsersResponseInnerGroupsInner",
    "CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner",
    "CoreEnrolGetEnrolledUsersResponseInnerRolesInner",
    "CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner",
    "CoreEnrolGetEnrolledUsersWithCapabilityResponseInner",
    "CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner",
    "CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner",
    "CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner",
    "CoreEnrolGetPotentialUsersResponseInner",
    "CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner",
    "CoreEnrolGetPotentialUsersResponseInnerPreferencesInner",
    "CoreEnrolGetUsersCoursesResponseInner",
    "CoreEnrolSubmitUserEnrolmentFormResponse",
    "CoreEnrolUnenrolUserEnrolmentResponse",
    "CoreEnrolUnenrolUserEnrolmentResponseErrorsInner",
    "CoreFetchNotificationsParameters",
    "CoreFetchNotificationsResponseInner",
    "CoreFetchNotificationsResponseInnerVariables",
    "CoreFilesDeleteDraftFilesParametersFilesInner",
    "CoreFilesDeleteDraftFilesResponse",
    "CoreFilesGetFilesResponse",
    "CoreFilesGetFilesResponseFilesInner",
    "CoreFilesGetFilesResponseParentsInner",
    "CoreFilesGetUnusedDraftItemidResponse",
    "CoreFilesUploadResponse",
    "CoreFiltersGetAllStatesResponse",
    "CoreFiltersGetAllStatesResponseFiltersInner",
    "CoreFiltersGetAvailableInContextParametersContextsInner",
    "CoreFiltersGetAvailableInContextResponse",
    "CoreFiltersGetAvailableInContextResponseFiltersInner",
    "CoreFormDynamicFormResponse",
    "CoreFormGetFiletypesBrowserDataParameters",
    "CoreFormGetFiletypesBrowserDataResponse",
    "CoreFormGetFiletypesBrowserDataResponseGroupsInner",
    "CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner",
    "CoreGetComponentStringsParameters",
    "CoreGetComponentStringsResponseInner",
    "CoreGetFragmentParametersArgsInner",
    "CoreGetFragmentResponse",
    "CoreGetStringParameters",
    "CoreGetStringParametersStringparamsInner",
    "CoreGetStringsParameters",
    "CoreGetStringsParametersStringsInner",
    "CoreGetStringsParametersStringsInnerStringparamsInner",
    "CoreGetStringsResponseInner",
    "CoreGetUserDatesParametersTimestampsInner",
    "CoreGetUserDatesResponse",
    "CoreGradesCreateGradecategoriesParametersCategoriesInner",
    "CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions",
    "CoreGradesCreateGradecategoriesResponse",
    "CoreGradesGetEnrolledUsersForSelectorResponse",
    "CoreGradesGetFeedbackResponse",
    "CoreGradesGetGradableUsersResponse",
    "CoreGradesGetGradeitemsResponse",
    "CoreGradesGetGradeitemsResponseGradeItemsInner",
    "CoreGradesGetGroupsForSelectorResponse",
    "CoreGradesGetGroupsForSelectorResponseGroupsInner",
    "CoreGradesGraderGradingpanelPointFetchResponse",
    "CoreGradesGraderGradingpanelPointFetchResponseGrade",
    "CoreGradesGraderGradingpanelPointStoreResponse",
    "CoreGradesGraderGradingpanelScaleFetchResponse",
    "CoreGradesGraderGradingpanelScaleFetchResponseGrade",
    "CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner",
    "CoreGradesGraderGradingpanelScaleStoreResponse",
    "CoreGradesUpdateGradesParametersGradesInner",
    "CoreGradesUpdateGradesParametersItemdetails",
    "CoreGradingGetDefinitionsResponse",
    "CoreGradingGetDefinitionsResponseAreasInner",
    "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner",
    "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide",
    "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner",
    "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner",
    "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric",
    "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner",
    "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner",
    "CoreGradingGetGradingformInstancesResponse",
    "CoreGradingGetGradingformInstancesResponseInstancesInner",
    "CoreGradingGetGradingformInstancesResponseInstancesInnerGuide",
    "CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner",
    "CoreGradingGetGradingformInstancesResponseInstancesInnerRubric",
    "CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner",
    "CoreGroupAddGroupMembersParametersMembersInner",
    "CoreGroupAssignGroupingParametersAssignmentsInner",
    "CoreGroupCreateGroupingsParametersGroupingsInner",
    "CoreGroupCreateGroupingsResponseInner",
    "CoreGroupCreateGroupsParametersGroupsInner",
    "CoreGroupCreateGroupsResponseInner",
    "CoreGroupGetActivityAllowedGroupsResponse",
    "CoreGroupGetActivityAllowedGroupsResponseGroupsInner",
    "CoreGroupGetActivityGroupmodeResponse",
    "CoreGroupGetCourseGroupingsResponseInner",
    "CoreGroupGetCourseGroupsResponseInner",
    "CoreGroupGetCourseUserGroupsResponse",
    "CoreGroupGetGroupMembersResponseInner",
    "CoreGroupGetGroupingsResponseInner",
    "CoreGroupGetGroupingsResponseInnerGroupsInner",
    "CoreGroupGetGroupsForSelectorResponse",
    "CoreGroupGetGroupsResponseInner",
    "CoreGroupUpdateGroupingsParametersGroupingsInner",
    "CoreGroupUpdateGroupsParametersGroupsInner",
    "CoreH5pGetTrustedH5pFileResponse",
    "CoreMessageCreateContactRequestResponse",
    "CoreMessageCreateContactRequestResponseRequest",
    "CoreMessageDataForMessageareaSearchMessagesResponse",
    "CoreMessageDataForMessageareaSearchMessagesResponseContactsInner",
    "CoreMessageDeleteMessageResponse",
    "CoreMessageGetBlockedUsersResponse",
    "CoreMessageGetBlockedUsersResponseUsersInner",
    "CoreMessageGetContactRequestsResponseInner",
    "CoreMessageGetContactRequestsResponseInnerContactrequestsInner",
    "CoreMessageGetContactRequestsResponseInnerConversationsInner",
    "CoreMessageGetConversationBetweenUsersResponse",
    "CoreMessageGetConversationBetweenUsersResponseMessagesInner",
    "CoreMessageGetConversationCountsResponse",
    "CoreMessageGetConversationCountsResponseTypes",
    "CoreMessageGetConversationMessagesResponse",
    "CoreMessageGetConversationResponse",
    "CoreMessageGetConversationsResponse",
    "CoreMessageGetConversationsResponseConversationsInner",
    "CoreMessageGetMessageProcessorResponse",
    "CoreMessageGetMessagesResponse",
    "CoreMessageGetMessagesResponseMessagesInner",
    "CoreMessageGetSelfConversationResponse",
    "CoreMessageGetUnreadConversationCountsResponse",
    "CoreMessageGetUnreadConversationCountsResponseTypes",
    "CoreMessageGetUnsentMessageResponse",
    "CoreMessageGetUserMessagePreferencesResponse",
    "CoreMessageGetUserMessagePreferencesResponsePreferences",
    "CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner",
    "CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner",
    "CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner",
    "CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner",
    "CoreMessageGetUserNotificationPreferencesResponse",
    "CoreMessageMarkMessageReadResponse",
    "CoreMessageMarkNotificationReadResponse",
    "CoreMessageMessageProcessorConfigFormParametersFormvaluesInner",
    "CoreMessageMessageSearchUsersResponse",
    "CoreMessageSearchContactsResponseInner",
    "CoreMessageSendInstantMessagesParametersMessagesInner",
    "CoreMessageSendInstantMessagesResponseInner",
    "CoreMessageSendMessagesToConversationParametersMessagesInner",
    "CoreMessageSetDefaultNotificationResponse",
    "CoreMoodlenetAuthCheckResponse",
    "CoreMoodlenetGetShareInfoActivityResponse",
    "CoreMoodlenetGetSharedCourseInfoResponse",
    "CoreMoodlenetSendActivityResponse",
    "CoreMoodlenetSendCourseResponse",
    "CoreMyViewPageResponse",
    "CoreNotesCreateNotesParametersNotesInner",
    "CoreNotesCreateNotesResponseInner",
    "CoreNotesDeleteNotesResponseInner",
    "CoreNotesGetCourseNotesResponse",
    "CoreNotesGetCourseNotesResponseCoursenotesInner",
    "CoreNotesGetNotesResponse",
    "CoreNotesGetNotesResponseNotesInner",
    "CoreNotesUpdateNotesParametersNotesInner",
    "CoreNotesViewNotesResponse",
    "CoreOutputLoadFontawesomeIconSystemMapParameters",
    "CoreOutputLoadFontawesomeIconSystemMapResponseInner",
    "CoreOutputLoadTemplateParameters",
    "CoreOutputLoadTemplateWithDependenciesParameters",
    "CoreOutputLoadTemplateWithDependenciesResponse",
    "CoreOutputLoadTemplateWithDependenciesResponseStringsInner",
    "CoreOutputPollStoredProgressResponseInner",
    "CorePaymentGetAvailableGatewaysResponseInner",
    "CoreQuestionGetRandomQuestionSummariesResponse",
    "CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner",
    "CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon",
    "CoreQuestionSearchSharedBanksResponse",
    "CoreQuestionSearchSharedBanksResponseSharedbanksInner",
    "CoreQuestionUpdateFlagResponse",
    "CoreRatingAddRatingResponse",
    "CoreRatingGetItemRatingsResponse",
    "CoreRatingGetItemRatingsResponseRatingsInner",
    "CoreReportbuilderCanViewSystemReportParametersParametersInner",
    "CoreReportbuilderColumnsAddResponse",
    "CoreReportbuilderColumnsAddResponseSortablecolumnsInner",
    "CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon",
    "CoreReportbuilderColumnsDeleteResponse",
    "CoreReportbuilderColumnsSortGetResponse",
    "CoreReportbuilderColumnsSortReorderResponse",
    "CoreReportbuilderColumnsSortToggleResponse",
    "CoreReportbuilderConditionsAddResponse",
    "CoreReportbuilderConditionsAddResponseAvailableconditionsInner",
    "CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup",
    "CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner",
    "CoreReportbuilderConditionsDeleteResponse",
    "CoreReportbuilderConditionsReorderResponse",
    "CoreReportbuilderConditionsResetResponse",
    "CoreReportbuilderFiltersAddResponse",
    "CoreReportbuilderFiltersAddResponseActivefiltersInner",
    "CoreReportbuilderFiltersDeleteResponse",
    "CoreReportbuilderFiltersReorderResponse",
    "CoreReportbuilderListReportsResponse",
    "CoreReportbuilderListReportsResponseReportsInner",
    "CoreReportbuilderListReportsResponseReportsInnerCustomfields",
    "CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner",
    "CoreReportbuilderReportsGetResponse",
    "CoreReportbuilderReportsGetResponseAttributesInner",
    "CoreReportbuilderReportsGetResponseButton",
    "CoreReportbuilderReportsGetResponseButtonAttributesInner",
    "CoreReportbuilderReportsGetResponseCardview",
    "CoreReportbuilderReportsGetResponseConditions",
    "CoreReportbuilderReportsGetResponseFilters",
    "CoreReportbuilderReportsGetResponseSidebarmenucards",
    "CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner",
    "CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner",
    "CoreReportbuilderReportsGetResponseSorting",
    "CoreReportbuilderRetrieveReportResponse",
    "CoreReportbuilderRetrieveReportResponseData",
    "CoreReportbuilderRetrieveReportResponseDataRowsInner",
    "CoreReportbuilderRetrieveSystemReportResponse",
    "CoreReportbuilderViewReportResponse",
    "CoreRoleAssignRolesParametersAssignmentsInner",
    "CoreRoleUnassignRolesParametersUnassignmentsInner",
    "CoreSearchGetRelevantUsersResponseInner",
    "CoreSearchGetResultsParametersFilters",
    "CoreSearchGetResultsResponse",
    "CoreSearchGetResultsResponseResultsInner",
    "CoreSearchGetSearchAreasListResponse",
    "CoreSearchGetSearchAreasListResponseAreasInner",
    "CoreSearchGetTopResultsResponse",
    "CoreSearchViewResultsParametersFilters",
    "CoreSearchViewResultsResponse",
    "CoreSessionTimeRemainingResponse",
    "CoreSmsSetGatewayStatusResponse",
    "CoreTableGetDynamicTableContentParametersFiltersInner",
    "CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner",
    "CoreTableGetDynamicTableContentParametersSortdataInner",
    "CoreTableGetDynamicTableContentResponse",
    "CoreTagGetTagAreasResponse",
    "CoreTagGetTagAreasResponseAreasInner",
    "CoreTagGetTagCloudResponse",
    "CoreTagGetTagCloudResponseTagsInner",
    "CoreTagGetTagCollectionsResponse",
    "CoreTagGetTagCollectionsResponseCollectionsInner",
    "CoreTagGetTagindexParametersTagindex",
    "CoreTagGetTagindexPerAreaParametersTagindex",
    "CoreTagGetTagindexPerAreaResponseInner",
    "CoreTagGetTagindexResponse",
    "CoreTagGetTagsParametersTagsInner",
    "CoreTagGetTagsResponse",
    "CoreTagGetTagsResponseTagsInner",
    "CoreTagUpdateTagsParametersTagsInner",
    "CoreTagUpdateTagsResponse",
    "CoreUpdateInplaceEditableResponse",
    "CoreUpdateInplaceEditableResponseEditicon",
    "CoreUserAgreeSitePolicyResponse",
    "CoreUserCreateUsersParametersUsersInner",
    "CoreUserCreateUsersParametersUsersInnerCustomfieldsInner",
    "CoreUserCreateUsersParametersUsersInnerPreferencesInner",
    "CoreUserCreateUsersResponseInner",
    "CoreUserGetCourseUserProfilesParametersUserlistInner",
    "CoreUserGetCourseUserProfilesResponseInner",
    "CoreUserGetPrivateFilesInfoResponse",
    "CoreUserGetUserPreferencesResponse",
    "CoreUserGetUserPreferencesResponsePreferencesInner",
    "CoreUserGetUsersParametersCriteriaInner",
    "CoreUserGetUsersResponse",
    "CoreUserGetUsersResponseWarningsInner",
    "CoreUserPreparePrivateFilesForEditionResponse",
    "CoreUserRemoveUserDeviceResponse",
    "CoreUserSearchIdentityResponse",
    "CoreUserSearchIdentityResponseListInner",
    "CoreUserSearchIdentityResponseListInnerExtrafieldsInner",
    "CoreUserSetUserPreferencesParameters",
    "CoreUserSetUserPreferencesParametersPreferencesInner",
    "CoreUserSetUserPreferencesResponse",
    "CoreUserSetUserPreferencesResponseSavedInner",
    "CoreUserUpdatePictureResponse",
    "CoreUserUpdatePrivateFilesResponse",
    "CoreUserUpdateUserDevicePublicKeyResponse",
    "CoreUserUpdateUserPreferencesParametersPreferencesInner",
    "CoreUserUpdateUsersParametersUsersInner",
    "CoreUserUpdateUsersResponse",
    "CoreUserViewUserListResponse",
    "CoreUserViewUserProfileResponse",
    "CoreWebserviceGetSiteInfoResponse",
    "CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner",
    "CoreWebserviceGetSiteInfoResponseFunctionsInner",
    "CustomfieldNumberRecalculateValueResponse",
    "EditorTinyGetConfigurationResponse",
    "EditorTinyGetConfigurationResponseInstalledlanguagesInner",
    "EditorTinyGetConfigurationResponsePluginsInner",
    "EditorTinyGetConfigurationResponsePluginsInnerSettingsInner",
    "EnrolGuestGetInstanceInfoResponse",
    "EnrolGuestGetInstanceInfoResponseInstanceinfo",
    "EnrolGuestValidatePasswordResponse",
    "EnrolManualEnrolUsersParametersEnrolmentsInner",
    "EnrolManualUnenrolUsersParametersEnrolmentsInner",
    "EnrolMetaAddInstancesParametersInstancesInner",
    "EnrolMetaAddInstancesResponseInner",
    "EnrolMetaDeleteInstancesParametersInstancesInner",
    "EnrolMetaDeleteInstancesResponseInner",
    "EnrolSelfEnrolUserResponse",
    "EnrolSelfGetInstanceInfoResponse",
    "GradereportGraderGetUsersInReportResponse",
    "GradereportOverviewGetCourseGradesResponse",
    "GradereportOverviewGetCourseGradesResponseGradesInner",
    "GradereportOverviewViewGradeReportResponse",
    "GradereportSingleviewGetGradeItemsForSearchWidgetResponse",
    "GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner",
    "GradereportUserGetAccessInformationResponse",
    "GradereportUserGetGradeItemsResponse",
    "GradereportUserGetGradeItemsResponseUsergradesInner",
    "GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner",
    "GradereportUserGetGradesTableResponse",
    "GradereportUserGetGradesTableResponseTablesInner",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInner",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank",
    "GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight",
    "GradereportUserViewGradeReportResponse",
    "GradingformGuideGraderGradingpanelFetchResponse",
    "GradingformGuideGraderGradingpanelFetchResponseGrade",
    "GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner",
    "GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner",
    "GradingformGuideGraderGradingpanelStoreResponse",
    "GradingformRubricGraderGradingpanelFetchResponse",
    "GradingformRubricGraderGradingpanelFetchResponseGrade",
    "GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner",
    "GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner",
    "GradingformRubricGraderGradingpanelStoreResponse",
    "LoginToken200Response",
    "MediaVideojsGetLanguageParameters",
    "MessageAirnotifierAreNotificationPreferencesConfiguredResponse",
    "MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner",
    "MessageAirnotifierEnableDeviceResponse",
    "MessageAirnotifierGetUserDevicesResponse",
    "MessageAirnotifierGetUserDevicesResponseDevicesInner",
    "MessagePopupGetPopupNotificationsResponse",
    "MessagePopupGetPopupNotificationsResponseNotificationsInner",
    "ModAssignGetAssignmentsResponse",
    "ModAssignGetAssignmentsResponseCoursesInner",
    "ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner",
    "ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner",
    "ModAssignGetAssignmentsResponseWarningsInner",
    "ModAssignGetGradesResponse",
    "ModAssignGetGradesResponseAssignmentsInner",
    "ModAssignGetGradesResponseAssignmentsInnerGradesInner",
    "ModAssignGetGradesResponseWarningsInner",
    "ModAssignGetParticipantResponse",
    "ModAssignGetSubmissionStatusResponse",
    "ModAssignGetSubmissionStatusResponseAssignmentdata",
    "ModAssignGetSubmissionStatusResponseAssignmentdataAttachments",
    "ModAssignGetSubmissionStatusResponseFeedback",
    "ModAssignGetSubmissionStatusResponseFeedbackPluginsInner",
    "ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner",
    "ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner",
    "ModAssignGetSubmissionStatusResponseGradingsummary",
    "ModAssignGetSubmissionStatusResponseLastattempt",
    "ModAssignGetSubmissionStatusResponseLastattemptSubmission",
    "ModAssignGetSubmissionStatusResponsePreviousattemptsInner",
    "ModAssignGetSubmissionsResponse",
    "ModAssignGetSubmissionsResponseAssignmentsInner",
    "ModAssignGetUserFlagsResponse",
    "ModAssignGetUserFlagsResponseAssignmentsInner",
    "ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner",
    "ModAssignGetUserFlagsResponseWarningsInner",
    "ModAssignGetUserMappingsResponse",
    "ModAssignGetUserMappingsResponseAssignmentsInner",
    "ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner",
    "ModAssignGetUserMappingsResponseWarningsInner",
    "ModAssignListParticipantsResponseInner",
    "ModAssignRemoveSubmissionResponse",
    "ModAssignSaveGradeParametersAdvancedgradingdata",
    "ModAssignSaveGradeParametersAdvancedgradingdataGuide",
    "ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner",
    "ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner",
    "ModAssignSaveGradeParametersAdvancedgradingdataRubric",
    "ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner",
    "ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner",
    "ModAssignSaveGradeParametersPlugindata",
    "ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor",
    "ModAssignSaveGradesParametersGradesInner",
    "ModAssignSaveSubmissionParametersPlugindata",
    "ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor",
    "ModAssignSetUserFlagsParametersUserflagsInner",
    "ModAssignSetUserFlagsResponseInner",
    "ModAssignStartSubmissionResponse",
    "ModAssignViewAssignResponse",
    "ModAssignViewGradingTableResponse",
    "ModAssignViewSubmissionStatusResponse",
    "ModBigbluebuttonbnCanJoinResponse",
    "ModBigbluebuttonbnCompletionValidateResponse",
    "ModBigbluebuttonbnEndMeetingResponse",
    "ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse",
    "ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner",
    "ModBigbluebuttonbnGetJoinUrlResponse",
    "ModBigbluebuttonbnGetRecordingsResponse",
    "ModBigbluebuttonbnGetRecordingsResponseTabledata",
    "ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner",
    "ModBigbluebuttonbnGetRecordingsToImportResponse",
    "ModBigbluebuttonbnMeetingInfoResponse",
    "ModBigbluebuttonbnMeetingInfoResponseFeaturesInner",
    "ModBigbluebuttonbnMeetingInfoResponsePresentationsInner",
    "ModBigbluebuttonbnViewBigbluebuttonbnResponse",
    "ModBookGetBooksByCoursesResponse",
    "ModBookGetBooksByCoursesResponseBooksInner",
    "ModBookViewBookResponse",
    "ModChoiceDeleteChoiceResponsesResponse",
    "ModChoiceGetChoiceOptionsResponse",
    "ModChoiceGetChoiceOptionsResponseOptionsInner",
    "ModChoiceGetChoiceResultsResponse",
    "ModChoiceGetChoiceResultsResponseOptionsInner",
    "ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner",
    "ModChoiceGetChoicesByCoursesResponse",
    "ModChoiceGetChoicesByCoursesResponseChoicesInner",
    "ModChoiceSubmitChoiceResponseResponse",
    "ModChoiceSubmitChoiceResponseResponseAnswersInner",
    "ModChoiceViewChoiceResponse",
    "ModDataAddEntryParametersDataInner",
    "ModDataAddEntryResponse",
    "ModDataAddEntryResponseFieldnotificationsInner",
    "ModDataApproveEntryResponse",
    "ModDataDeleteEntryResponse",
    "ModDataDeleteSavedPresetResponse",
    "ModDataGetDataAccessInformationResponse",
    "ModDataGetDatabasesByCoursesResponse",
    "ModDataGetDatabasesByCoursesResponseDatabasesInner",
    "ModDataGetEntriesResponse",
    "ModDataGetEntriesResponseEntriesInner",
    "ModDataGetEntriesResponseEntriesInnerContentsInner",
    "ModDataGetEntryResponse",
    "ModDataGetEntryResponseRatinginfo",
    "ModDataGetEntryResponseRatinginfoRatingsInner",
    "ModDataGetEntryResponseRatinginfoScalesInner",
    "ModDataGetEntryResponseRatinginfoScalesInnerItemsInner",
    "ModDataGetFieldsResponse",
    "ModDataGetFieldsResponseFieldsInner",
    "ModDataGetMappingInformationResponse",
    "ModDataGetMappingInformationResponseData",
    "ModDataSearchEntriesParametersAdvsearchInner",
    "ModDataSearchEntriesResponse",
    "ModDataUpdateEntryParametersDataInner",
    "ModDataUpdateEntryResponse",
    "ModDataViewDatabaseResponse",
    "ModFeedbackGetAnalysisResponse",
    "ModFeedbackGetAnalysisResponseItemsdataInner",
    "ModFeedbackGetAnalysisResponseItemsdataInnerItem",
    "ModFeedbackGetCurrentCompletedTmpResponse",
    "ModFeedbackGetCurrentCompletedTmpResponseFeedback",
    "ModFeedbackGetFeedbackAccessInformationResponse",
    "ModFeedbackGetFeedbacksByCoursesResponse",
    "ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner",
    "ModFeedbackGetFinishedResponsesResponse",
    "ModFeedbackGetFinishedResponsesResponseResponsesInner",
    "ModFeedbackGetItemsResponse",
    "ModFeedbackGetLastCompletedResponse",
    "ModFeedbackGetLastCompletedResponseCompleted",
    "ModFeedbackGetNonRespondentsResponse",
    "ModFeedbackGetNonRespondentsResponseUsersInner",
    "ModFeedbackGetPageItemsResponse",
    "ModFeedbackGetResponsesAnalysisResponse",
    "ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner",
    "ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner",
    "ModFeedbackGetResponsesAnalysisResponseAttemptsInner",
    "ModFeedbackGetUnfinishedResponsesResponse",
    "ModFeedbackGetUnfinishedResponsesResponseResponsesInner",
    "ModFeedbackLaunchFeedbackResponse",
    "ModFeedbackProcessPageParametersResponsesInner",
    "ModFeedbackProcessPageResponse",
    "ModFeedbackViewFeedbackResponse",
    "ModFolderGetFoldersByCoursesResponse",
    "ModFolderGetFoldersByCoursesResponseFoldersInner",
    "ModFolderViewFolderResponse",
    "ModForumAddDiscussionParametersOptionsInner",
    "ModForumAddDiscussionPostParametersOptionsInner",
    "ModForumAddDiscussionPostResponse",
    "ModForumAddDiscussionPostResponseMessagesInner",
    "ModForumAddDiscussionPostResponsePost",
    "ModForumAddDiscussionPostResponsePostAttachmentsInner",
    "ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml",
    "ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls",
    "ModForumAddDiscussionPostResponsePostAuthor",
    "ModForumAddDiscussionPostResponsePostAuthorGroupsInner",
    "ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls",
    "ModForumAddDiscussionPostResponsePostAuthorUrls",
    "ModForumAddDiscussionPostResponsePostCapabilities",
    "ModForumAddDiscussionPostResponsePostHtml",
    "ModForumAddDiscussionPostResponsePostTagsInner",
    "ModForumAddDiscussionPostResponsePostTagsInnerUrls",
    "ModForumAddDiscussionPostResponsePostUrls",
    "ModForumAddDiscussionResponse",
    "ModForumCanAddDiscussionResponse",
    "ModForumDeletePostResponse",
    "ModForumGetDiscussionPostResponse",
    "ModForumGetDiscussionPostsByUseridResponse",
    "ModForumGetDiscussionPostsByUseridResponseDiscussionsInner",
    "ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts",
    "ModForumGetDiscussionPostsResponse",
    "ModForumGetForumAccessInformationResponse",
    "ModForumGetForumDiscussionsResponse",
    "ModForumGetForumDiscussionsResponseDiscussionsInner",
    "ModForumGetForumsByCoursesResponseInner",
    "ModForumPrepareDraftAreaForPostParametersFilestokeepInner",
    "ModForumPrepareDraftAreaForPostResponse",
    "ModForumSetLockStateResponse",
    "ModForumSetLockStateResponseTimes",
    "ModForumSetPinStateResponse",
    "ModForumSetPinStateResponseCapabilities",
    "ModForumSetPinStateResponseGroup",
    "ModForumSetPinStateResponseGroupUrls",
    "ModForumSetPinStateResponseTimed",
    "ModForumSetPinStateResponseTimes",
    "ModForumSetPinStateResponseUrls",
    "ModForumSetPinStateResponseUserstate",
    "ModForumSetSubscriptionStateResponse",
    "ModForumToggleFavouriteStateResponse",
    "ModForumUpdateDiscussionPostParametersOptionsInner",
    "ModForumUpdateDiscussionPostResponse",
    "ModForumViewForumDiscussionResponse",
    "ModForumViewForumResponse",
    "ModGlossaryAddEntryParametersOptionsInner",
    "ModGlossaryAddEntryResponse",
    "ModGlossaryDeleteEntryResponse",
    "ModGlossaryGetAuthorsParametersOptions",
    "ModGlossaryGetAuthorsResponse",
    "ModGlossaryGetAuthorsResponseAuthorsInner",
    "ModGlossaryGetCategoriesResponse",
    "ModGlossaryGetCategoriesResponseCategoriesInner",
    "ModGlossaryGetEntriesByAuthorIdParametersOptions",
    "ModGlossaryGetEntriesByAuthorIdResponse",
    "ModGlossaryGetEntriesByAuthorIdResponseEntriesInner",
    "ModGlossaryGetEntriesByAuthorResponse",
    "ModGlossaryGetEntriesByCategoryResponse",
    "ModGlossaryGetEntriesByCategoryResponseEntriesInner",
    "ModGlossaryGetEntriesByDateResponse",
    "ModGlossaryGetEntriesByLetterResponse",
    "ModGlossaryGetEntriesBySearchResponse",
    "ModGlossaryGetEntriesByTermResponse",
    "ModGlossaryGetEntriesToApproveResponse",
    "ModGlossaryGetEntryByIdResponse",
    "ModGlossaryGetEntryByIdResponsePermissions",
    "ModGlossaryGetGlossariesByCoursesResponse",
    "ModGlossaryGetGlossariesByCoursesResponseGlossariesInner",
    "ModGlossaryPrepareEntryForEditionResponse",
    "ModGlossaryUpdateEntryResponse",
    "ModGlossaryViewEntryResponse",
    "ModGlossaryViewGlossaryResponse",
    "ModH5pactivityGetAttemptsResponse",
    "ModH5pactivityGetAttemptsResponseUsersattemptsInner",
    "ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner",
    "ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored",
    "ModH5pactivityGetH5pactivitiesByCoursesResponse",
    "ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner",
    "ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile",
    "ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings",
    "ModH5pactivityGetH5pactivityAccessInformationResponse",
    "ModH5pactivityGetResultsResponse",
    "ModH5pactivityGetResultsResponseAttemptsInner",
    "ModH5pactivityGetResultsResponseAttemptsInnerResultsInner",
    "ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner",
    "ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer",
    "ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer",
    "ModH5pactivityGetUserAttemptsResponse",
    "ModH5pactivityGetUserAttemptsResponseUsersattemptsInner",
    "ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored",
    "ModH5pactivityLogReportViewedResponse",
    "ModH5pactivityViewH5pactivityResponse",
    "ModImscpGetImscpsByCoursesResponse",
    "ModImscpGetImscpsByCoursesResponseImscpsInner",
    "ModImscpViewImscpResponse",
    "ModLabelGetLabelsByCoursesResponse",
    "ModLabelGetLabelsByCoursesResponseLabelsInner",
    "ModLessonFinishAttemptResponse",
    "ModLessonFinishAttemptResponseDataInner",
    "ModLessonFinishAttemptResponseMessagesInner",
    "ModLessonGetAttemptsOverviewResponse",
    "ModLessonGetAttemptsOverviewResponseData",
    "ModLessonGetAttemptsOverviewResponseDataStudentsInner",
    "ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner",
    "ModLessonGetContentPagesViewedResponse",
    "ModLessonGetContentPagesViewedResponsePagesInner",
    "ModLessonGetLessonAccessInformationResponse",
    "ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner",
    "ModLessonGetLessonResponse",
    "ModLessonGetLessonResponseLesson",
    "ModLessonGetLessonsByCoursesResponse",
    "ModLessonGetPageDataResponse",
    "ModLessonGetPageDataResponseAnswersInner",
    "ModLessonGetPageDataResponsePage",
    "ModLessonGetPagesPossibleJumpsResponse",
    "ModLessonGetPagesPossibleJumpsResponseJumpsInner",
    "ModLessonGetPagesResponse",
    "ModLessonGetPagesResponsePagesInner",
    "ModLessonGetQuestionsAttemptsResponse",
    "ModLessonGetQuestionsAttemptsResponseAttemptsInner",
    "ModLessonGetUserAttemptGradeResponse",
    "ModLessonGetUserAttemptGradeResponseGrade",
    "ModLessonGetUserAttemptResponse",
    "ModLessonGetUserAttemptResponseAnswerpagesInner",
    "ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata",
    "ModLessonGetUserAttemptResponseUserstats",
    "ModLessonGetUserGradeResponse",
    "ModLessonGetUserTimersResponse",
    "ModLessonGetUserTimersResponseTimersInner",
    "ModLessonLaunchAttemptResponse",
    "ModLessonProcessPageParametersDataInner",
    "ModLessonProcessPageResponse",
    "ModLessonViewLessonResponse",
    "ModLtiCreateToolProxyResponse",
    "ModLtiCreateToolTypeResponse",
    "ModLtiCreateToolTypeResponseState",
    "ModLtiCreateToolTypeResponseUrls",
    "ModLtiDeleteToolProxyResponse",
    "ModLtiDeleteToolTypeResponse",
    "ModLtiGetLtisByCoursesResponse",
    "ModLtiGetLtisByCoursesResponseLtisInner",
    "ModLtiGetToolLaunchDataResponse",
    "ModLtiGetToolLaunchDataResponseParametersInner",
    "ModLtiGetToolProxiesResponseInner",
    "ModLtiGetToolProxyRegistrationRequestResponse",
    "ModLtiGetToolTypesAndProxiesCountResponse",
    "ModLtiGetToolTypesAndProxiesResponse",
    "ModLtiGetToolTypesAndProxiesResponseTypesInner",
    "ModLtiIsCartridgeResponse",
    "ModLtiUpdateToolTypeResponse",
    "ModLtiViewLtiResponse",
    "ModPageGetPagesByCoursesResponse",
    "ModPageGetPagesByCoursesResponsePagesInner",
    "ModPageViewPageResponse",
    "ModQuizAddRandomQuestionsResponse",
    "ModQuizCreateGradeItemsParametersQuizgradeitemsInner",
    "ModQuizDeleteGradeItemsParametersQuizgradeitemsInner",
    "ModQuizDeleteOverridesParametersData",
    "ModQuizDeleteOverridesResponse",
    "ModQuizGetAttemptAccessInformationResponse",
    "ModQuizGetAttemptDataResponse",
    "ModQuizGetAttemptDataResponseAttempt",
    "ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner",
    "ModQuizGetAttemptDataResponseQuestionsInner",
    "ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner",
    "ModQuizGetAttemptReviewResponse",
    "ModQuizGetAttemptReviewResponseAdditionaldataInner",
    "ModQuizGetAttemptSummaryResponse",
    "ModQuizGetCombinedReviewOptionsResponse",
    "ModQuizGetCombinedReviewOptionsResponseAlloptionsInner",
    "ModQuizGetOverridesResponse",
    "ModQuizGetOverridesResponseOverridesInner",
    "ModQuizGetQuizAccessInformationResponse",
    "ModQuizGetQuizFeedbackForGradeResponse",
    "ModQuizGetQuizRequiredQtypesResponse",
    "ModQuizGetQuizzesByCoursesResponse",
    "ModQuizGetQuizzesByCoursesResponseQuizzesInner",
    "ModQuizGetUserAttemptsResponse",
    "ModQuizGetUserAttemptsResponseAttemptsInner",
    "ModQuizGetUserBestGradeResponse",
    "ModQuizGetUserQuizAttemptsResponse",
    "ModQuizProcessAttemptResponse",
    "ModQuizSaveAttemptResponse",
    "ModQuizSaveOverridesParametersData",
    "ModQuizSaveOverridesParametersDataOverridesInner",
    "ModQuizSaveOverridesResponse",
    "ModQuizSetQuestionVersionResponse",
    "ModQuizStartAttemptResponse",
    "ModQuizUpdateFilterConditionResponse",
    "ModQuizUpdateGradeItemsParametersQuizgradeitemsInner",
    "ModQuizUpdateSlotsParametersSlotsInner",
    "ModQuizViewAttemptResponse",
    "ModQuizViewAttemptReviewResponse",
    "ModQuizViewAttemptSummaryResponse",
    "ModQuizViewQuizResponse",
    "ModResourceGetResourcesByCoursesResponse",
    "ModResourceGetResourcesByCoursesResponseResourcesInner",
    "ModResourceViewResourceResponse",
    "ModScormGetScormAccessInformationResponse",
    "ModScormGetScormAttemptCountResponse",
    "ModScormGetScormScoTracksResponse",
    "ModScormGetScormScoTracksResponseData",
    "ModScormGetScormScoTracksResponseDataTracksInner",
    "ModScormGetScormScoesResponse",
    "ModScormGetScormScoesResponseScoesInner",
    "ModScormGetScormScoesResponseScoesInnerExtradataInner",
    "ModScormGetScormUserDataResponse",
    "ModScormGetScormUserDataResponseDataInner",
    "ModScormGetScormsByCoursesResponse",
    "ModScormGetScormsByCoursesResponseOptionsInner",
    "ModScormGetScormsByCoursesResponseScormsInner",
    "ModScormInsertScormTracksResponse",
    "ModScormLaunchScoResponse",
    "ModScormViewScormResponse",
    "ModUrlGetUrlsByCoursesResponse",
    "ModUrlGetUrlsByCoursesResponseUrlsInner",
    "ModUrlViewUrlResponse",
    "ModWikiEditPageResponse",
    "ModWikiGetPageContentsResponse",
    "ModWikiGetPageContentsResponsePage",
    "ModWikiGetPageForEditingResponse",
    "ModWikiGetPageForEditingResponsePagesection",
    "ModWikiGetSubwikiFilesResponse",
    "ModWikiGetSubwikiPagesParametersOptions",
    "ModWikiGetSubwikiPagesResponse",
    "ModWikiGetSubwikiPagesResponsePagesInner",
    "ModWikiGetSubwikisResponse",
    "ModWikiGetSubwikisResponseSubwikisInner",
    "ModWikiGetWikisByCoursesResponse",
    "ModWikiGetWikisByCoursesResponseWikisInner",
    "ModWikiNewPageResponse",
    "ModWikiViewPageResponse",
    "ModWikiViewWikiResponse",
    "ModWorkshopAddSubmissionResponse",
    "ModWorkshopDeleteSubmissionResponse",
    "ModWorkshopEvaluateAssessmentResponse",
    "ModWorkshopEvaluateSubmissionResponse",
    "ModWorkshopGetAssessmentFormDefinitionResponse",
    "ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner",
    "ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner",
    "ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner",
    "ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner",
    "ModWorkshopGetAssessmentResponse",
    "ModWorkshopGetAssessmentResponseAssessment",
    "ModWorkshopGetGradesReportResponse",
    "ModWorkshopGetGradesReportResponseReport",
    "ModWorkshopGetGradesReportResponseReportGradesInner",
    "ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner",
    "ModWorkshopGetGradesResponse",
    "ModWorkshopGetReviewerAssessmentsResponse",
    "ModWorkshopGetSubmissionAssessmentsResponse",
    "ModWorkshopGetSubmissionResponse",
    "ModWorkshopGetSubmissionResponseSubmission",
    "ModWorkshopGetSubmissionsResponse",
    "ModWorkshopGetUserPlanResponse",
    "ModWorkshopGetUserPlanResponseUserplan",
    "ModWorkshopGetUserPlanResponseUserplanExamplesInner",
    "ModWorkshopGetUserPlanResponseUserplanPhasesInner",
    "ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner",
    "ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner",
    "ModWorkshopGetWorkshopAccessInformationResponse",
    "ModWorkshopGetWorkshopsByCoursesResponse",
    "ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner",
    "ModWorkshopUpdateAssessmentParametersDataInner",
    "ModWorkshopUpdateAssessmentResponse",
    "ModWorkshopUpdateSubmissionResponse",
    "ModWorkshopViewSubmissionResponse",
    "ModWorkshopViewWorkshopResponse",
    "PaygwPaypalCreateTransactionCompleteParameters",
    "PaygwPaypalCreateTransactionCompleteResponse",
    "PaygwPaypalGetConfigForJsResponse",
    "QbankEditquestionSetStatusResponse",
    "QbankManagecategoriesMoveCategoryResponseInner",
    "QbankManagecategoriesMoveCategoryResponseInnerFields",
    "QbankTagquestionSubmitTagsFormResponse",
    "QuizaccessSebValidateQuizKeysResponse",
    "ReportCompetencyDataForReportResponse",
    "ReportCompetencyDataForReportResponseUsercompetenciesInner",
    "ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency",
    "ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath",
    "ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner",
    "ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse",
    "ReportInsightsActionExecutedResponse",
    "TinyAutosaveResetSessionParameters",
    "TinyAutosaveResumeSessionParameters",
    "TinyAutosaveResumeSessionResponse",
    "TinyAutosaveUpdateSessionParameters",
    "TinyEquationFilterResponse",
    "TinyMediaPreviewResponse",
    "TinyPremiumGetApiKeyResponse",
    "ToolAnalyticsPotentialContextsResponseInner",
    "ToolBehatGetEntityGeneratorResponse",
    "ToolDataprivacyApproveDataRequestResponse",
    "ToolDataprivacyBulkApproveDataRequestsResponse",
    "ToolDataprivacyBulkDenyDataRequestsResponse",
    "ToolDataprivacyCancelDataRequestResponse",
    "ToolDataprivacyConfirmContextsForDeletionResponse",
    "ToolDataprivacyContactDpoResponse",
    "ToolDataprivacyCreateCategoryFormResponse",
    "ToolDataprivacyCreateCategoryFormResponseCategory",
    "ToolDataprivacyCreateDataRequestResponse",
    "ToolDataprivacyCreatePurposeFormResponse",
    "ToolDataprivacyCreatePurposeFormResponsePurpose",
    "ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner",
    "ToolDataprivacyDeleteCategoryResponse",
    "ToolDataprivacyDeletePurposeResponse",
    "ToolDataprivacyDenyDataRequestResponse",
    "ToolDataprivacyGetAccessInformationResponse",
    "ToolDataprivacyGetActivityOptionsResponse",
    "ToolDataprivacyGetActivityOptionsResponseOptionsInner",
    "ToolDataprivacyGetCategoryOptionsResponse",
    "ToolDataprivacyGetCategoryOptionsResponseOptionsInner",
    "ToolDataprivacyGetDataRequestResponse",
    "ToolDataprivacyGetDataRequestResponseResult",
    "ToolDataprivacyGetDataRequestsResponse",
    "ToolDataprivacyGetPurposeOptionsResponse",
    "ToolDataprivacyGetPurposeOptionsResponseOptionsInner",
    "ToolDataprivacyMarkCompleteResponse",
    "ToolDataprivacySetContextDefaultsResponse",
    "ToolDataprivacySetContextFormResponse",
    "ToolDataprivacySetContextlevelFormResponse",
    "ToolDataprivacySubmitSelectedCoursesFormResponse",
    "ToolDataprivacyTreeExtraBranchesResponse",
    "ToolDataprivacyTreeExtraBranchesResponseBranchesInner",
    "ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner",
    "ToolLpDataForCompetenciesManagePageResponse",
    "ToolLpDataForCompetencyFrameworksManagePageResponse",
    "ToolLpDataForCompetencySummaryResponse",
    "ToolLpDataForCourseCompetenciesPageResponse",
    "ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner",
    "ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner",
    "ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner",
    "ToolLpDataForCourseCompetenciesPageResponseSettings",
    "ToolLpDataForCourseCompetenciesPageResponseStatistics",
    "ToolLpDataForPlanPageResponse",
    "ToolLpDataForPlanPageResponseCompetenciesInner",
    "ToolLpDataForPlansPageResponse",
    "ToolLpDataForRelatedCompetenciesSectionResponse",
    "ToolLpDataForTemplateCompetenciesPageResponse",
    "ToolLpDataForTemplateCompetenciesPageResponseStatistics",
    "ToolLpDataForTemplatesManagePageResponse",
    "ToolLpDataForUserCompetencySummaryInCourseResponse",
    "ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary",
    "ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner",
    "ToolLpDataForUserCompetencySummaryInPlanResponse",
    "ToolLpDataForUserCompetencySummaryResponse",
    "ToolLpDataForUserEvidenceListPageResponse",
    "ToolLpDataForUserEvidenceListPageResponseEvidenceInner",
    "ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner",
    "ToolLpDataForUserEvidencePageResponse",
    "ToolLpSearchCohortsResponse",
    "ToolLpSearchUsersResponse",
    "ToolMobileCallExternalFunctionsParametersRequestsInner",
    "ToolMobileCallExternalFunctionsResponse",
    "ToolMobileCallExternalFunctionsResponseResponsesInner",
    "ToolMobileGetAutologinKeyResponse",
    "ToolMobileGetConfigResponse",
    "ToolMobileGetConfigResponseSettingsInner",
    "ToolMobileGetContentParametersArgsInner",
    "ToolMobileGetContentResponse",
    "ToolMobileGetContentResponseOtherdataInner",
    "ToolMobileGetContentResponseRestrict",
    "ToolMobileGetContentResponseTemplatesInner",
    "ToolMobileGetPluginsSupportingMobileResponse",
    "ToolMobileGetPluginsSupportingMobileResponsePluginsInner",
    "ToolMobileGetPublicConfigResponse",
    "ToolMobileGetPublicConfigResponseIdentityprovidersInner",
    "ToolMobileGetTokensForQrLoginParameters",
    "ToolMobileGetTokensForQrLoginResponse",
    "ToolMobileValidateSubscriptionKeyParameters",
    "ToolMobileValidateSubscriptionKeyResponse",
    "ToolMoodlenetSearchCoursesResponse",
    "ToolMoodlenetSearchCoursesResponseCoursesInner",
    "ToolMoodlenetVerifyWebfingerResponse",
    "ToolPolicyGetPolicyVersionParameters",
    "ToolPolicyGetPolicyVersionResponse",
    "ToolPolicyGetPolicyVersionResponseResult",
    "ToolPolicyGetPolicyVersionResponseResultPolicy",
    "ToolPolicyGetUserAcceptancesResponse",
    "ToolPolicyGetUserAcceptancesResponsePoliciesInner",
    "ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance",
    "ToolPolicySetAcceptancesStatusParametersPoliciesInner",
    "ToolPolicySetAcceptancesStatusResponse",
    "ToolTemplatelibraryListTemplatesParameters",
    "ToolTemplatelibraryLoadCanonicalTemplateParameters",
    "ToolUsertoursFetchAndStartTourResponse",
    "ToolUsertoursFetchAndStartTourResponseTourconfig",
    "ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner",
    "ToolUsertoursResetTourResponse",
]

if __import__("typing").TYPE_CHECKING:
    # import apis into sdk package
    from poodle_async_full.api.default_api import DefaultApi as DefaultApi
    
    # import ApiClient
    from poodle_async_full.api_response import ApiResponse as ApiResponse
    from poodle_async_full.api_client import ApiClient as ApiClient
    from poodle_async_full.configuration import Configuration as Configuration
    from poodle_async_full.configuration import settings as settings
    from poodle_async_full.exceptions import OpenApiException as OpenApiException
    from poodle_async_full.exceptions import ApiTypeError as ApiTypeError
    from poodle_async_full.exceptions import ApiValueError as ApiValueError
    from poodle_async_full.exceptions import ApiKeyError as ApiKeyError
    from poodle_async_full.exceptions import ApiAttributeError as ApiAttributeError
    from poodle_async_full.exceptions import ApiException as ApiException
    
    # import models into sdk package
    from poodle_async_full.models.aiplacement_courseassist_explain_text_response import AiplacementCourseassistExplainTextResponse as AiplacementCourseassistExplainTextResponse
    from poodle_async_full.models.aiplacement_courseassist_summarise_text_response import AiplacementCourseassistSummariseTextResponse as AiplacementCourseassistSummariseTextResponse
    from poodle_async_full.models.aiplacement_editor_generate_image_response import AiplacementEditorGenerateImageResponse as AiplacementEditorGenerateImageResponse
    from poodle_async_full.models.aiplacement_editor_generate_text_response import AiplacementEditorGenerateTextResponse as AiplacementEditorGenerateTextResponse
    from poodle_async_full.models.auth_email_get_signup_settings_response import AuthEmailGetSignupSettingsResponse as AuthEmailGetSignupSettingsResponse
    from poodle_async_full.models.auth_email_get_signup_settings_response_profilefields_inner import AuthEmailGetSignupSettingsResponseProfilefieldsInner as AuthEmailGetSignupSettingsResponseProfilefieldsInner
    from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner as AuthEmailGetSignupSettingsResponseWarningsInner
    from poodle_async_full.models.auth_email_signup_user_parameters import AuthEmailSignupUserParameters as AuthEmailSignupUserParameters
    from poodle_async_full.models.auth_email_signup_user_parameters_customprofilefields_inner import AuthEmailSignupUserParametersCustomprofilefieldsInner as AuthEmailSignupUserParametersCustomprofilefieldsInner
    from poodle_async_full.models.auth_email_signup_user_response import AuthEmailSignupUserResponse as AuthEmailSignupUserResponse
    from poodle_async_full.models.block_accessreview_get_module_data_response_inner import BlockAccessreviewGetModuleDataResponseInner as BlockAccessreviewGetModuleDataResponseInner
    from poodle_async_full.models.block_accessreview_get_section_data_response_inner import BlockAccessreviewGetSectionDataResponseInner as BlockAccessreviewGetSectionDataResponseInner
    from poodle_async_full.models.block_recentlyaccesseditems_get_recent_items_response_inner import BlockRecentlyaccesseditemsGetRecentItemsResponseInner as BlockRecentlyaccesseditemsGetRecentItemsResponseInner
    from poodle_async_full.models.block_starredcourses_get_starred_courses_response_inner import BlockStarredcoursesGetStarredCoursesResponseInner as BlockStarredcoursesGetStarredCoursesResponseInner
    from poodle_async_full.models.core_ai_delete_provider_instance_response import CoreAiDeleteProviderInstanceResponse as CoreAiDeleteProviderInstanceResponse
    from poodle_async_full.models.core_ai_get_policy_status_response import CoreAiGetPolicyStatusResponse as CoreAiGetPolicyStatusResponse
    from poodle_async_full.models.core_ai_set_policy_status_response import CoreAiSetPolicyStatusResponse as CoreAiSetPolicyStatusResponse
    from poodle_async_full.models.core_ai_set_provider_status_response import CoreAiSetProviderStatusResponse as CoreAiSetProviderStatusResponse
    from poodle_async_full.models.core_auth_confirm_user_parameters import CoreAuthConfirmUserParameters as CoreAuthConfirmUserParameters
    from poodle_async_full.models.core_auth_confirm_user_response import CoreAuthConfirmUserResponse as CoreAuthConfirmUserResponse
    from poodle_async_full.models.core_auth_is_age_digital_consent_verification_enabled_response import CoreAuthIsAgeDigitalConsentVerificationEnabledResponse as CoreAuthIsAgeDigitalConsentVerificationEnabledResponse
    from poodle_async_full.models.core_auth_is_minor_parameters import CoreAuthIsMinorParameters as CoreAuthIsMinorParameters
    from poodle_async_full.models.core_auth_is_minor_response import CoreAuthIsMinorResponse as CoreAuthIsMinorResponse
    from poodle_async_full.models.core_auth_request_password_reset_parameters import CoreAuthRequestPasswordResetParameters as CoreAuthRequestPasswordResetParameters
    from poodle_async_full.models.core_auth_request_password_reset_response import CoreAuthRequestPasswordResetResponse as CoreAuthRequestPasswordResetResponse
    from poodle_async_full.models.core_auth_resend_confirmation_email_parameters import CoreAuthResendConfirmationEmailParameters as CoreAuthResendConfirmationEmailParameters
    from poodle_async_full.models.core_auth_resend_confirmation_email_response import CoreAuthResendConfirmationEmailResponse as CoreAuthResendConfirmationEmailResponse
    from poodle_async_full.models.core_backup_get_async_backup_links_backup_response import CoreBackupGetAsyncBackupLinksBackupResponse as CoreBackupGetAsyncBackupLinksBackupResponse
    from poodle_async_full.models.core_backup_get_async_backup_links_restore_response import CoreBackupGetAsyncBackupLinksRestoreResponse as CoreBackupGetAsyncBackupLinksRestoreResponse
    from poodle_async_full.models.core_backup_get_async_backup_progress_response_inner import CoreBackupGetAsyncBackupProgressResponseInner as CoreBackupGetAsyncBackupProgressResponseInner
    from poodle_async_full.models.core_backup_get_copy_progress_parameters_copies_inner import CoreBackupGetCopyProgressParametersCopiesInner as CoreBackupGetCopyProgressParametersCopiesInner
    from poodle_async_full.models.core_backup_get_copy_progress_response_inner import CoreBackupGetCopyProgressResponseInner as CoreBackupGetCopyProgressResponseInner
    from poodle_async_full.models.core_badges_disable_badges_response import CoreBadgesDisableBadgesResponse as CoreBadgesDisableBadgesResponse
    from poodle_async_full.models.core_badges_enable_badges_response import CoreBadgesEnableBadgesResponse as CoreBadgesEnableBadgesResponse
    from poodle_async_full.models.core_badges_enable_badges_response_result_inner import CoreBadgesEnableBadgesResponseResultInner as CoreBadgesEnableBadgesResponseResultInner
    from poodle_async_full.models.core_badges_get_badge_response import CoreBadgesGetBadgeResponse as CoreBadgesGetBadgeResponse
    from poodle_async_full.models.core_badges_get_badge_response_badge import CoreBadgesGetBadgeResponseBadge as CoreBadgesGetBadgeResponseBadge
    from poodle_async_full.models.core_badges_get_badge_response_badge_alignment_inner import CoreBadgesGetBadgeResponseBadgeAlignmentInner as CoreBadgesGetBadgeResponseBadgeAlignmentInner
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response import CoreBadgesGetUserBadgeByHashResponse as CoreBadgesGetUserBadgeByHashResponse
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInner as CoreBadgesGetUserBadgeByHashResponseBadgeInner
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_endorsement import CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement as CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_relatedbadges_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner as CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner
    from poodle_async_full.models.core_badges_get_user_badges_response import CoreBadgesGetUserBadgesResponse as CoreBadgesGetUserBadgesResponse
    from poodle_async_full.models.core_block_fetch_addable_blocks_response_inner import CoreBlockFetchAddableBlocksResponseInner as CoreBlockFetchAddableBlocksResponseInner
    from poodle_async_full.models.core_block_get_course_blocks_response import CoreBlockGetCourseBlocksResponse as CoreBlockGetCourseBlocksResponse
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner import CoreBlockGetCourseBlocksResponseBlocksInner as CoreBlockGetCourseBlocksResponseBlocksInner
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_configs_inner import CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner as CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents import CoreBlockGetCourseBlocksResponseBlocksInnerContents as CoreBlockGetCourseBlocksResponseBlocksInnerContents
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner as CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
    from poodle_async_full.models.core_block_get_dashboard_blocks_response import CoreBlockGetDashboardBlocksResponse as CoreBlockGetDashboardBlocksResponse
    from poodle_async_full.models.core_blog_add_entry_parameters_options_inner import CoreBlogAddEntryParametersOptionsInner as CoreBlogAddEntryParametersOptionsInner
    from poodle_async_full.models.core_blog_add_entry_response import CoreBlogAddEntryResponse as CoreBlogAddEntryResponse
    from poodle_async_full.models.core_blog_delete_entry_response import CoreBlogDeleteEntryResponse as CoreBlogDeleteEntryResponse
    from poodle_async_full.models.core_blog_get_access_information_response import CoreBlogGetAccessInformationResponse as CoreBlogGetAccessInformationResponse
    from poodle_async_full.models.core_blog_get_entries_parameters import CoreBlogGetEntriesParameters as CoreBlogGetEntriesParameters
    from poodle_async_full.models.core_blog_get_entries_parameters_filters_inner import CoreBlogGetEntriesParametersFiltersInner as CoreBlogGetEntriesParametersFiltersInner
    from poodle_async_full.models.core_blog_get_entries_response import CoreBlogGetEntriesResponse as CoreBlogGetEntriesResponse
    from poodle_async_full.models.core_blog_get_entries_response_entries_inner import CoreBlogGetEntriesResponseEntriesInner as CoreBlogGetEntriesResponseEntriesInner
    from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner as CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
    from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner as CoreBlogGetEntriesResponseEntriesInnerTagsInner
    from poodle_async_full.models.core_blog_prepare_entry_for_edition_response import CoreBlogPrepareEntryForEditionResponse as CoreBlogPrepareEntryForEditionResponse
    from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner import CoreBlogPrepareEntryForEditionResponseAreasInner as CoreBlogPrepareEntryForEditionResponseAreasInner
    from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner_options_inner import CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner as CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner
    from poodle_async_full.models.core_blog_update_entry_response import CoreBlogUpdateEntryResponse as CoreBlogUpdateEntryResponse
    from poodle_async_full.models.core_blog_view_entries_parameters import CoreBlogViewEntriesParameters as CoreBlogViewEntriesParameters
    from poodle_async_full.models.core_blog_view_entries_parameters_filters_inner import CoreBlogViewEntriesParametersFiltersInner as CoreBlogViewEntriesParametersFiltersInner
    from poodle_async_full.models.core_blog_view_entries_response import CoreBlogViewEntriesResponse as CoreBlogViewEntriesResponse
    from poodle_async_full.models.core_calendar_create_calendar_events_parameters_events_inner import CoreCalendarCreateCalendarEventsParametersEventsInner as CoreCalendarCreateCalendarEventsParametersEventsInner
    from poodle_async_full.models.core_calendar_create_calendar_events_response import CoreCalendarCreateCalendarEventsResponse as CoreCalendarCreateCalendarEventsResponse
    from poodle_async_full.models.core_calendar_create_calendar_events_response_events_inner import CoreCalendarCreateCalendarEventsResponseEventsInner as CoreCalendarCreateCalendarEventsResponseEventsInner
    from poodle_async_full.models.core_calendar_delete_calendar_events_parameters_events_inner import CoreCalendarDeleteCalendarEventsParametersEventsInner as CoreCalendarDeleteCalendarEventsParametersEventsInner
    from poodle_async_full.models.core_calendar_delete_subscription_response import CoreCalendarDeleteSubscriptionResponse as CoreCalendarDeleteSubscriptionResponse
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response import CoreCalendarGetActionEventsByCourseResponse as CoreCalendarGetActionEventsByCourseResponse
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner import CoreCalendarGetActionEventsByCourseResponseEventsInner as CoreCalendarGetActionEventsByCourseResponseEventsInner
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_action import CoreCalendarGetActionEventsByCourseResponseEventsInnerAction as CoreCalendarGetActionEventsByCourseResponseEventsInnerAction
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_category import CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory as CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_icon import CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon as CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_subscription import CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription as CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription
    from poodle_async_full.models.core_calendar_get_action_events_by_courses_response import CoreCalendarGetActionEventsByCoursesResponse as CoreCalendarGetActionEventsByCoursesResponse
    from poodle_async_full.models.core_calendar_get_action_events_by_courses_response_groupedbycourse_inner import CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner as CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner
    from poodle_async_full.models.core_calendar_get_action_events_by_timesort_response import CoreCalendarGetActionEventsByTimesortResponse as CoreCalendarGetActionEventsByTimesortResponse
    from poodle_async_full.models.core_calendar_get_allowed_event_types_response import CoreCalendarGetAllowedEventTypesResponse as CoreCalendarGetAllowedEventTypesResponse
    from poodle_async_full.models.core_calendar_get_calendar_access_information_response import CoreCalendarGetCalendarAccessInformationResponse as CoreCalendarGetCalendarAccessInformationResponse
    from poodle_async_full.models.core_calendar_get_calendar_day_view_response import CoreCalendarGetCalendarDayViewResponse as CoreCalendarGetCalendarDayViewResponse
    from poodle_async_full.models.core_calendar_get_calendar_day_view_response_date import CoreCalendarGetCalendarDayViewResponseDate as CoreCalendarGetCalendarDayViewResponseDate
    from poodle_async_full.models.core_calendar_get_calendar_day_view_response_events_inner import CoreCalendarGetCalendarDayViewResponseEventsInner as CoreCalendarGetCalendarDayViewResponseEventsInner
    from poodle_async_full.models.core_calendar_get_calendar_event_by_id_response import CoreCalendarGetCalendarEventByIdResponse as CoreCalendarGetCalendarEventByIdResponse
    from poodle_async_full.models.core_calendar_get_calendar_events_parameters_events import CoreCalendarGetCalendarEventsParametersEvents as CoreCalendarGetCalendarEventsParametersEvents
    from poodle_async_full.models.core_calendar_get_calendar_events_parameters_options import CoreCalendarGetCalendarEventsParametersOptions as CoreCalendarGetCalendarEventsParametersOptions
    from poodle_async_full.models.core_calendar_get_calendar_events_response import CoreCalendarGetCalendarEventsResponse as CoreCalendarGetCalendarEventsResponse
    from poodle_async_full.models.core_calendar_get_calendar_events_response_events_inner import CoreCalendarGetCalendarEventsResponseEventsInner as CoreCalendarGetCalendarEventsResponseEventsInner
    from poodle_async_full.models.core_calendar_get_calendar_export_token_response import CoreCalendarGetCalendarExportTokenResponse as CoreCalendarGetCalendarExportTokenResponse
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response import CoreCalendarGetCalendarMonthlyViewResponse as CoreCalendarGetCalendarMonthlyViewResponse
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_daynames_inner import CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner as CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInner as CoreCalendarGetCalendarMonthlyViewResponseWeeksInner
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner_days_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner as CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner
    from poodle_async_full.models.core_calendar_get_calendar_upcoming_view_response import CoreCalendarGetCalendarUpcomingViewResponse as CoreCalendarGetCalendarUpcomingViewResponse
    from poodle_async_full.models.core_calendar_get_timestamps_parameters_data_inner import CoreCalendarGetTimestampsParametersDataInner as CoreCalendarGetTimestampsParametersDataInner
    from poodle_async_full.models.core_calendar_get_timestamps_response import CoreCalendarGetTimestampsResponse as CoreCalendarGetTimestampsResponse
    from poodle_async_full.models.core_calendar_get_timestamps_response_timestamps_inner import CoreCalendarGetTimestampsResponseTimestampsInner as CoreCalendarGetTimestampsResponseTimestampsInner
    from poodle_async_full.models.core_calendar_submit_create_update_form_response import CoreCalendarSubmitCreateUpdateFormResponse as CoreCalendarSubmitCreateUpdateFormResponse
    from poodle_async_full.models.core_calendar_update_event_start_day_response import CoreCalendarUpdateEventStartDayResponse as CoreCalendarUpdateEventStartDayResponse
    from poodle_async_full.models.core_change_editmode_response import CoreChangeEditmodeResponse as CoreChangeEditmodeResponse
    from poodle_async_full.models.core_check_get_result_admintree_response import CoreCheckGetResultAdmintreeResponse as CoreCheckGetResultAdmintreeResponse
    from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner import CoreCohortAddCohortMembersParametersMembersInner as CoreCohortAddCohortMembersParametersMembersInner
    from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_cohorttype import CoreCohortAddCohortMembersParametersMembersInnerCohorttype as CoreCohortAddCohortMembersParametersMembersInnerCohorttype
    from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_usertype import CoreCohortAddCohortMembersParametersMembersInnerUsertype as CoreCohortAddCohortMembersParametersMembersInnerUsertype
    from poodle_async_full.models.core_cohort_add_cohort_members_response import CoreCohortAddCohortMembersResponse as CoreCohortAddCohortMembersResponse
    from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner import CoreCohortCreateCohortsParametersCohortsInner as CoreCohortCreateCohortsParametersCohortsInner
    from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_categorytype import CoreCohortCreateCohortsParametersCohortsInnerCategorytype as CoreCohortCreateCohortsParametersCohortsInnerCategorytype
    from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_customfields_inner import CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner as CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner
    from poodle_async_full.models.core_cohort_create_cohorts_response_inner import CoreCohortCreateCohortsResponseInner as CoreCohortCreateCohortsResponseInner
    from poodle_async_full.models.core_cohort_delete_cohort_members_parameters_members_inner import CoreCohortDeleteCohortMembersParametersMembersInner as CoreCohortDeleteCohortMembersParametersMembersInner
    from poodle_async_full.models.core_cohort_get_cohort_members_response_inner import CoreCohortGetCohortMembersResponseInner as CoreCohortGetCohortMembersResponseInner
    from poodle_async_full.models.core_cohort_get_cohorts_response_inner import CoreCohortGetCohortsResponseInner as CoreCohortGetCohortsResponseInner
    from poodle_async_full.models.core_cohort_get_cohorts_response_inner_customfields_inner import CoreCohortGetCohortsResponseInnerCustomfieldsInner as CoreCohortGetCohortsResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_cohort_search_cohorts_parameters_context import CoreCohortSearchCohortsParametersContext as CoreCohortSearchCohortsParametersContext
    from poodle_async_full.models.core_cohort_search_cohorts_response import CoreCohortSearchCohortsResponse as CoreCohortSearchCohortsResponse
    from poodle_async_full.models.core_cohort_update_cohorts_parameters_cohorts_inner import CoreCohortUpdateCohortsParametersCohortsInner as CoreCohortUpdateCohortsParametersCohortsInner
    from poodle_async_full.models.core_comment_add_comments_parameters_comments_inner import CoreCommentAddCommentsParametersCommentsInner as CoreCommentAddCommentsParametersCommentsInner
    from poodle_async_full.models.core_comment_add_comments_response_inner import CoreCommentAddCommentsResponseInner as CoreCommentAddCommentsResponseInner
    from poodle_async_full.models.core_comment_get_comments_response import CoreCommentGetCommentsResponse as CoreCommentGetCommentsResponse
    from poodle_async_full.models.core_competency_count_competencies_parameters_filters_inner import CoreCompetencyCountCompetenciesParametersFiltersInner as CoreCompetencyCountCompetenciesParametersFiltersInner
    from poodle_async_full.models.core_competency_create_competency_framework_parameters_competencyframework import CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework as CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework
    from poodle_async_full.models.core_competency_create_competency_framework_response import CoreCompetencyCreateCompetencyFrameworkResponse as CoreCompetencyCreateCompetencyFrameworkResponse
    from poodle_async_full.models.core_competency_create_competency_parameters_competency import CoreCompetencyCreateCompetencyParametersCompetency as CoreCompetencyCreateCompetencyParametersCompetency
    from poodle_async_full.models.core_competency_create_competency_response import CoreCompetencyCreateCompetencyResponse as CoreCompetencyCreateCompetencyResponse
    from poodle_async_full.models.core_competency_create_plan_parameters_plan import CoreCompetencyCreatePlanParametersPlan as CoreCompetencyCreatePlanParametersPlan
    from poodle_async_full.models.core_competency_create_plan_response import CoreCompetencyCreatePlanResponse as CoreCompetencyCreatePlanResponse
    from poodle_async_full.models.core_competency_create_plan_response_commentarea import CoreCompetencyCreatePlanResponseCommentarea as CoreCompetencyCreatePlanResponseCommentarea
    from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer as CoreCompetencyCreatePlanResponseReviewer
    from poodle_async_full.models.core_competency_create_plan_response_template import CoreCompetencyCreatePlanResponseTemplate as CoreCompetencyCreatePlanResponseTemplate
    from poodle_async_full.models.core_competency_create_template_parameters_template import CoreCompetencyCreateTemplateParametersTemplate as CoreCompetencyCreateTemplateParametersTemplate
    from poodle_async_full.models.core_competency_create_template_response import CoreCompetencyCreateTemplateResponse as CoreCompetencyCreateTemplateResponse
    from poodle_async_full.models.core_competency_create_user_evidence_competency_response import CoreCompetencyCreateUserEvidenceCompetencyResponse as CoreCompetencyCreateUserEvidenceCompetencyResponse
    from poodle_async_full.models.core_competency_duplicate_competency_framework_response import CoreCompetencyDuplicateCompetencyFrameworkResponse as CoreCompetencyDuplicateCompetencyFrameworkResponse
    from poodle_async_full.models.core_competency_duplicate_template_response import CoreCompetencyDuplicateTemplateResponse as CoreCompetencyDuplicateTemplateResponse
    from poodle_async_full.models.core_competency_get_scale_values_response_inner import CoreCompetencyGetScaleValuesResponseInner as CoreCompetencyGetScaleValuesResponseInner
    from poodle_async_full.models.core_competency_grade_competency_in_course_response import CoreCompetencyGradeCompetencyInCourseResponse as CoreCompetencyGradeCompetencyInCourseResponse
    from poodle_async_full.models.core_competency_grade_competency_in_plan_response import CoreCompetencyGradeCompetencyInPlanResponse as CoreCompetencyGradeCompetencyInPlanResponse
    from poodle_async_full.models.core_competency_grade_competency_response import CoreCompetencyGradeCompetencyResponse as CoreCompetencyGradeCompetencyResponse
    from poodle_async_full.models.core_competency_list_competencies_in_template_response_inner import CoreCompetencyListCompetenciesInTemplateResponseInner as CoreCompetencyListCompetenciesInTemplateResponseInner
    from poodle_async_full.models.core_competency_list_competency_frameworks_response_inner import CoreCompetencyListCompetencyFrameworksResponseInner as CoreCompetencyListCompetencyFrameworksResponseInner
    from poodle_async_full.models.core_competency_list_course_competencies_response_inner import CoreCompetencyListCourseCompetenciesResponseInner as CoreCompetencyListCourseCompetenciesResponseInner
    from poodle_async_full.models.core_competency_list_course_competencies_response_inner_coursecompetency import CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency as CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency
    from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner import CoreCompetencyListCourseModuleCompetenciesResponseInner as CoreCompetencyListCourseModuleCompetenciesResponseInner
    from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner_coursemodulecompetency import CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency as CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency
    from poodle_async_full.models.core_competency_list_plan_competencies_response_inner import CoreCompetencyListPlanCompetenciesResponseInner as CoreCompetencyListPlanCompetenciesResponseInner
    from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetency import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency as CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency
    from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetencyplan import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan as CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan
    from poodle_async_full.models.core_competency_list_user_plans_response_inner import CoreCompetencyListUserPlansResponseInner as CoreCompetencyListUserPlansResponseInner
    from poodle_async_full.models.core_competency_read_competency_framework_response import CoreCompetencyReadCompetencyFrameworkResponse as CoreCompetencyReadCompetencyFrameworkResponse
    from poodle_async_full.models.core_competency_read_competency_response import CoreCompetencyReadCompetencyResponse as CoreCompetencyReadCompetencyResponse
    from poodle_async_full.models.core_competency_read_plan_response import CoreCompetencyReadPlanResponse as CoreCompetencyReadPlanResponse
    from poodle_async_full.models.core_competency_read_template_response import CoreCompetencyReadTemplateResponse as CoreCompetencyReadTemplateResponse
    from poodle_async_full.models.core_competency_read_user_evidence_response import CoreCompetencyReadUserEvidenceResponse as CoreCompetencyReadUserEvidenceResponse
    from poodle_async_full.models.core_competency_read_user_evidence_response_files_inner import CoreCompetencyReadUserEvidenceResponseFilesInner as CoreCompetencyReadUserEvidenceResponseFilesInner
    from poodle_async_full.models.core_competency_update_competency_framework_parameters_competencyframework import CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework as CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework
    from poodle_async_full.models.core_competency_update_competency_parameters_competency import CoreCompetencyUpdateCompetencyParametersCompetency as CoreCompetencyUpdateCompetencyParametersCompetency
    from poodle_async_full.models.core_competency_update_course_competency_settings_parameters_settings import CoreCompetencyUpdateCourseCompetencySettingsParametersSettings as CoreCompetencyUpdateCourseCompetencySettingsParametersSettings
    from poodle_async_full.models.core_competency_update_plan_parameters_plan import CoreCompetencyUpdatePlanParametersPlan as CoreCompetencyUpdatePlanParametersPlan
    from poodle_async_full.models.core_competency_update_plan_response import CoreCompetencyUpdatePlanResponse as CoreCompetencyUpdatePlanResponse
    from poodle_async_full.models.core_competency_update_template_parameters_template import CoreCompetencyUpdateTemplateParametersTemplate as CoreCompetencyUpdateTemplateParametersTemplate
    from poodle_async_full.models.core_completion_get_activities_completion_status_response import CoreCompletionGetActivitiesCompletionStatusResponse as CoreCompletionGetActivitiesCompletionStatusResponse
    from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner as CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner
    from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner as CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner
    from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner_rulevalue import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue as CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue
    from poodle_async_full.models.core_completion_get_course_completion_status_response import CoreCompletionGetCourseCompletionStatusResponse as CoreCompletionGetCourseCompletionStatusResponse
    from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus import CoreCompletionGetCourseCompletionStatusResponseCompletionstatus as CoreCompletionGetCourseCompletionStatusResponseCompletionstatus
    from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner as CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner
    from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner_details import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails as CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails
    from poodle_async_full.models.core_completion_mark_course_self_completed_response import CoreCompletionMarkCourseSelfCompletedResponse as CoreCompletionMarkCourseSelfCompletedResponse
    from poodle_async_full.models.core_completion_override_activity_completion_status_response import CoreCompletionOverrideActivityCompletionStatusResponse as CoreCompletionOverrideActivityCompletionStatusResponse
    from poodle_async_full.models.core_completion_update_activity_completion_status_manually_response import CoreCompletionUpdateActivityCompletionStatusManuallyResponse as CoreCompletionUpdateActivityCompletionStatusManuallyResponse
    from poodle_async_full.models.core_contentbank_copy_content_response import CoreContentbankCopyContentResponse as CoreContentbankCopyContentResponse
    from poodle_async_full.models.core_contentbank_delete_content_response import CoreContentbankDeleteContentResponse as CoreContentbankDeleteContentResponse
    from poodle_async_full.models.core_contentbank_rename_content_response import CoreContentbankRenameContentResponse as CoreContentbankRenameContentResponse
    from poodle_async_full.models.core_contentbank_set_content_visibility_response import CoreContentbankSetContentVisibilityResponse as CoreContentbankSetContentVisibilityResponse
    from poodle_async_full.models.core_course_add_content_item_to_user_favourites_response import CoreCourseAddContentItemToUserFavouritesResponse as CoreCourseAddContentItemToUserFavouritesResponse
    from poodle_async_full.models.core_course_check_updates_parameters_tocheck_inner import CoreCourseCheckUpdatesParametersTocheckInner as CoreCourseCheckUpdatesParametersTocheckInner
    from poodle_async_full.models.core_course_check_updates_response import CoreCourseCheckUpdatesResponse as CoreCourseCheckUpdatesResponse
    from poodle_async_full.models.core_course_check_updates_response_instances_inner import CoreCourseCheckUpdatesResponseInstancesInner as CoreCourseCheckUpdatesResponseInstancesInner
    from poodle_async_full.models.core_course_check_updates_response_instances_inner_updates_inner import CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner as CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner
    from poodle_async_full.models.core_course_create_categories_parameters_categories_inner import CoreCourseCreateCategoriesParametersCategoriesInner as CoreCourseCreateCategoriesParametersCategoriesInner
    from poodle_async_full.models.core_course_create_categories_response_inner import CoreCourseCreateCategoriesResponseInner as CoreCourseCreateCategoriesResponseInner
    from poodle_async_full.models.core_course_create_courses_parameters_courses_inner import CoreCourseCreateCoursesParametersCoursesInner as CoreCourseCreateCoursesParametersCoursesInner
    from poodle_async_full.models.core_course_create_courses_parameters_courses_inner_courseformatoptions_inner import CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner as CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner
    from poodle_async_full.models.core_course_create_courses_response_inner import CoreCourseCreateCoursesResponseInner as CoreCourseCreateCoursesResponseInner
    from poodle_async_full.models.core_course_delete_categories_parameters_categories_inner import CoreCourseDeleteCategoriesParametersCategoriesInner as CoreCourseDeleteCategoriesParametersCategoriesInner
    from poodle_async_full.models.core_course_delete_courses_response import CoreCourseDeleteCoursesResponse as CoreCourseDeleteCoursesResponse
    from poodle_async_full.models.core_course_duplicate_course_parameters_options_inner import CoreCourseDuplicateCourseParametersOptionsInner as CoreCourseDuplicateCourseParametersOptionsInner
    from poodle_async_full.models.core_course_duplicate_course_response import CoreCourseDuplicateCourseResponse as CoreCourseDuplicateCourseResponse
    from poodle_async_full.models.core_course_get_activity_chooser_footer_response import CoreCourseGetActivityChooserFooterResponse as CoreCourseGetActivityChooserFooterResponse
    from poodle_async_full.models.core_course_get_categories_parameters_criteria_inner import CoreCourseGetCategoriesParametersCriteriaInner as CoreCourseGetCategoriesParametersCriteriaInner
    from poodle_async_full.models.core_course_get_categories_response_inner import CoreCourseGetCategoriesResponseInner as CoreCourseGetCategoriesResponseInner
    from poodle_async_full.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner as CoreCourseGetContentsParametersOptionsInner
    from poodle_async_full.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner as CoreCourseGetContentsResponseInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner as CoreCourseGetContentsResponseInnerModulesInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge as CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata as CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo as CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner as CoreCourseGetContentsResponseInnerModulesInnerDatesInner
    from poodle_async_full.models.core_course_get_course_content_items_response import CoreCourseGetCourseContentItemsResponse as CoreCourseGetCourseContentItemsResponse
    from poodle_async_full.models.core_course_get_course_content_items_response_content_items_inner import CoreCourseGetCourseContentItemsResponseContentItemsInner as CoreCourseGetCourseContentItemsResponseContentItemsInner
    from poodle_async_full.models.core_course_get_course_module_by_instance_response import CoreCourseGetCourseModuleByInstanceResponse as CoreCourseGetCourseModuleByInstanceResponse
    from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm import CoreCourseGetCourseModuleByInstanceResponseCm as CoreCourseGetCourseModuleByInstanceResponseCm
    from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_advancedgrading_inner import CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner as CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner
    from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_outcomes_inner import CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner as CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner
    from poodle_async_full.models.core_course_get_course_module_response import CoreCourseGetCourseModuleResponse as CoreCourseGetCourseModuleResponse
    from poodle_async_full.models.core_course_get_courses_by_field_response import CoreCourseGetCoursesByFieldResponse as CoreCourseGetCoursesByFieldResponse
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner import CoreCourseGetCoursesByFieldResponseCoursesInner as CoreCourseGetCoursesByFieldResponseCoursesInner
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_contacts_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner as CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_courseformatoptions_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner as CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_filters_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner as CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner
    from poodle_async_full.models.core_course_get_courses_parameters_options import CoreCourseGetCoursesParametersOptions as CoreCourseGetCoursesParametersOptions
    from poodle_async_full.models.core_course_get_courses_response_inner import CoreCourseGetCoursesResponseInner as CoreCourseGetCoursesResponseInner
    from poodle_async_full.models.core_course_get_courses_response_inner_customfields_inner import CoreCourseGetCoursesResponseInnerCustomfieldsInner as CoreCourseGetCoursesResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_course_get_enrolled_courses_by_timeline_classification_response import CoreCourseGetEnrolledCoursesByTimelineClassificationResponse as CoreCourseGetEnrolledCoursesByTimelineClassificationResponse
    from poodle_async_full.models.core_course_get_enrolled_courses_with_action_events_by_timeline_classification_response import CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse as CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse
    from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response import CoreCourseGetEnrolledUsersByCmidResponse as CoreCourseGetEnrolledUsersByCmidResponse
    from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response_users_inner import CoreCourseGetEnrolledUsersByCmidResponseUsersInner as CoreCourseGetEnrolledUsersByCmidResponseUsersInner
    from poodle_async_full.models.core_course_get_updates_since_response import CoreCourseGetUpdatesSinceResponse as CoreCourseGetUpdatesSinceResponse
    from poodle_async_full.models.core_course_get_user_administration_options_response import CoreCourseGetUserAdministrationOptionsResponse as CoreCourseGetUserAdministrationOptionsResponse
    from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInner as CoreCourseGetUserAdministrationOptionsResponseCoursesInner
    from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner_options_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner as CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner
    from poodle_async_full.models.core_course_get_user_navigation_options_response import CoreCourseGetUserNavigationOptionsResponse as CoreCourseGetUserNavigationOptionsResponse
    from poodle_async_full.models.core_course_import_course_parameters_options_inner import CoreCourseImportCourseParametersOptionsInner as CoreCourseImportCourseParametersOptionsInner
    from poodle_async_full.models.core_course_remove_content_item_from_user_favourites_response import CoreCourseRemoveContentItemFromUserFavouritesResponse as CoreCourseRemoveContentItemFromUserFavouritesResponse
    from poodle_async_full.models.core_course_search_courses_response import CoreCourseSearchCoursesResponse as CoreCourseSearchCoursesResponse
    from poodle_async_full.models.core_course_search_courses_response_courses_inner import CoreCourseSearchCoursesResponseCoursesInner as CoreCourseSearchCoursesResponseCoursesInner
    from poodle_async_full.models.core_course_set_favourite_courses_parameters_courses_inner import CoreCourseSetFavouriteCoursesParametersCoursesInner as CoreCourseSetFavouriteCoursesParametersCoursesInner
    from poodle_async_full.models.core_course_set_favourite_courses_response import CoreCourseSetFavouriteCoursesResponse as CoreCourseSetFavouriteCoursesResponse
    from poodle_async_full.models.core_course_toggle_activity_recommendation_response import CoreCourseToggleActivityRecommendationResponse as CoreCourseToggleActivityRecommendationResponse
    from poodle_async_full.models.core_course_update_categories_parameters_categories_inner import CoreCourseUpdateCategoriesParametersCategoriesInner as CoreCourseUpdateCategoriesParametersCategoriesInner
    from poodle_async_full.models.core_course_update_courses_parameters_courses_inner import CoreCourseUpdateCoursesParametersCoursesInner as CoreCourseUpdateCoursesParametersCoursesInner
    from poodle_async_full.models.core_course_update_courses_response import CoreCourseUpdateCoursesResponse as CoreCourseUpdateCoursesResponse
    from poodle_async_full.models.core_course_view_course_response import CoreCourseViewCourseResponse as CoreCourseViewCourseResponse
    from poodle_async_full.models.core_courseformat_file_handlers_response_inner import CoreCourseformatFileHandlersResponseInner as CoreCourseformatFileHandlersResponseInner
    from poodle_async_full.models.core_customfield_reload_template_response import CoreCustomfieldReloadTemplateResponse as CoreCustomfieldReloadTemplateResponse
    from poodle_async_full.models.core_customfield_reload_template_response_categories_inner import CoreCustomfieldReloadTemplateResponseCategoriesInner as CoreCustomfieldReloadTemplateResponseCategoriesInner
    from poodle_async_full.models.core_customfield_reload_template_response_categories_inner_fields_inner import CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner as CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner
    from poodle_async_full.models.core_dynamic_tabs_get_content_response import CoreDynamicTabsGetContentResponse as CoreDynamicTabsGetContentResponse
    from poodle_async_full.models.core_enrol_get_course_enrolment_methods_response_inner import CoreEnrolGetCourseEnrolmentMethodsResponseInner as CoreEnrolGetCourseEnrolmentMethodsResponseInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_parameters_options_inner import CoreEnrolGetEnrolledUsersParametersOptionsInner as CoreEnrolGetEnrolledUsersParametersOptionsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner import CoreEnrolGetEnrolledUsersResponseInner as CoreEnrolGetEnrolledUsersResponseInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_customfields_inner import CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner as CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_enrolledcourses_inner import CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner as CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_groups_inner import CoreEnrolGetEnrolledUsersResponseInnerGroupsInner as CoreEnrolGetEnrolledUsersResponseInnerGroupsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_preferences_inner import CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner as CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_roles_inner import CoreEnrolGetEnrolledUsersResponseInnerRolesInner as CoreEnrolGetEnrolledUsersResponseInnerRolesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_parameters_coursecapabilities_inner import CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner as CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_customfields_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_groups_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner
    from poodle_async_full.models.core_enrol_get_potential_users_response_inner import CoreEnrolGetPotentialUsersResponseInner as CoreEnrolGetPotentialUsersResponseInner
    from poodle_async_full.models.core_enrol_get_potential_users_response_inner_customfields_inner import CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner as CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_enrol_get_potential_users_response_inner_preferences_inner import CoreEnrolGetPotentialUsersResponseInnerPreferencesInner as CoreEnrolGetPotentialUsersResponseInnerPreferencesInner
    from poodle_async_full.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner as CoreEnrolGetUsersCoursesResponseInner
    from poodle_async_full.models.core_enrol_submit_user_enrolment_form_response import CoreEnrolSubmitUserEnrolmentFormResponse as CoreEnrolSubmitUserEnrolmentFormResponse
    from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response import CoreEnrolUnenrolUserEnrolmentResponse as CoreEnrolUnenrolUserEnrolmentResponse
    from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response_errors_inner import CoreEnrolUnenrolUserEnrolmentResponseErrorsInner as CoreEnrolUnenrolUserEnrolmentResponseErrorsInner
    from poodle_async_full.models.core_fetch_notifications_parameters import CoreFetchNotificationsParameters as CoreFetchNotificationsParameters
    from poodle_async_full.models.core_fetch_notifications_response_inner import CoreFetchNotificationsResponseInner as CoreFetchNotificationsResponseInner
    from poodle_async_full.models.core_fetch_notifications_response_inner_variables import CoreFetchNotificationsResponseInnerVariables as CoreFetchNotificationsResponseInnerVariables
    from poodle_async_full.models.core_files_delete_draft_files_parameters_files_inner import CoreFilesDeleteDraftFilesParametersFilesInner as CoreFilesDeleteDraftFilesParametersFilesInner
    from poodle_async_full.models.core_files_delete_draft_files_response import CoreFilesDeleteDraftFilesResponse as CoreFilesDeleteDraftFilesResponse
    from poodle_async_full.models.core_files_get_files_response import CoreFilesGetFilesResponse as CoreFilesGetFilesResponse
    from poodle_async_full.models.core_files_get_files_response_files_inner import CoreFilesGetFilesResponseFilesInner as CoreFilesGetFilesResponseFilesInner
    from poodle_async_full.models.core_files_get_files_response_parents_inner import CoreFilesGetFilesResponseParentsInner as CoreFilesGetFilesResponseParentsInner
    from poodle_async_full.models.core_files_get_unused_draft_itemid_response import CoreFilesGetUnusedDraftItemidResponse as CoreFilesGetUnusedDraftItemidResponse
    from poodle_async_full.models.core_files_upload_response import CoreFilesUploadResponse as CoreFilesUploadResponse
    from poodle_async_full.models.core_filters_get_all_states_response import CoreFiltersGetAllStatesResponse as CoreFiltersGetAllStatesResponse
    from poodle_async_full.models.core_filters_get_all_states_response_filters_inner import CoreFiltersGetAllStatesResponseFiltersInner as CoreFiltersGetAllStatesResponseFiltersInner
    from poodle_async_full.models.core_filters_get_available_in_context_parameters_contexts_inner import CoreFiltersGetAvailableInContextParametersContextsInner as CoreFiltersGetAvailableInContextParametersContextsInner
    from poodle_async_full.models.core_filters_get_available_in_context_response import CoreFiltersGetAvailableInContextResponse as CoreFiltersGetAvailableInContextResponse
    from poodle_async_full.models.core_filters_get_available_in_context_response_filters_inner import CoreFiltersGetAvailableInContextResponseFiltersInner as CoreFiltersGetAvailableInContextResponseFiltersInner
    from poodle_async_full.models.core_form_dynamic_form_response import CoreFormDynamicFormResponse as CoreFormDynamicFormResponse
    from poodle_async_full.models.core_form_get_filetypes_browser_data_parameters import CoreFormGetFiletypesBrowserDataParameters as CoreFormGetFiletypesBrowserDataParameters
    from poodle_async_full.models.core_form_get_filetypes_browser_data_response import CoreFormGetFiletypesBrowserDataResponse as CoreFormGetFiletypesBrowserDataResponse
    from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInner as CoreFormGetFiletypesBrowserDataResponseGroupsInner
    from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner_types_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner as CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner
    from poodle_async_full.models.core_get_component_strings_parameters import CoreGetComponentStringsParameters as CoreGetComponentStringsParameters
    from poodle_async_full.models.core_get_component_strings_response_inner import CoreGetComponentStringsResponseInner as CoreGetComponentStringsResponseInner
    from poodle_async_full.models.core_get_fragment_parameters_args_inner import CoreGetFragmentParametersArgsInner as CoreGetFragmentParametersArgsInner
    from poodle_async_full.models.core_get_fragment_response import CoreGetFragmentResponse as CoreGetFragmentResponse
    from poodle_async_full.models.core_get_string_parameters import CoreGetStringParameters as CoreGetStringParameters
    from poodle_async_full.models.core_get_string_parameters_stringparams_inner import CoreGetStringParametersStringparamsInner as CoreGetStringParametersStringparamsInner
    from poodle_async_full.models.core_get_strings_parameters import CoreGetStringsParameters as CoreGetStringsParameters
    from poodle_async_full.models.core_get_strings_parameters_strings_inner import CoreGetStringsParametersStringsInner as CoreGetStringsParametersStringsInner
    from poodle_async_full.models.core_get_strings_parameters_strings_inner_stringparams_inner import CoreGetStringsParametersStringsInnerStringparamsInner as CoreGetStringsParametersStringsInnerStringparamsInner
    from poodle_async_full.models.core_get_strings_response_inner import CoreGetStringsResponseInner as CoreGetStringsResponseInner
    from poodle_async_full.models.core_get_user_dates_parameters_timestamps_inner import CoreGetUserDatesParametersTimestampsInner as CoreGetUserDatesParametersTimestampsInner
    from poodle_async_full.models.core_get_user_dates_response import CoreGetUserDatesResponse as CoreGetUserDatesResponse
    from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner import CoreGradesCreateGradecategoriesParametersCategoriesInner as CoreGradesCreateGradecategoriesParametersCategoriesInner
    from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner_options import CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions as CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions
    from poodle_async_full.models.core_grades_create_gradecategories_response import CoreGradesCreateGradecategoriesResponse as CoreGradesCreateGradecategoriesResponse
    from poodle_async_full.models.core_grades_get_enrolled_users_for_selector_response import CoreGradesGetEnrolledUsersForSelectorResponse as CoreGradesGetEnrolledUsersForSelectorResponse
    from poodle_async_full.models.core_grades_get_feedback_response import CoreGradesGetFeedbackResponse as CoreGradesGetFeedbackResponse
    from poodle_async_full.models.core_grades_get_gradable_users_response import CoreGradesGetGradableUsersResponse as CoreGradesGetGradableUsersResponse
    from poodle_async_full.models.core_grades_get_gradeitems_response import CoreGradesGetGradeitemsResponse as CoreGradesGetGradeitemsResponse
    from poodle_async_full.models.core_grades_get_gradeitems_response_grade_items_inner import CoreGradesGetGradeitemsResponseGradeItemsInner as CoreGradesGetGradeitemsResponseGradeItemsInner
    from poodle_async_full.models.core_grades_get_groups_for_selector_response import CoreGradesGetGroupsForSelectorResponse as CoreGradesGetGroupsForSelectorResponse
    from poodle_async_full.models.core_grades_get_groups_for_selector_response_groups_inner import CoreGradesGetGroupsForSelectorResponseGroupsInner as CoreGradesGetGroupsForSelectorResponseGroupsInner
    from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response import CoreGradesGraderGradingpanelPointFetchResponse as CoreGradesGraderGradingpanelPointFetchResponse
    from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response_grade import CoreGradesGraderGradingpanelPointFetchResponseGrade as CoreGradesGraderGradingpanelPointFetchResponseGrade
    from poodle_async_full.models.core_grades_grader_gradingpanel_point_store_response import CoreGradesGraderGradingpanelPointStoreResponse as CoreGradesGraderGradingpanelPointStoreResponse
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response import CoreGradesGraderGradingpanelScaleFetchResponse as CoreGradesGraderGradingpanelScaleFetchResponse
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade import CoreGradesGraderGradingpanelScaleFetchResponseGrade as CoreGradesGraderGradingpanelScaleFetchResponseGrade
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade_options_inner import CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner as CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_store_response import CoreGradesGraderGradingpanelScaleStoreResponse as CoreGradesGraderGradingpanelScaleStoreResponse
    from poodle_async_full.models.core_grades_update_grades_parameters_grades_inner import CoreGradesUpdateGradesParametersGradesInner as CoreGradesUpdateGradesParametersGradesInner
    from poodle_async_full.models.core_grades_update_grades_parameters_itemdetails import CoreGradesUpdateGradesParametersItemdetails as CoreGradesUpdateGradesParametersItemdetails
    from poodle_async_full.models.core_grading_get_definitions_response import CoreGradingGetDefinitionsResponse as CoreGradingGetDefinitionsResponse
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner import CoreGradingGetDefinitionsResponseAreasInner as CoreGradingGetDefinitionsResponseAreasInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_comments_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner_levels_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner
    from poodle_async_full.models.core_grading_get_gradingform_instances_response import CoreGradingGetGradingformInstancesResponse as CoreGradingGetGradingformInstancesResponse
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner import CoreGradingGetGradingformInstancesResponseInstancesInner as CoreGradingGetGradingformInstancesResponseInstancesInner
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide import CoreGradingGetGradingformInstancesResponseInstancesInnerGuide as CoreGradingGetGradingformInstancesResponseInstancesInnerGuide
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner as CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric import CoreGradingGetGradingformInstancesResponseInstancesInnerRubric as CoreGradingGetGradingformInstancesResponseInstancesInnerRubric
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner as CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner
    from poodle_async_full.models.core_group_add_group_members_parameters_members_inner import CoreGroupAddGroupMembersParametersMembersInner as CoreGroupAddGroupMembersParametersMembersInner
    from poodle_async_full.models.core_group_assign_grouping_parameters_assignments_inner import CoreGroupAssignGroupingParametersAssignmentsInner as CoreGroupAssignGroupingParametersAssignmentsInner
    from poodle_async_full.models.core_group_create_groupings_parameters_groupings_inner import CoreGroupCreateGroupingsParametersGroupingsInner as CoreGroupCreateGroupingsParametersGroupingsInner
    from poodle_async_full.models.core_group_create_groupings_response_inner import CoreGroupCreateGroupingsResponseInner as CoreGroupCreateGroupingsResponseInner
    from poodle_async_full.models.core_group_create_groups_parameters_groups_inner import CoreGroupCreateGroupsParametersGroupsInner as CoreGroupCreateGroupsParametersGroupsInner
    from poodle_async_full.models.core_group_create_groups_response_inner import CoreGroupCreateGroupsResponseInner as CoreGroupCreateGroupsResponseInner
    from poodle_async_full.models.core_group_get_activity_allowed_groups_response import CoreGroupGetActivityAllowedGroupsResponse as CoreGroupGetActivityAllowedGroupsResponse
    from poodle_async_full.models.core_group_get_activity_allowed_groups_response_groups_inner import CoreGroupGetActivityAllowedGroupsResponseGroupsInner as CoreGroupGetActivityAllowedGroupsResponseGroupsInner
    from poodle_async_full.models.core_group_get_activity_groupmode_response import CoreGroupGetActivityGroupmodeResponse as CoreGroupGetActivityGroupmodeResponse
    from poodle_async_full.models.core_group_get_course_groupings_response_inner import CoreGroupGetCourseGroupingsResponseInner as CoreGroupGetCourseGroupingsResponseInner
    from poodle_async_full.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner as CoreGroupGetCourseGroupsResponseInner
    from poodle_async_full.models.core_group_get_course_user_groups_response import CoreGroupGetCourseUserGroupsResponse as CoreGroupGetCourseUserGroupsResponse
    from poodle_async_full.models.core_group_get_group_members_response_inner import CoreGroupGetGroupMembersResponseInner as CoreGroupGetGroupMembersResponseInner
    from poodle_async_full.models.core_group_get_groupings_response_inner import CoreGroupGetGroupingsResponseInner as CoreGroupGetGroupingsResponseInner
    from poodle_async_full.models.core_group_get_groupings_response_inner_groups_inner import CoreGroupGetGroupingsResponseInnerGroupsInner as CoreGroupGetGroupingsResponseInnerGroupsInner
    from poodle_async_full.models.core_group_get_groups_for_selector_response import CoreGroupGetGroupsForSelectorResponse as CoreGroupGetGroupsForSelectorResponse
    from poodle_async_full.models.core_group_get_groups_response_inner import CoreGroupGetGroupsResponseInner as CoreGroupGetGroupsResponseInner
    from poodle_async_full.models.core_group_update_groupings_parameters_groupings_inner import CoreGroupUpdateGroupingsParametersGroupingsInner as CoreGroupUpdateGroupingsParametersGroupingsInner
    from poodle_async_full.models.core_group_update_groups_parameters_groups_inner import CoreGroupUpdateGroupsParametersGroupsInner as CoreGroupUpdateGroupsParametersGroupsInner
    from poodle_async_full.models.core_h5p_get_trusted_h5p_file_response import CoreH5pGetTrustedH5pFileResponse as CoreH5pGetTrustedH5pFileResponse
    from poodle_async_full.models.core_message_create_contact_request_response import CoreMessageCreateContactRequestResponse as CoreMessageCreateContactRequestResponse
    from poodle_async_full.models.core_message_create_contact_request_response_request import CoreMessageCreateContactRequestResponseRequest as CoreMessageCreateContactRequestResponseRequest
    from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response import CoreMessageDataForMessageareaSearchMessagesResponse as CoreMessageDataForMessageareaSearchMessagesResponse
    from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response_contacts_inner import CoreMessageDataForMessageareaSearchMessagesResponseContactsInner as CoreMessageDataForMessageareaSearchMessagesResponseContactsInner
    from poodle_async_full.models.core_message_delete_message_response import CoreMessageDeleteMessageResponse as CoreMessageDeleteMessageResponse
    from poodle_async_full.models.core_message_get_blocked_users_response import CoreMessageGetBlockedUsersResponse as CoreMessageGetBlockedUsersResponse
    from poodle_async_full.models.core_message_get_blocked_users_response_users_inner import CoreMessageGetBlockedUsersResponseUsersInner as CoreMessageGetBlockedUsersResponseUsersInner
    from poodle_async_full.models.core_message_get_contact_requests_response_inner import CoreMessageGetContactRequestsResponseInner as CoreMessageGetContactRequestsResponseInner
    from poodle_async_full.models.core_message_get_contact_requests_response_inner_contactrequests_inner import CoreMessageGetContactRequestsResponseInnerContactrequestsInner as CoreMessageGetContactRequestsResponseInnerContactrequestsInner
    from poodle_async_full.models.core_message_get_contact_requests_response_inner_conversations_inner import CoreMessageGetContactRequestsResponseInnerConversationsInner as CoreMessageGetContactRequestsResponseInnerConversationsInner
    from poodle_async_full.models.core_message_get_conversation_between_users_response import CoreMessageGetConversationBetweenUsersResponse as CoreMessageGetConversationBetweenUsersResponse
    from poodle_async_full.models.core_message_get_conversation_between_users_response_messages_inner import CoreMessageGetConversationBetweenUsersResponseMessagesInner as CoreMessageGetConversationBetweenUsersResponseMessagesInner
    from poodle_async_full.models.core_message_get_conversation_counts_response import CoreMessageGetConversationCountsResponse as CoreMessageGetConversationCountsResponse
    from poodle_async_full.models.core_message_get_conversation_counts_response_types import CoreMessageGetConversationCountsResponseTypes as CoreMessageGetConversationCountsResponseTypes
    from poodle_async_full.models.core_message_get_conversation_messages_response import CoreMessageGetConversationMessagesResponse as CoreMessageGetConversationMessagesResponse
    from poodle_async_full.models.core_message_get_conversation_response import CoreMessageGetConversationResponse as CoreMessageGetConversationResponse
    from poodle_async_full.models.core_message_get_conversations_response import CoreMessageGetConversationsResponse as CoreMessageGetConversationsResponse
    from poodle_async_full.models.core_message_get_conversations_response_conversations_inner import CoreMessageGetConversationsResponseConversationsInner as CoreMessageGetConversationsResponseConversationsInner
    from poodle_async_full.models.core_message_get_message_processor_response import CoreMessageGetMessageProcessorResponse as CoreMessageGetMessageProcessorResponse
    from poodle_async_full.models.core_message_get_messages_response import CoreMessageGetMessagesResponse as CoreMessageGetMessagesResponse
    from poodle_async_full.models.core_message_get_messages_response_messages_inner import CoreMessageGetMessagesResponseMessagesInner as CoreMessageGetMessagesResponseMessagesInner
    from poodle_async_full.models.core_message_get_self_conversation_response import CoreMessageGetSelfConversationResponse as CoreMessageGetSelfConversationResponse
    from poodle_async_full.models.core_message_get_unread_conversation_counts_response import CoreMessageGetUnreadConversationCountsResponse as CoreMessageGetUnreadConversationCountsResponse
    from poodle_async_full.models.core_message_get_unread_conversation_counts_response_types import CoreMessageGetUnreadConversationCountsResponseTypes as CoreMessageGetUnreadConversationCountsResponseTypes
    from poodle_async_full.models.core_message_get_unsent_message_response import CoreMessageGetUnsentMessageResponse as CoreMessageGetUnsentMessageResponse
    from poodle_async_full.models.core_message_get_user_message_preferences_response import CoreMessageGetUserMessagePreferencesResponse as CoreMessageGetUserMessagePreferencesResponse
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences import CoreMessageGetUserMessagePreferencesResponsePreferences as CoreMessageGetUserMessagePreferencesResponsePreferences
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner
    from poodle_async_full.models.core_message_get_user_notification_preferences_response import CoreMessageGetUserNotificationPreferencesResponse as CoreMessageGetUserNotificationPreferencesResponse
    from poodle_async_full.models.core_message_mark_message_read_response import CoreMessageMarkMessageReadResponse as CoreMessageMarkMessageReadResponse
    from poodle_async_full.models.core_message_mark_notification_read_response import CoreMessageMarkNotificationReadResponse as CoreMessageMarkNotificationReadResponse
    from poodle_async_full.models.core_message_message_processor_config_form_parameters_formvalues_inner import CoreMessageMessageProcessorConfigFormParametersFormvaluesInner as CoreMessageMessageProcessorConfigFormParametersFormvaluesInner
    from poodle_async_full.models.core_message_message_search_users_response import CoreMessageMessageSearchUsersResponse as CoreMessageMessageSearchUsersResponse
    from poodle_async_full.models.core_message_search_contacts_response_inner import CoreMessageSearchContactsResponseInner as CoreMessageSearchContactsResponseInner
    from poodle_async_full.models.core_message_send_instant_messages_parameters_messages_inner import CoreMessageSendInstantMessagesParametersMessagesInner as CoreMessageSendInstantMessagesParametersMessagesInner
    from poodle_async_full.models.core_message_send_instant_messages_response_inner import CoreMessageSendInstantMessagesResponseInner as CoreMessageSendInstantMessagesResponseInner
    from poodle_async_full.models.core_message_send_messages_to_conversation_parameters_messages_inner import CoreMessageSendMessagesToConversationParametersMessagesInner as CoreMessageSendMessagesToConversationParametersMessagesInner
    from poodle_async_full.models.core_message_set_default_notification_response import CoreMessageSetDefaultNotificationResponse as CoreMessageSetDefaultNotificationResponse
    from poodle_async_full.models.core_moodlenet_auth_check_response import CoreMoodlenetAuthCheckResponse as CoreMoodlenetAuthCheckResponse
    from poodle_async_full.models.core_moodlenet_get_share_info_activity_response import CoreMoodlenetGetShareInfoActivityResponse as CoreMoodlenetGetShareInfoActivityResponse
    from poodle_async_full.models.core_moodlenet_get_shared_course_info_response import CoreMoodlenetGetSharedCourseInfoResponse as CoreMoodlenetGetSharedCourseInfoResponse
    from poodle_async_full.models.core_moodlenet_send_activity_response import CoreMoodlenetSendActivityResponse as CoreMoodlenetSendActivityResponse
    from poodle_async_full.models.core_moodlenet_send_course_response import CoreMoodlenetSendCourseResponse as CoreMoodlenetSendCourseResponse
    from poodle_async_full.models.core_my_view_page_response import CoreMyViewPageResponse as CoreMyViewPageResponse
    from poodle_async_full.models.core_notes_create_notes_parameters_notes_inner import CoreNotesCreateNotesParametersNotesInner as CoreNotesCreateNotesParametersNotesInner
    from poodle_async_full.models.core_notes_create_notes_response_inner import CoreNotesCreateNotesResponseInner as CoreNotesCreateNotesResponseInner
    from poodle_async_full.models.core_notes_delete_notes_response_inner import CoreNotesDeleteNotesResponseInner as CoreNotesDeleteNotesResponseInner
    from poodle_async_full.models.core_notes_get_course_notes_response import CoreNotesGetCourseNotesResponse as CoreNotesGetCourseNotesResponse
    from poodle_async_full.models.core_notes_get_course_notes_response_coursenotes_inner import CoreNotesGetCourseNotesResponseCoursenotesInner as CoreNotesGetCourseNotesResponseCoursenotesInner
    from poodle_async_full.models.core_notes_get_notes_response import CoreNotesGetNotesResponse as CoreNotesGetNotesResponse
    from poodle_async_full.models.core_notes_get_notes_response_notes_inner import CoreNotesGetNotesResponseNotesInner as CoreNotesGetNotesResponseNotesInner
    from poodle_async_full.models.core_notes_update_notes_parameters_notes_inner import CoreNotesUpdateNotesParametersNotesInner as CoreNotesUpdateNotesParametersNotesInner
    from poodle_async_full.models.core_notes_view_notes_response import CoreNotesViewNotesResponse as CoreNotesViewNotesResponse
    from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_parameters import CoreOutputLoadFontawesomeIconSystemMapParameters as CoreOutputLoadFontawesomeIconSystemMapParameters
    from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_response_inner import CoreOutputLoadFontawesomeIconSystemMapResponseInner as CoreOutputLoadFontawesomeIconSystemMapResponseInner
    from poodle_async_full.models.core_output_load_template_parameters import CoreOutputLoadTemplateParameters as CoreOutputLoadTemplateParameters
    from poodle_async_full.models.core_output_load_template_with_dependencies_parameters import CoreOutputLoadTemplateWithDependenciesParameters as CoreOutputLoadTemplateWithDependenciesParameters
    from poodle_async_full.models.core_output_load_template_with_dependencies_response import CoreOutputLoadTemplateWithDependenciesResponse as CoreOutputLoadTemplateWithDependenciesResponse
    from poodle_async_full.models.core_output_load_template_with_dependencies_response_strings_inner import CoreOutputLoadTemplateWithDependenciesResponseStringsInner as CoreOutputLoadTemplateWithDependenciesResponseStringsInner
    from poodle_async_full.models.core_output_poll_stored_progress_response_inner import CoreOutputPollStoredProgressResponseInner as CoreOutputPollStoredProgressResponseInner
    from poodle_async_full.models.core_payment_get_available_gateways_response_inner import CorePaymentGetAvailableGatewaysResponseInner as CorePaymentGetAvailableGatewaysResponseInner
    from poodle_async_full.models.core_question_get_random_question_summaries_response import CoreQuestionGetRandomQuestionSummariesResponse as CoreQuestionGetRandomQuestionSummariesResponse
    from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner as CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner
    from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner_icon import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon as CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon
    from poodle_async_full.models.core_question_search_shared_banks_response import CoreQuestionSearchSharedBanksResponse as CoreQuestionSearchSharedBanksResponse
    from poodle_async_full.models.core_question_search_shared_banks_response_sharedbanks_inner import CoreQuestionSearchSharedBanksResponseSharedbanksInner as CoreQuestionSearchSharedBanksResponseSharedbanksInner
    from poodle_async_full.models.core_question_update_flag_response import CoreQuestionUpdateFlagResponse as CoreQuestionUpdateFlagResponse
    from poodle_async_full.models.core_rating_add_rating_response import CoreRatingAddRatingResponse as CoreRatingAddRatingResponse
    from poodle_async_full.models.core_rating_get_item_ratings_response import CoreRatingGetItemRatingsResponse as CoreRatingGetItemRatingsResponse
    from poodle_async_full.models.core_rating_get_item_ratings_response_ratings_inner import CoreRatingGetItemRatingsResponseRatingsInner as CoreRatingGetItemRatingsResponseRatingsInner
    from poodle_async_full.models.core_reportbuilder_can_view_system_report_parameters_parameters_inner import CoreReportbuilderCanViewSystemReportParametersParametersInner as CoreReportbuilderCanViewSystemReportParametersParametersInner
    from poodle_async_full.models.core_reportbuilder_columns_add_response import CoreReportbuilderColumnsAddResponse as CoreReportbuilderColumnsAddResponse
    from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner import CoreReportbuilderColumnsAddResponseSortablecolumnsInner as CoreReportbuilderColumnsAddResponseSortablecolumnsInner
    from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner_sorticon import CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon as CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon
    from poodle_async_full.models.core_reportbuilder_columns_delete_response import CoreReportbuilderColumnsDeleteResponse as CoreReportbuilderColumnsDeleteResponse
    from poodle_async_full.models.core_reportbuilder_columns_sort_get_response import CoreReportbuilderColumnsSortGetResponse as CoreReportbuilderColumnsSortGetResponse
    from poodle_async_full.models.core_reportbuilder_columns_sort_reorder_response import CoreReportbuilderColumnsSortReorderResponse as CoreReportbuilderColumnsSortReorderResponse
    from poodle_async_full.models.core_reportbuilder_columns_sort_toggle_response import CoreReportbuilderColumnsSortToggleResponse as CoreReportbuilderColumnsSortToggleResponse
    from poodle_async_full.models.core_reportbuilder_conditions_add_response import CoreReportbuilderConditionsAddResponse as CoreReportbuilderConditionsAddResponse
    from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInner as CoreReportbuilderConditionsAddResponseAvailableconditionsInner
    from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup as CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup
    from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup_values_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner as CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner
    from poodle_async_full.models.core_reportbuilder_conditions_delete_response import CoreReportbuilderConditionsDeleteResponse as CoreReportbuilderConditionsDeleteResponse
    from poodle_async_full.models.core_reportbuilder_conditions_reorder_response import CoreReportbuilderConditionsReorderResponse as CoreReportbuilderConditionsReorderResponse
    from poodle_async_full.models.core_reportbuilder_conditions_reset_response import CoreReportbuilderConditionsResetResponse as CoreReportbuilderConditionsResetResponse
    from poodle_async_full.models.core_reportbuilder_filters_add_response import CoreReportbuilderFiltersAddResponse as CoreReportbuilderFiltersAddResponse
    from poodle_async_full.models.core_reportbuilder_filters_add_response_activefilters_inner import CoreReportbuilderFiltersAddResponseActivefiltersInner as CoreReportbuilderFiltersAddResponseActivefiltersInner
    from poodle_async_full.models.core_reportbuilder_filters_delete_response import CoreReportbuilderFiltersDeleteResponse as CoreReportbuilderFiltersDeleteResponse
    from poodle_async_full.models.core_reportbuilder_filters_reorder_response import CoreReportbuilderFiltersReorderResponse as CoreReportbuilderFiltersReorderResponse
    from poodle_async_full.models.core_reportbuilder_list_reports_response import CoreReportbuilderListReportsResponse as CoreReportbuilderListReportsResponse
    from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner import CoreReportbuilderListReportsResponseReportsInner as CoreReportbuilderListReportsResponseReportsInner
    from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields import CoreReportbuilderListReportsResponseReportsInnerCustomfields as CoreReportbuilderListReportsResponseReportsInnerCustomfields
    from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields_data_inner import CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner as CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response import CoreReportbuilderReportsGetResponse as CoreReportbuilderReportsGetResponse
    from poodle_async_full.models.core_reportbuilder_reports_get_response_attributes_inner import CoreReportbuilderReportsGetResponseAttributesInner as CoreReportbuilderReportsGetResponseAttributesInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_button import CoreReportbuilderReportsGetResponseButton as CoreReportbuilderReportsGetResponseButton
    from poodle_async_full.models.core_reportbuilder_reports_get_response_button_attributes_inner import CoreReportbuilderReportsGetResponseButtonAttributesInner as CoreReportbuilderReportsGetResponseButtonAttributesInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_cardview import CoreReportbuilderReportsGetResponseCardview as CoreReportbuilderReportsGetResponseCardview
    from poodle_async_full.models.core_reportbuilder_reports_get_response_conditions import CoreReportbuilderReportsGetResponseConditions as CoreReportbuilderReportsGetResponseConditions
    from poodle_async_full.models.core_reportbuilder_reports_get_response_filters import CoreReportbuilderReportsGetResponseFilters as CoreReportbuilderReportsGetResponseFilters
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards import CoreReportbuilderReportsGetResponseSidebarmenucards as CoreReportbuilderReportsGetResponseSidebarmenucards
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner as CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner_items_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner as CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sorting import CoreReportbuilderReportsGetResponseSorting as CoreReportbuilderReportsGetResponseSorting
    from poodle_async_full.models.core_reportbuilder_retrieve_report_response import CoreReportbuilderRetrieveReportResponse as CoreReportbuilderRetrieveReportResponse
    from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data import CoreReportbuilderRetrieveReportResponseData as CoreReportbuilderRetrieveReportResponseData
    from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data_rows_inner import CoreReportbuilderRetrieveReportResponseDataRowsInner as CoreReportbuilderRetrieveReportResponseDataRowsInner
    from poodle_async_full.models.core_reportbuilder_retrieve_system_report_response import CoreReportbuilderRetrieveSystemReportResponse as CoreReportbuilderRetrieveSystemReportResponse
    from poodle_async_full.models.core_reportbuilder_view_report_response import CoreReportbuilderViewReportResponse as CoreReportbuilderViewReportResponse
    from poodle_async_full.models.core_role_assign_roles_parameters_assignments_inner import CoreRoleAssignRolesParametersAssignmentsInner as CoreRoleAssignRolesParametersAssignmentsInner
    from poodle_async_full.models.core_role_unassign_roles_parameters_unassignments_inner import CoreRoleUnassignRolesParametersUnassignmentsInner as CoreRoleUnassignRolesParametersUnassignmentsInner
    from poodle_async_full.models.core_search_get_relevant_users_response_inner import CoreSearchGetRelevantUsersResponseInner as CoreSearchGetRelevantUsersResponseInner
    from poodle_async_full.models.core_search_get_results_parameters_filters import CoreSearchGetResultsParametersFilters as CoreSearchGetResultsParametersFilters
    from poodle_async_full.models.core_search_get_results_response import CoreSearchGetResultsResponse as CoreSearchGetResultsResponse
    from poodle_async_full.models.core_search_get_results_response_results_inner import CoreSearchGetResultsResponseResultsInner as CoreSearchGetResultsResponseResultsInner
    from poodle_async_full.models.core_search_get_search_areas_list_response import CoreSearchGetSearchAreasListResponse as CoreSearchGetSearchAreasListResponse
    from poodle_async_full.models.core_search_get_search_areas_list_response_areas_inner import CoreSearchGetSearchAreasListResponseAreasInner as CoreSearchGetSearchAreasListResponseAreasInner
    from poodle_async_full.models.core_search_get_top_results_response import CoreSearchGetTopResultsResponse as CoreSearchGetTopResultsResponse
    from poodle_async_full.models.core_search_view_results_parameters_filters import CoreSearchViewResultsParametersFilters as CoreSearchViewResultsParametersFilters
    from poodle_async_full.models.core_search_view_results_response import CoreSearchViewResultsResponse as CoreSearchViewResultsResponse
    from poodle_async_full.models.core_session_time_remaining_response import CoreSessionTimeRemainingResponse as CoreSessionTimeRemainingResponse
    from poodle_async_full.models.core_sms_set_gateway_status_response import CoreSmsSetGatewayStatusResponse as CoreSmsSetGatewayStatusResponse
    from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner import CoreTableGetDynamicTableContentParametersFiltersInner as CoreTableGetDynamicTableContentParametersFiltersInner
    from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner_filteroptions_inner import CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner as CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner
    from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_sortdata_inner import CoreTableGetDynamicTableContentParametersSortdataInner as CoreTableGetDynamicTableContentParametersSortdataInner
    from poodle_async_full.models.core_table_get_dynamic_table_content_response import CoreTableGetDynamicTableContentResponse as CoreTableGetDynamicTableContentResponse
    from poodle_async_full.models.core_tag_get_tag_areas_response import CoreTagGetTagAreasResponse as CoreTagGetTagAreasResponse
    from poodle_async_full.models.core_tag_get_tag_areas_response_areas_inner import CoreTagGetTagAreasResponseAreasInner as CoreTagGetTagAreasResponseAreasInner
    from poodle_async_full.models.core_tag_get_tag_cloud_response import CoreTagGetTagCloudResponse as CoreTagGetTagCloudResponse
    from poodle_async_full.models.core_tag_get_tag_cloud_response_tags_inner import CoreTagGetTagCloudResponseTagsInner as CoreTagGetTagCloudResponseTagsInner
    from poodle_async_full.models.core_tag_get_tag_collections_response import CoreTagGetTagCollectionsResponse as CoreTagGetTagCollectionsResponse
    from poodle_async_full.models.core_tag_get_tag_collections_response_collections_inner import CoreTagGetTagCollectionsResponseCollectionsInner as CoreTagGetTagCollectionsResponseCollectionsInner
    from poodle_async_full.models.core_tag_get_tagindex_parameters_tagindex import CoreTagGetTagindexParametersTagindex as CoreTagGetTagindexParametersTagindex
    from poodle_async_full.models.core_tag_get_tagindex_per_area_parameters_tagindex import CoreTagGetTagindexPerAreaParametersTagindex as CoreTagGetTagindexPerAreaParametersTagindex
    from poodle_async_full.models.core_tag_get_tagindex_per_area_response_inner import CoreTagGetTagindexPerAreaResponseInner as CoreTagGetTagindexPerAreaResponseInner
    from poodle_async_full.models.core_tag_get_tagindex_response import CoreTagGetTagindexResponse as CoreTagGetTagindexResponse
    from poodle_async_full.models.core_tag_get_tags_parameters_tags_inner import CoreTagGetTagsParametersTagsInner as CoreTagGetTagsParametersTagsInner
    from poodle_async_full.models.core_tag_get_tags_response import CoreTagGetTagsResponse as CoreTagGetTagsResponse
    from poodle_async_full.models.core_tag_get_tags_response_tags_inner import CoreTagGetTagsResponseTagsInner as CoreTagGetTagsResponseTagsInner
    from poodle_async_full.models.core_tag_update_tags_parameters_tags_inner import CoreTagUpdateTagsParametersTagsInner as CoreTagUpdateTagsParametersTagsInner
    from poodle_async_full.models.core_tag_update_tags_response import CoreTagUpdateTagsResponse as CoreTagUpdateTagsResponse
    from poodle_async_full.models.core_update_inplace_editable_response import CoreUpdateInplaceEditableResponse as CoreUpdateInplaceEditableResponse
    from poodle_async_full.models.core_update_inplace_editable_response_editicon import CoreUpdateInplaceEditableResponseEditicon as CoreUpdateInplaceEditableResponseEditicon
    from poodle_async_full.models.core_user_agree_site_policy_response import CoreUserAgreeSitePolicyResponse as CoreUserAgreeSitePolicyResponse
    from poodle_async_full.models.core_user_create_users_parameters_users_inner import CoreUserCreateUsersParametersUsersInner as CoreUserCreateUsersParametersUsersInner
    from poodle_async_full.models.core_user_create_users_parameters_users_inner_customfields_inner import CoreUserCreateUsersParametersUsersInnerCustomfieldsInner as CoreUserCreateUsersParametersUsersInnerCustomfieldsInner
    from poodle_async_full.models.core_user_create_users_parameters_users_inner_preferences_inner import CoreUserCreateUsersParametersUsersInnerPreferencesInner as CoreUserCreateUsersParametersUsersInnerPreferencesInner
    from poodle_async_full.models.core_user_create_users_response_inner import CoreUserCreateUsersResponseInner as CoreUserCreateUsersResponseInner
    from poodle_async_full.models.core_user_get_course_user_profiles_parameters_userlist_inner import CoreUserGetCourseUserProfilesParametersUserlistInner as CoreUserGetCourseUserProfilesParametersUserlistInner
    from poodle_async_full.models.core_user_get_course_user_profiles_response_inner import CoreUserGetCourseUserProfilesResponseInner as CoreUserGetCourseUserProfilesResponseInner
    from poodle_async_full.models.core_user_get_private_files_info_response import CoreUserGetPrivateFilesInfoResponse as CoreUserGetPrivateFilesInfoResponse
    from poodle_async_full.models.core_user_get_user_preferences_response import CoreUserGetUserPreferencesResponse as CoreUserGetUserPreferencesResponse
    from poodle_async_full.models.core_user_get_user_preferences_response_preferences_inner import CoreUserGetUserPreferencesResponsePreferencesInner as CoreUserGetUserPreferencesResponsePreferencesInner
    from poodle_async_full.models.core_user_get_users_parameters_criteria_inner import CoreUserGetUsersParametersCriteriaInner as CoreUserGetUsersParametersCriteriaInner
    from poodle_async_full.models.core_user_get_users_response import CoreUserGetUsersResponse as CoreUserGetUsersResponse
    from poodle_async_full.models.core_user_get_users_response_warnings_inner import CoreUserGetUsersResponseWarningsInner as CoreUserGetUsersResponseWarningsInner
    from poodle_async_full.models.core_user_prepare_private_files_for_edition_response import CoreUserPreparePrivateFilesForEditionResponse as CoreUserPreparePrivateFilesForEditionResponse
    from poodle_async_full.models.core_user_remove_user_device_response import CoreUserRemoveUserDeviceResponse as CoreUserRemoveUserDeviceResponse
    from poodle_async_full.models.core_user_search_identity_response import CoreUserSearchIdentityResponse as CoreUserSearchIdentityResponse
    from poodle_async_full.models.core_user_search_identity_response_list_inner import CoreUserSearchIdentityResponseListInner as CoreUserSearchIdentityResponseListInner
    from poodle_async_full.models.core_user_search_identity_response_list_inner_extrafields_inner import CoreUserSearchIdentityResponseListInnerExtrafieldsInner as CoreUserSearchIdentityResponseListInnerExtrafieldsInner
    from poodle_async_full.models.core_user_set_user_preferences_parameters import CoreUserSetUserPreferencesParameters as CoreUserSetUserPreferencesParameters
    from poodle_async_full.models.core_user_set_user_preferences_parameters_preferences_inner import CoreUserSetUserPreferencesParametersPreferencesInner as CoreUserSetUserPreferencesParametersPreferencesInner
    from poodle_async_full.models.core_user_set_user_preferences_response import CoreUserSetUserPreferencesResponse as CoreUserSetUserPreferencesResponse
    from poodle_async_full.models.core_user_set_user_preferences_response_saved_inner import CoreUserSetUserPreferencesResponseSavedInner as CoreUserSetUserPreferencesResponseSavedInner
    from poodle_async_full.models.core_user_update_picture_response import CoreUserUpdatePictureResponse as CoreUserUpdatePictureResponse
    from poodle_async_full.models.core_user_update_private_files_response import CoreUserUpdatePrivateFilesResponse as CoreUserUpdatePrivateFilesResponse
    from poodle_async_full.models.core_user_update_user_device_public_key_response import CoreUserUpdateUserDevicePublicKeyResponse as CoreUserUpdateUserDevicePublicKeyResponse
    from poodle_async_full.models.core_user_update_user_preferences_parameters_preferences_inner import CoreUserUpdateUserPreferencesParametersPreferencesInner as CoreUserUpdateUserPreferencesParametersPreferencesInner
    from poodle_async_full.models.core_user_update_users_parameters_users_inner import CoreUserUpdateUsersParametersUsersInner as CoreUserUpdateUsersParametersUsersInner
    from poodle_async_full.models.core_user_update_users_response import CoreUserUpdateUsersResponse as CoreUserUpdateUsersResponse
    from poodle_async_full.models.core_user_view_user_list_response import CoreUserViewUserListResponse as CoreUserViewUserListResponse
    from poodle_async_full.models.core_user_view_user_profile_response import CoreUserViewUserProfileResponse as CoreUserViewUserProfileResponse
    from poodle_async_full.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse as CoreWebserviceGetSiteInfoResponse
    from poodle_async_full.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner as CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
    from poodle_async_full.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner as CoreWebserviceGetSiteInfoResponseFunctionsInner
    from poodle_async_full.models.customfield_number_recalculate_value_response import CustomfieldNumberRecalculateValueResponse as CustomfieldNumberRecalculateValueResponse
    from poodle_async_full.models.editor_tiny_get_configuration_response import EditorTinyGetConfigurationResponse as EditorTinyGetConfigurationResponse
    from poodle_async_full.models.editor_tiny_get_configuration_response_installedlanguages_inner import EditorTinyGetConfigurationResponseInstalledlanguagesInner as EditorTinyGetConfigurationResponseInstalledlanguagesInner
    from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner import EditorTinyGetConfigurationResponsePluginsInner as EditorTinyGetConfigurationResponsePluginsInner
    from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner_settings_inner import EditorTinyGetConfigurationResponsePluginsInnerSettingsInner as EditorTinyGetConfigurationResponsePluginsInnerSettingsInner
    from poodle_async_full.models.enrol_guest_get_instance_info_response import EnrolGuestGetInstanceInfoResponse as EnrolGuestGetInstanceInfoResponse
    from poodle_async_full.models.enrol_guest_get_instance_info_response_instanceinfo import EnrolGuestGetInstanceInfoResponseInstanceinfo as EnrolGuestGetInstanceInfoResponseInstanceinfo
    from poodle_async_full.models.enrol_guest_validate_password_response import EnrolGuestValidatePasswordResponse as EnrolGuestValidatePasswordResponse
    from poodle_async_full.models.enrol_manual_enrol_users_parameters_enrolments_inner import EnrolManualEnrolUsersParametersEnrolmentsInner as EnrolManualEnrolUsersParametersEnrolmentsInner
    from poodle_async_full.models.enrol_manual_unenrol_users_parameters_enrolments_inner import EnrolManualUnenrolUsersParametersEnrolmentsInner as EnrolManualUnenrolUsersParametersEnrolmentsInner
    from poodle_async_full.models.enrol_meta_add_instances_parameters_instances_inner import EnrolMetaAddInstancesParametersInstancesInner as EnrolMetaAddInstancesParametersInstancesInner
    from poodle_async_full.models.enrol_meta_add_instances_response_inner import EnrolMetaAddInstancesResponseInner as EnrolMetaAddInstancesResponseInner
    from poodle_async_full.models.enrol_meta_delete_instances_parameters_instances_inner import EnrolMetaDeleteInstancesParametersInstancesInner as EnrolMetaDeleteInstancesParametersInstancesInner
    from poodle_async_full.models.enrol_meta_delete_instances_response_inner import EnrolMetaDeleteInstancesResponseInner as EnrolMetaDeleteInstancesResponseInner
    from poodle_async_full.models.enrol_self_enrol_user_response import EnrolSelfEnrolUserResponse as EnrolSelfEnrolUserResponse
    from poodle_async_full.models.enrol_self_get_instance_info_response import EnrolSelfGetInstanceInfoResponse as EnrolSelfGetInstanceInfoResponse
    from poodle_async_full.models.gradereport_grader_get_users_in_report_response import GradereportGraderGetUsersInReportResponse as GradereportGraderGetUsersInReportResponse
    from poodle_async_full.models.gradereport_overview_get_course_grades_response import GradereportOverviewGetCourseGradesResponse as GradereportOverviewGetCourseGradesResponse
    from poodle_async_full.models.gradereport_overview_get_course_grades_response_grades_inner import GradereportOverviewGetCourseGradesResponseGradesInner as GradereportOverviewGetCourseGradesResponseGradesInner
    from poodle_async_full.models.gradereport_overview_view_grade_report_response import GradereportOverviewViewGradeReportResponse as GradereportOverviewViewGradeReportResponse
    from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response import GradereportSingleviewGetGradeItemsForSearchWidgetResponse as GradereportSingleviewGetGradeItemsForSearchWidgetResponse
    from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response_gradeitems_inner import GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner as GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner
    from poodle_async_full.models.gradereport_user_get_access_information_response import GradereportUserGetAccessInformationResponse as GradereportUserGetAccessInformationResponse
    from poodle_async_full.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse as GradereportUserGetGradeItemsResponse
    from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner as GradereportUserGetGradeItemsResponseUsergradesInner
    from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner as GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
    from poodle_async_full.models.gradereport_user_get_grades_table_response import GradereportUserGetGradesTableResponse as GradereportUserGetGradesTableResponse
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner import GradereportUserGetGradesTableResponseTablesInner as GradereportUserGetGradesTableResponseTablesInner
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner import GradereportUserGetGradesTableResponseTablesInnerTabledataInner as GradereportUserGetGradesTableResponseTablesInnerTabledataInner
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_average import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_contributiontocoursetotal import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_feedback import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_grade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_itemname import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_leader import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_lettergrade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_percentage import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_range import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_rank import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_weight import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight
    from poodle_async_full.models.gradereport_user_view_grade_report_response import GradereportUserViewGradeReportResponse as GradereportUserViewGradeReportResponse
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response import GradingformGuideGraderGradingpanelFetchResponse as GradingformGuideGraderGradingpanelFetchResponse
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade import GradingformGuideGraderGradingpanelFetchResponseGrade as GradingformGuideGraderGradingpanelFetchResponseGrade
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_comments_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner as GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_criterion_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner as GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_store_response import GradingformGuideGraderGradingpanelStoreResponse as GradingformGuideGraderGradingpanelStoreResponse
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response import GradingformRubricGraderGradingpanelFetchResponse as GradingformRubricGraderGradingpanelFetchResponse
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade import GradingformRubricGraderGradingpanelFetchResponseGrade as GradingformRubricGraderGradingpanelFetchResponseGrade
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner as GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner_levels_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner as GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_store_response import GradingformRubricGraderGradingpanelStoreResponse as GradingformRubricGraderGradingpanelStoreResponse
    from poodle_async_full.models.login_token200_response import LoginToken200Response as LoginToken200Response
    from poodle_async_full.models.media_videojs_get_language_parameters import MediaVideojsGetLanguageParameters as MediaVideojsGetLanguageParameters
    from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response import MessageAirnotifierAreNotificationPreferencesConfiguredResponse as MessageAirnotifierAreNotificationPreferencesConfiguredResponse
    from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response_users_inner import MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner as MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner
    from poodle_async_full.models.message_airnotifier_enable_device_response import MessageAirnotifierEnableDeviceResponse as MessageAirnotifierEnableDeviceResponse
    from poodle_async_full.models.message_airnotifier_get_user_devices_response import MessageAirnotifierGetUserDevicesResponse as MessageAirnotifierGetUserDevicesResponse
    from poodle_async_full.models.message_airnotifier_get_user_devices_response_devices_inner import MessageAirnotifierGetUserDevicesResponseDevicesInner as MessageAirnotifierGetUserDevicesResponseDevicesInner
    from poodle_async_full.models.message_popup_get_popup_notifications_response import MessagePopupGetPopupNotificationsResponse as MessagePopupGetPopupNotificationsResponse
    from poodle_async_full.models.message_popup_get_popup_notifications_response_notifications_inner import MessagePopupGetPopupNotificationsResponseNotificationsInner as MessagePopupGetPopupNotificationsResponseNotificationsInner
    from poodle_async_full.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse as ModAssignGetAssignmentsResponse
    from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner as ModAssignGetAssignmentsResponseCoursesInner
    from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
    from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
    from poodle_async_full.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner as ModAssignGetAssignmentsResponseWarningsInner
    from poodle_async_full.models.mod_assign_get_grades_response import ModAssignGetGradesResponse as ModAssignGetGradesResponse
    from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner import ModAssignGetGradesResponseAssignmentsInner as ModAssignGetGradesResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner_grades_inner import ModAssignGetGradesResponseAssignmentsInnerGradesInner as ModAssignGetGradesResponseAssignmentsInnerGradesInner
    from poodle_async_full.models.mod_assign_get_grades_response_warnings_inner import ModAssignGetGradesResponseWarningsInner as ModAssignGetGradesResponseWarningsInner
    from poodle_async_full.models.mod_assign_get_participant_response import ModAssignGetParticipantResponse as ModAssignGetParticipantResponse
    from poodle_async_full.models.mod_assign_get_submission_status_response import ModAssignGetSubmissionStatusResponse as ModAssignGetSubmissionStatusResponse
    from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata import ModAssignGetSubmissionStatusResponseAssignmentdata as ModAssignGetSubmissionStatusResponseAssignmentdata
    from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata_attachments import ModAssignGetSubmissionStatusResponseAssignmentdataAttachments as ModAssignGetSubmissionStatusResponseAssignmentdataAttachments
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback import ModAssignGetSubmissionStatusResponseFeedback as ModAssignGetSubmissionStatusResponseFeedback
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInner as ModAssignGetSubmissionStatusResponseFeedbackPluginsInner
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_editorfields_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner as ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_fileareas_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner as ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner
    from poodle_async_full.models.mod_assign_get_submission_status_response_gradingsummary import ModAssignGetSubmissionStatusResponseGradingsummary as ModAssignGetSubmissionStatusResponseGradingsummary
    from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt import ModAssignGetSubmissionStatusResponseLastattempt as ModAssignGetSubmissionStatusResponseLastattempt
    from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt_submission import ModAssignGetSubmissionStatusResponseLastattemptSubmission as ModAssignGetSubmissionStatusResponseLastattemptSubmission
    from poodle_async_full.models.mod_assign_get_submission_status_response_previousattempts_inner import ModAssignGetSubmissionStatusResponsePreviousattemptsInner as ModAssignGetSubmissionStatusResponsePreviousattemptsInner
    from poodle_async_full.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse as ModAssignGetSubmissionsResponse
    from poodle_async_full.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner as ModAssignGetSubmissionsResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_user_flags_response import ModAssignGetUserFlagsResponse as ModAssignGetUserFlagsResponse
    from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner import ModAssignGetUserFlagsResponseAssignmentsInner as ModAssignGetUserFlagsResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner_userflags_inner import ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner as ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner
    from poodle_async_full.models.mod_assign_get_user_flags_response_warnings_inner import ModAssignGetUserFlagsResponseWarningsInner as ModAssignGetUserFlagsResponseWarningsInner
    from poodle_async_full.models.mod_assign_get_user_mappings_response import ModAssignGetUserMappingsResponse as ModAssignGetUserMappingsResponse
    from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner import ModAssignGetUserMappingsResponseAssignmentsInner as ModAssignGetUserMappingsResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner_mappings_inner import ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner as ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner
    from poodle_async_full.models.mod_assign_get_user_mappings_response_warnings_inner import ModAssignGetUserMappingsResponseWarningsInner as ModAssignGetUserMappingsResponseWarningsInner
    from poodle_async_full.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner as ModAssignListParticipantsResponseInner
    from poodle_async_full.models.mod_assign_remove_submission_response import ModAssignRemoveSubmissionResponse as ModAssignRemoveSubmissionResponse
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata import ModAssignSaveGradeParametersAdvancedgradingdata as ModAssignSaveGradeParametersAdvancedgradingdata
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide import ModAssignSaveGradeParametersAdvancedgradingdataGuide as ModAssignSaveGradeParametersAdvancedgradingdataGuide
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner as ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner as ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric import ModAssignSaveGradeParametersAdvancedgradingdataRubric as ModAssignSaveGradeParametersAdvancedgradingdataRubric
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner as ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner as ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata import ModAssignSaveGradeParametersPlugindata as ModAssignSaveGradeParametersPlugindata
    from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata_assignfeedbackcomments_editor import ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor as ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor
    from poodle_async_full.models.mod_assign_save_grades_parameters_grades_inner import ModAssignSaveGradesParametersGradesInner as ModAssignSaveGradesParametersGradesInner
    from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata import ModAssignSaveSubmissionParametersPlugindata as ModAssignSaveSubmissionParametersPlugindata
    from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata_onlinetext_editor import ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor as ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor
    from poodle_async_full.models.mod_assign_set_user_flags_parameters_userflags_inner import ModAssignSetUserFlagsParametersUserflagsInner as ModAssignSetUserFlagsParametersUserflagsInner
    from poodle_async_full.models.mod_assign_set_user_flags_response_inner import ModAssignSetUserFlagsResponseInner as ModAssignSetUserFlagsResponseInner
    from poodle_async_full.models.mod_assign_start_submission_response import ModAssignStartSubmissionResponse as ModAssignStartSubmissionResponse
    from poodle_async_full.models.mod_assign_view_assign_response import ModAssignViewAssignResponse as ModAssignViewAssignResponse
    from poodle_async_full.models.mod_assign_view_grading_table_response import ModAssignViewGradingTableResponse as ModAssignViewGradingTableResponse
    from poodle_async_full.models.mod_assign_view_submission_status_response import ModAssignViewSubmissionStatusResponse as ModAssignViewSubmissionStatusResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_can_join_response import ModBigbluebuttonbnCanJoinResponse as ModBigbluebuttonbnCanJoinResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_completion_validate_response import ModBigbluebuttonbnCompletionValidateResponse as ModBigbluebuttonbnCompletionValidateResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_end_meeting_response import ModBigbluebuttonbnEndMeetingResponse as ModBigbluebuttonbnEndMeetingResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse as ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response_bigbluebuttonbns_inner import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner as ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner
    from poodle_async_full.models.mod_bigbluebuttonbn_get_join_url_response import ModBigbluebuttonbnGetJoinUrlResponse as ModBigbluebuttonbnGetJoinUrlResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response import ModBigbluebuttonbnGetRecordingsResponse as ModBigbluebuttonbnGetRecordingsResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata import ModBigbluebuttonbnGetRecordingsResponseTabledata as ModBigbluebuttonbnGetRecordingsResponseTabledata
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata_columns_inner import ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner as ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_to_import_response import ModBigbluebuttonbnGetRecordingsToImportResponse as ModBigbluebuttonbnGetRecordingsToImportResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response import ModBigbluebuttonbnMeetingInfoResponse as ModBigbluebuttonbnMeetingInfoResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_features_inner import ModBigbluebuttonbnMeetingInfoResponseFeaturesInner as ModBigbluebuttonbnMeetingInfoResponseFeaturesInner
    from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_presentations_inner import ModBigbluebuttonbnMeetingInfoResponsePresentationsInner as ModBigbluebuttonbnMeetingInfoResponsePresentationsInner
    from poodle_async_full.models.mod_bigbluebuttonbn_view_bigbluebuttonbn_response import ModBigbluebuttonbnViewBigbluebuttonbnResponse as ModBigbluebuttonbnViewBigbluebuttonbnResponse
    from poodle_async_full.models.mod_book_get_books_by_courses_response import ModBookGetBooksByCoursesResponse as ModBookGetBooksByCoursesResponse
    from poodle_async_full.models.mod_book_get_books_by_courses_response_books_inner import ModBookGetBooksByCoursesResponseBooksInner as ModBookGetBooksByCoursesResponseBooksInner
    from poodle_async_full.models.mod_book_view_book_response import ModBookViewBookResponse as ModBookViewBookResponse
    from poodle_async_full.models.mod_choice_delete_choice_responses_response import ModChoiceDeleteChoiceResponsesResponse as ModChoiceDeleteChoiceResponsesResponse
    from poodle_async_full.models.mod_choice_get_choice_options_response import ModChoiceGetChoiceOptionsResponse as ModChoiceGetChoiceOptionsResponse
    from poodle_async_full.models.mod_choice_get_choice_options_response_options_inner import ModChoiceGetChoiceOptionsResponseOptionsInner as ModChoiceGetChoiceOptionsResponseOptionsInner
    from poodle_async_full.models.mod_choice_get_choice_results_response import ModChoiceGetChoiceResultsResponse as ModChoiceGetChoiceResultsResponse
    from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner import ModChoiceGetChoiceResultsResponseOptionsInner as ModChoiceGetChoiceResultsResponseOptionsInner
    from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner_userresponses_inner import ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner as ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner
    from poodle_async_full.models.mod_choice_get_choices_by_courses_response import ModChoiceGetChoicesByCoursesResponse as ModChoiceGetChoicesByCoursesResponse
    from poodle_async_full.models.mod_choice_get_choices_by_courses_response_choices_inner import ModChoiceGetChoicesByCoursesResponseChoicesInner as ModChoiceGetChoicesByCoursesResponseChoicesInner
    from poodle_async_full.models.mod_choice_submit_choice_response_response import ModChoiceSubmitChoiceResponseResponse as ModChoiceSubmitChoiceResponseResponse
    from poodle_async_full.models.mod_choice_submit_choice_response_response_answers_inner import ModChoiceSubmitChoiceResponseResponseAnswersInner as ModChoiceSubmitChoiceResponseResponseAnswersInner
    from poodle_async_full.models.mod_choice_view_choice_response import ModChoiceViewChoiceResponse as ModChoiceViewChoiceResponse
    from poodle_async_full.models.mod_data_add_entry_parameters_data_inner import ModDataAddEntryParametersDataInner as ModDataAddEntryParametersDataInner
    from poodle_async_full.models.mod_data_add_entry_response import ModDataAddEntryResponse as ModDataAddEntryResponse
    from poodle_async_full.models.mod_data_add_entry_response_fieldnotifications_inner import ModDataAddEntryResponseFieldnotificationsInner as ModDataAddEntryResponseFieldnotificationsInner
    from poodle_async_full.models.mod_data_approve_entry_response import ModDataApproveEntryResponse as ModDataApproveEntryResponse
    from poodle_async_full.models.mod_data_delete_entry_response import ModDataDeleteEntryResponse as ModDataDeleteEntryResponse
    from poodle_async_full.models.mod_data_delete_saved_preset_response import ModDataDeleteSavedPresetResponse as ModDataDeleteSavedPresetResponse
    from poodle_async_full.models.mod_data_get_data_access_information_response import ModDataGetDataAccessInformationResponse as ModDataGetDataAccessInformationResponse
    from poodle_async_full.models.mod_data_get_databases_by_courses_response import ModDataGetDatabasesByCoursesResponse as ModDataGetDatabasesByCoursesResponse
    from poodle_async_full.models.mod_data_get_databases_by_courses_response_databases_inner import ModDataGetDatabasesByCoursesResponseDatabasesInner as ModDataGetDatabasesByCoursesResponseDatabasesInner
    from poodle_async_full.models.mod_data_get_entries_response import ModDataGetEntriesResponse as ModDataGetEntriesResponse
    from poodle_async_full.models.mod_data_get_entries_response_entries_inner import ModDataGetEntriesResponseEntriesInner as ModDataGetEntriesResponseEntriesInner
    from poodle_async_full.models.mod_data_get_entries_response_entries_inner_contents_inner import ModDataGetEntriesResponseEntriesInnerContentsInner as ModDataGetEntriesResponseEntriesInnerContentsInner
    from poodle_async_full.models.mod_data_get_entry_response import ModDataGetEntryResponse as ModDataGetEntryResponse
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo import ModDataGetEntryResponseRatinginfo as ModDataGetEntryResponseRatinginfo
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_ratings_inner import ModDataGetEntryResponseRatinginfoRatingsInner as ModDataGetEntryResponseRatinginfoRatingsInner
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner import ModDataGetEntryResponseRatinginfoScalesInner as ModDataGetEntryResponseRatinginfoScalesInner
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner_items_inner import ModDataGetEntryResponseRatinginfoScalesInnerItemsInner as ModDataGetEntryResponseRatinginfoScalesInnerItemsInner
    from poodle_async_full.models.mod_data_get_fields_response import ModDataGetFieldsResponse as ModDataGetFieldsResponse
    from poodle_async_full.models.mod_data_get_fields_response_fields_inner import ModDataGetFieldsResponseFieldsInner as ModDataGetFieldsResponseFieldsInner
    from poodle_async_full.models.mod_data_get_mapping_information_response import ModDataGetMappingInformationResponse as ModDataGetMappingInformationResponse
    from poodle_async_full.models.mod_data_get_mapping_information_response_data import ModDataGetMappingInformationResponseData as ModDataGetMappingInformationResponseData
    from poodle_async_full.models.mod_data_search_entries_parameters_advsearch_inner import ModDataSearchEntriesParametersAdvsearchInner as ModDataSearchEntriesParametersAdvsearchInner
    from poodle_async_full.models.mod_data_search_entries_response import ModDataSearchEntriesResponse as ModDataSearchEntriesResponse
    from poodle_async_full.models.mod_data_update_entry_parameters_data_inner import ModDataUpdateEntryParametersDataInner as ModDataUpdateEntryParametersDataInner
    from poodle_async_full.models.mod_data_update_entry_response import ModDataUpdateEntryResponse as ModDataUpdateEntryResponse
    from poodle_async_full.models.mod_data_view_database_response import ModDataViewDatabaseResponse as ModDataViewDatabaseResponse
    from poodle_async_full.models.mod_feedback_get_analysis_response import ModFeedbackGetAnalysisResponse as ModFeedbackGetAnalysisResponse
    from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner import ModFeedbackGetAnalysisResponseItemsdataInner as ModFeedbackGetAnalysisResponseItemsdataInner
    from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner_item import ModFeedbackGetAnalysisResponseItemsdataInnerItem as ModFeedbackGetAnalysisResponseItemsdataInnerItem
    from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response import ModFeedbackGetCurrentCompletedTmpResponse as ModFeedbackGetCurrentCompletedTmpResponse
    from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response_feedback import ModFeedbackGetCurrentCompletedTmpResponseFeedback as ModFeedbackGetCurrentCompletedTmpResponseFeedback
    from poodle_async_full.models.mod_feedback_get_feedback_access_information_response import ModFeedbackGetFeedbackAccessInformationResponse as ModFeedbackGetFeedbackAccessInformationResponse
    from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response import ModFeedbackGetFeedbacksByCoursesResponse as ModFeedbackGetFeedbacksByCoursesResponse
    from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response_feedbacks_inner import ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner as ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner
    from poodle_async_full.models.mod_feedback_get_finished_responses_response import ModFeedbackGetFinishedResponsesResponse as ModFeedbackGetFinishedResponsesResponse
    from poodle_async_full.models.mod_feedback_get_finished_responses_response_responses_inner import ModFeedbackGetFinishedResponsesResponseResponsesInner as ModFeedbackGetFinishedResponsesResponseResponsesInner
    from poodle_async_full.models.mod_feedback_get_items_response import ModFeedbackGetItemsResponse as ModFeedbackGetItemsResponse
    from poodle_async_full.models.mod_feedback_get_last_completed_response import ModFeedbackGetLastCompletedResponse as ModFeedbackGetLastCompletedResponse
    from poodle_async_full.models.mod_feedback_get_last_completed_response_completed import ModFeedbackGetLastCompletedResponseCompleted as ModFeedbackGetLastCompletedResponseCompleted
    from poodle_async_full.models.mod_feedback_get_non_respondents_response import ModFeedbackGetNonRespondentsResponse as ModFeedbackGetNonRespondentsResponse
    from poodle_async_full.models.mod_feedback_get_non_respondents_response_users_inner import ModFeedbackGetNonRespondentsResponseUsersInner as ModFeedbackGetNonRespondentsResponseUsersInner
    from poodle_async_full.models.mod_feedback_get_page_items_response import ModFeedbackGetPageItemsResponse as ModFeedbackGetPageItemsResponse
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response import ModFeedbackGetResponsesAnalysisResponse as ModFeedbackGetResponsesAnalysisResponse
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner as ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner_responses_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner as ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response_attempts_inner import ModFeedbackGetResponsesAnalysisResponseAttemptsInner as ModFeedbackGetResponsesAnalysisResponseAttemptsInner
    from poodle_async_full.models.mod_feedback_get_unfinished_responses_response import ModFeedbackGetUnfinishedResponsesResponse as ModFeedbackGetUnfinishedResponsesResponse
    from poodle_async_full.models.mod_feedback_get_unfinished_responses_response_responses_inner import ModFeedbackGetUnfinishedResponsesResponseResponsesInner as ModFeedbackGetUnfinishedResponsesResponseResponsesInner
    from poodle_async_full.models.mod_feedback_launch_feedback_response import ModFeedbackLaunchFeedbackResponse as ModFeedbackLaunchFeedbackResponse
    from poodle_async_full.models.mod_feedback_process_page_parameters_responses_inner import ModFeedbackProcessPageParametersResponsesInner as ModFeedbackProcessPageParametersResponsesInner
    from poodle_async_full.models.mod_feedback_process_page_response import ModFeedbackProcessPageResponse as ModFeedbackProcessPageResponse
    from poodle_async_full.models.mod_feedback_view_feedback_response import ModFeedbackViewFeedbackResponse as ModFeedbackViewFeedbackResponse
    from poodle_async_full.models.mod_folder_get_folders_by_courses_response import ModFolderGetFoldersByCoursesResponse as ModFolderGetFoldersByCoursesResponse
    from poodle_async_full.models.mod_folder_get_folders_by_courses_response_folders_inner import ModFolderGetFoldersByCoursesResponseFoldersInner as ModFolderGetFoldersByCoursesResponseFoldersInner
    from poodle_async_full.models.mod_folder_view_folder_response import ModFolderViewFolderResponse as ModFolderViewFolderResponse
    from poodle_async_full.models.mod_forum_add_discussion_parameters_options_inner import ModForumAddDiscussionParametersOptionsInner as ModForumAddDiscussionParametersOptionsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_parameters_options_inner import ModForumAddDiscussionPostParametersOptionsInner as ModForumAddDiscussionPostParametersOptionsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response import ModForumAddDiscussionPostResponse as ModForumAddDiscussionPostResponse
    from poodle_async_full.models.mod_forum_add_discussion_post_response_messages_inner import ModForumAddDiscussionPostResponseMessagesInner as ModForumAddDiscussionPostResponseMessagesInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post import ModForumAddDiscussionPostResponsePost as ModForumAddDiscussionPostResponsePost
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner import ModForumAddDiscussionPostResponsePostAttachmentsInner as ModForumAddDiscussionPostResponsePostAttachmentsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_html import ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml as ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_urls import ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls as ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author import ModForumAddDiscussionPostResponsePostAuthor as ModForumAddDiscussionPostResponsePostAuthor
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner import ModForumAddDiscussionPostResponsePostAuthorGroupsInner as ModForumAddDiscussionPostResponsePostAuthorGroupsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner_urls import ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls as ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_urls import ModForumAddDiscussionPostResponsePostAuthorUrls as ModForumAddDiscussionPostResponsePostAuthorUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_capabilities import ModForumAddDiscussionPostResponsePostCapabilities as ModForumAddDiscussionPostResponsePostCapabilities
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_html import ModForumAddDiscussionPostResponsePostHtml as ModForumAddDiscussionPostResponsePostHtml
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner import ModForumAddDiscussionPostResponsePostTagsInner as ModForumAddDiscussionPostResponsePostTagsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner_urls import ModForumAddDiscussionPostResponsePostTagsInnerUrls as ModForumAddDiscussionPostResponsePostTagsInnerUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_urls import ModForumAddDiscussionPostResponsePostUrls as ModForumAddDiscussionPostResponsePostUrls
    from poodle_async_full.models.mod_forum_add_discussion_response import ModForumAddDiscussionResponse as ModForumAddDiscussionResponse
    from poodle_async_full.models.mod_forum_can_add_discussion_response import ModForumCanAddDiscussionResponse as ModForumCanAddDiscussionResponse
    from poodle_async_full.models.mod_forum_delete_post_response import ModForumDeletePostResponse as ModForumDeletePostResponse
    from poodle_async_full.models.mod_forum_get_discussion_post_response import ModForumGetDiscussionPostResponse as ModForumGetDiscussionPostResponse
    from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response import ModForumGetDiscussionPostsByUseridResponse as ModForumGetDiscussionPostsByUseridResponse
    from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner import ModForumGetDiscussionPostsByUseridResponseDiscussionsInner as ModForumGetDiscussionPostsByUseridResponseDiscussionsInner
    from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner_posts import ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts as ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts
    from poodle_async_full.models.mod_forum_get_discussion_posts_response import ModForumGetDiscussionPostsResponse as ModForumGetDiscussionPostsResponse
    from poodle_async_full.models.mod_forum_get_forum_access_information_response import ModForumGetForumAccessInformationResponse as ModForumGetForumAccessInformationResponse
    from poodle_async_full.models.mod_forum_get_forum_discussions_response import ModForumGetForumDiscussionsResponse as ModForumGetForumDiscussionsResponse
    from poodle_async_full.models.mod_forum_get_forum_discussions_response_discussions_inner import ModForumGetForumDiscussionsResponseDiscussionsInner as ModForumGetForumDiscussionsResponseDiscussionsInner
    from poodle_async_full.models.mod_forum_get_forums_by_courses_response_inner import ModForumGetForumsByCoursesResponseInner as ModForumGetForumsByCoursesResponseInner
    from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_parameters_filestokeep_inner import ModForumPrepareDraftAreaForPostParametersFilestokeepInner as ModForumPrepareDraftAreaForPostParametersFilestokeepInner
    from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_response import ModForumPrepareDraftAreaForPostResponse as ModForumPrepareDraftAreaForPostResponse
    from poodle_async_full.models.mod_forum_set_lock_state_response import ModForumSetLockStateResponse as ModForumSetLockStateResponse
    from poodle_async_full.models.mod_forum_set_lock_state_response_times import ModForumSetLockStateResponseTimes as ModForumSetLockStateResponseTimes
    from poodle_async_full.models.mod_forum_set_pin_state_response import ModForumSetPinStateResponse as ModForumSetPinStateResponse
    from poodle_async_full.models.mod_forum_set_pin_state_response_capabilities import ModForumSetPinStateResponseCapabilities as ModForumSetPinStateResponseCapabilities
    from poodle_async_full.models.mod_forum_set_pin_state_response_group import ModForumSetPinStateResponseGroup as ModForumSetPinStateResponseGroup
    from poodle_async_full.models.mod_forum_set_pin_state_response_group_urls import ModForumSetPinStateResponseGroupUrls as ModForumSetPinStateResponseGroupUrls
    from poodle_async_full.models.mod_forum_set_pin_state_response_timed import ModForumSetPinStateResponseTimed as ModForumSetPinStateResponseTimed
    from poodle_async_full.models.mod_forum_set_pin_state_response_times import ModForumSetPinStateResponseTimes as ModForumSetPinStateResponseTimes
    from poodle_async_full.models.mod_forum_set_pin_state_response_urls import ModForumSetPinStateResponseUrls as ModForumSetPinStateResponseUrls
    from poodle_async_full.models.mod_forum_set_pin_state_response_userstate import ModForumSetPinStateResponseUserstate as ModForumSetPinStateResponseUserstate
    from poodle_async_full.models.mod_forum_set_subscription_state_response import ModForumSetSubscriptionStateResponse as ModForumSetSubscriptionStateResponse
    from poodle_async_full.models.mod_forum_toggle_favourite_state_response import ModForumToggleFavouriteStateResponse as ModForumToggleFavouriteStateResponse
    from poodle_async_full.models.mod_forum_update_discussion_post_parameters_options_inner import ModForumUpdateDiscussionPostParametersOptionsInner as ModForumUpdateDiscussionPostParametersOptionsInner
    from poodle_async_full.models.mod_forum_update_discussion_post_response import ModForumUpdateDiscussionPostResponse as ModForumUpdateDiscussionPostResponse
    from poodle_async_full.models.mod_forum_view_forum_discussion_response import ModForumViewForumDiscussionResponse as ModForumViewForumDiscussionResponse
    from poodle_async_full.models.mod_forum_view_forum_response import ModForumViewForumResponse as ModForumViewForumResponse
    from poodle_async_full.models.mod_glossary_add_entry_parameters_options_inner import ModGlossaryAddEntryParametersOptionsInner as ModGlossaryAddEntryParametersOptionsInner
    from poodle_async_full.models.mod_glossary_add_entry_response import ModGlossaryAddEntryResponse as ModGlossaryAddEntryResponse
    from poodle_async_full.models.mod_glossary_delete_entry_response import ModGlossaryDeleteEntryResponse as ModGlossaryDeleteEntryResponse
    from poodle_async_full.models.mod_glossary_get_authors_parameters_options import ModGlossaryGetAuthorsParametersOptions as ModGlossaryGetAuthorsParametersOptions
    from poodle_async_full.models.mod_glossary_get_authors_response import ModGlossaryGetAuthorsResponse as ModGlossaryGetAuthorsResponse
    from poodle_async_full.models.mod_glossary_get_authors_response_authors_inner import ModGlossaryGetAuthorsResponseAuthorsInner as ModGlossaryGetAuthorsResponseAuthorsInner
    from poodle_async_full.models.mod_glossary_get_categories_response import ModGlossaryGetCategoriesResponse as ModGlossaryGetCategoriesResponse
    from poodle_async_full.models.mod_glossary_get_categories_response_categories_inner import ModGlossaryGetCategoriesResponseCategoriesInner as ModGlossaryGetCategoriesResponseCategoriesInner
    from poodle_async_full.models.mod_glossary_get_entries_by_author_id_parameters_options import ModGlossaryGetEntriesByAuthorIdParametersOptions as ModGlossaryGetEntriesByAuthorIdParametersOptions
    from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response import ModGlossaryGetEntriesByAuthorIdResponse as ModGlossaryGetEntriesByAuthorIdResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response_entries_inner import ModGlossaryGetEntriesByAuthorIdResponseEntriesInner as ModGlossaryGetEntriesByAuthorIdResponseEntriesInner
    from poodle_async_full.models.mod_glossary_get_entries_by_author_response import ModGlossaryGetEntriesByAuthorResponse as ModGlossaryGetEntriesByAuthorResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_category_response import ModGlossaryGetEntriesByCategoryResponse as ModGlossaryGetEntriesByCategoryResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_category_response_entries_inner import ModGlossaryGetEntriesByCategoryResponseEntriesInner as ModGlossaryGetEntriesByCategoryResponseEntriesInner
    from poodle_async_full.models.mod_glossary_get_entries_by_date_response import ModGlossaryGetEntriesByDateResponse as ModGlossaryGetEntriesByDateResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_letter_response import ModGlossaryGetEntriesByLetterResponse as ModGlossaryGetEntriesByLetterResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_search_response import ModGlossaryGetEntriesBySearchResponse as ModGlossaryGetEntriesBySearchResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_term_response import ModGlossaryGetEntriesByTermResponse as ModGlossaryGetEntriesByTermResponse
    from poodle_async_full.models.mod_glossary_get_entries_to_approve_response import ModGlossaryGetEntriesToApproveResponse as ModGlossaryGetEntriesToApproveResponse
    from poodle_async_full.models.mod_glossary_get_entry_by_id_response import ModGlossaryGetEntryByIdResponse as ModGlossaryGetEntryByIdResponse
    from poodle_async_full.models.mod_glossary_get_entry_by_id_response_permissions import ModGlossaryGetEntryByIdResponsePermissions as ModGlossaryGetEntryByIdResponsePermissions
    from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response import ModGlossaryGetGlossariesByCoursesResponse as ModGlossaryGetGlossariesByCoursesResponse
    from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response_glossaries_inner import ModGlossaryGetGlossariesByCoursesResponseGlossariesInner as ModGlossaryGetGlossariesByCoursesResponseGlossariesInner
    from poodle_async_full.models.mod_glossary_prepare_entry_for_edition_response import ModGlossaryPrepareEntryForEditionResponse as ModGlossaryPrepareEntryForEditionResponse
    from poodle_async_full.models.mod_glossary_update_entry_response import ModGlossaryUpdateEntryResponse as ModGlossaryUpdateEntryResponse
    from poodle_async_full.models.mod_glossary_view_entry_response import ModGlossaryViewEntryResponse as ModGlossaryViewEntryResponse
    from poodle_async_full.models.mod_glossary_view_glossary_response import ModGlossaryViewGlossaryResponse as ModGlossaryViewGlossaryResponse
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response import ModH5pactivityGetAttemptsResponse as ModH5pactivityGetAttemptsResponse
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInner as ModH5pactivityGetAttemptsResponseUsersattemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_attempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner as ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_scored import ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored as ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response import ModH5pactivityGetH5pactivitiesByCoursesResponse as ModH5pactivityGetH5pactivitiesByCoursesResponse
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner as ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner_deployedfile import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile as ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pglobalsettings import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings as ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivity_access_information_response import ModH5pactivityGetH5pactivityAccessInformationResponse as ModH5pactivityGetH5pactivityAccessInformationResponse
    from poodle_async_full.models.mod_h5pactivity_get_results_response import ModH5pactivityGetResultsResponse as ModH5pactivityGetResultsResponse
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner import ModH5pactivityGetResultsResponseAttemptsInner as ModH5pactivityGetResultsResponseAttemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInner as ModH5pactivityGetResultsResponseAttemptsInnerResultsInner
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner as ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_correctanswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer as ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_useranswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer as ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer
    from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response import ModH5pactivityGetUserAttemptsResponse as ModH5pactivityGetUserAttemptsResponse
    from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner import ModH5pactivityGetUserAttemptsResponseUsersattemptsInner as ModH5pactivityGetUserAttemptsResponseUsersattemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner_scored import ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored as ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored
    from poodle_async_full.models.mod_h5pactivity_log_report_viewed_response import ModH5pactivityLogReportViewedResponse as ModH5pactivityLogReportViewedResponse
    from poodle_async_full.models.mod_h5pactivity_view_h5pactivity_response import ModH5pactivityViewH5pactivityResponse as ModH5pactivityViewH5pactivityResponse
    from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response import ModImscpGetImscpsByCoursesResponse as ModImscpGetImscpsByCoursesResponse
    from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response_imscps_inner import ModImscpGetImscpsByCoursesResponseImscpsInner as ModImscpGetImscpsByCoursesResponseImscpsInner
    from poodle_async_full.models.mod_imscp_view_imscp_response import ModImscpViewImscpResponse as ModImscpViewImscpResponse
    from poodle_async_full.models.mod_label_get_labels_by_courses_response import ModLabelGetLabelsByCoursesResponse as ModLabelGetLabelsByCoursesResponse
    from poodle_async_full.models.mod_label_get_labels_by_courses_response_labels_inner import ModLabelGetLabelsByCoursesResponseLabelsInner as ModLabelGetLabelsByCoursesResponseLabelsInner
    from poodle_async_full.models.mod_lesson_finish_attempt_response import ModLessonFinishAttemptResponse as ModLessonFinishAttemptResponse
    from poodle_async_full.models.mod_lesson_finish_attempt_response_data_inner import ModLessonFinishAttemptResponseDataInner as ModLessonFinishAttemptResponseDataInner
    from poodle_async_full.models.mod_lesson_finish_attempt_response_messages_inner import ModLessonFinishAttemptResponseMessagesInner as ModLessonFinishAttemptResponseMessagesInner
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response import ModLessonGetAttemptsOverviewResponse as ModLessonGetAttemptsOverviewResponse
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data import ModLessonGetAttemptsOverviewResponseData as ModLessonGetAttemptsOverviewResponseData
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInner as ModLessonGetAttemptsOverviewResponseDataStudentsInner
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner_attempts_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner as ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner
    from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response import ModLessonGetContentPagesViewedResponse as ModLessonGetContentPagesViewedResponse
    from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response_pages_inner import ModLessonGetContentPagesViewedResponsePagesInner as ModLessonGetContentPagesViewedResponsePagesInner
    from poodle_async_full.models.mod_lesson_get_lesson_access_information_response import ModLessonGetLessonAccessInformationResponse as ModLessonGetLessonAccessInformationResponse
    from poodle_async_full.models.mod_lesson_get_lesson_access_information_response_preventaccessreasons_inner import ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner as ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner
    from poodle_async_full.models.mod_lesson_get_lesson_response import ModLessonGetLessonResponse as ModLessonGetLessonResponse
    from poodle_async_full.models.mod_lesson_get_lesson_response_lesson import ModLessonGetLessonResponseLesson as ModLessonGetLessonResponseLesson
    from poodle_async_full.models.mod_lesson_get_lessons_by_courses_response import ModLessonGetLessonsByCoursesResponse as ModLessonGetLessonsByCoursesResponse
    from poodle_async_full.models.mod_lesson_get_page_data_response import ModLessonGetPageDataResponse as ModLessonGetPageDataResponse
    from poodle_async_full.models.mod_lesson_get_page_data_response_answers_inner import ModLessonGetPageDataResponseAnswersInner as ModLessonGetPageDataResponseAnswersInner
    from poodle_async_full.models.mod_lesson_get_page_data_response_page import ModLessonGetPageDataResponsePage as ModLessonGetPageDataResponsePage
    from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response import ModLessonGetPagesPossibleJumpsResponse as ModLessonGetPagesPossibleJumpsResponse
    from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response_jumps_inner import ModLessonGetPagesPossibleJumpsResponseJumpsInner as ModLessonGetPagesPossibleJumpsResponseJumpsInner
    from poodle_async_full.models.mod_lesson_get_pages_response import ModLessonGetPagesResponse as ModLessonGetPagesResponse
    from poodle_async_full.models.mod_lesson_get_pages_response_pages_inner import ModLessonGetPagesResponsePagesInner as ModLessonGetPagesResponsePagesInner
    from poodle_async_full.models.mod_lesson_get_questions_attempts_response import ModLessonGetQuestionsAttemptsResponse as ModLessonGetQuestionsAttemptsResponse
    from poodle_async_full.models.mod_lesson_get_questions_attempts_response_attempts_inner import ModLessonGetQuestionsAttemptsResponseAttemptsInner as ModLessonGetQuestionsAttemptsResponseAttemptsInner
    from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response import ModLessonGetUserAttemptGradeResponse as ModLessonGetUserAttemptGradeResponse
    from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response_grade import ModLessonGetUserAttemptGradeResponseGrade as ModLessonGetUserAttemptGradeResponseGrade
    from poodle_async_full.models.mod_lesson_get_user_attempt_response import ModLessonGetUserAttemptResponse as ModLessonGetUserAttemptResponse
    from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner import ModLessonGetUserAttemptResponseAnswerpagesInner as ModLessonGetUserAttemptResponseAnswerpagesInner
    from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner_answerdata import ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata as ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata
    from poodle_async_full.models.mod_lesson_get_user_attempt_response_userstats import ModLessonGetUserAttemptResponseUserstats as ModLessonGetUserAttemptResponseUserstats
    from poodle_async_full.models.mod_lesson_get_user_grade_response import ModLessonGetUserGradeResponse as ModLessonGetUserGradeResponse
    from poodle_async_full.models.mod_lesson_get_user_timers_response import ModLessonGetUserTimersResponse as ModLessonGetUserTimersResponse
    from poodle_async_full.models.mod_lesson_get_user_timers_response_timers_inner import ModLessonGetUserTimersResponseTimersInner as ModLessonGetUserTimersResponseTimersInner
    from poodle_async_full.models.mod_lesson_launch_attempt_response import ModLessonLaunchAttemptResponse as ModLessonLaunchAttemptResponse
    from poodle_async_full.models.mod_lesson_process_page_parameters_data_inner import ModLessonProcessPageParametersDataInner as ModLessonProcessPageParametersDataInner
    from poodle_async_full.models.mod_lesson_process_page_response import ModLessonProcessPageResponse as ModLessonProcessPageResponse
    from poodle_async_full.models.mod_lesson_view_lesson_response import ModLessonViewLessonResponse as ModLessonViewLessonResponse
    from poodle_async_full.models.mod_lti_create_tool_proxy_response import ModLtiCreateToolProxyResponse as ModLtiCreateToolProxyResponse
    from poodle_async_full.models.mod_lti_create_tool_type_response import ModLtiCreateToolTypeResponse as ModLtiCreateToolTypeResponse
    from poodle_async_full.models.mod_lti_create_tool_type_response_state import ModLtiCreateToolTypeResponseState as ModLtiCreateToolTypeResponseState
    from poodle_async_full.models.mod_lti_create_tool_type_response_urls import ModLtiCreateToolTypeResponseUrls as ModLtiCreateToolTypeResponseUrls
    from poodle_async_full.models.mod_lti_delete_tool_proxy_response import ModLtiDeleteToolProxyResponse as ModLtiDeleteToolProxyResponse
    from poodle_async_full.models.mod_lti_delete_tool_type_response import ModLtiDeleteToolTypeResponse as ModLtiDeleteToolTypeResponse
    from poodle_async_full.models.mod_lti_get_ltis_by_courses_response import ModLtiGetLtisByCoursesResponse as ModLtiGetLtisByCoursesResponse
    from poodle_async_full.models.mod_lti_get_ltis_by_courses_response_ltis_inner import ModLtiGetLtisByCoursesResponseLtisInner as ModLtiGetLtisByCoursesResponseLtisInner
    from poodle_async_full.models.mod_lti_get_tool_launch_data_response import ModLtiGetToolLaunchDataResponse as ModLtiGetToolLaunchDataResponse
    from poodle_async_full.models.mod_lti_get_tool_launch_data_response_parameters_inner import ModLtiGetToolLaunchDataResponseParametersInner as ModLtiGetToolLaunchDataResponseParametersInner
    from poodle_async_full.models.mod_lti_get_tool_proxies_response_inner import ModLtiGetToolProxiesResponseInner as ModLtiGetToolProxiesResponseInner
    from poodle_async_full.models.mod_lti_get_tool_proxy_registration_request_response import ModLtiGetToolProxyRegistrationRequestResponse as ModLtiGetToolProxyRegistrationRequestResponse
    from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_count_response import ModLtiGetToolTypesAndProxiesCountResponse as ModLtiGetToolTypesAndProxiesCountResponse
    from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response import ModLtiGetToolTypesAndProxiesResponse as ModLtiGetToolTypesAndProxiesResponse
    from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response_types_inner import ModLtiGetToolTypesAndProxiesResponseTypesInner as ModLtiGetToolTypesAndProxiesResponseTypesInner
    from poodle_async_full.models.mod_lti_is_cartridge_response import ModLtiIsCartridgeResponse as ModLtiIsCartridgeResponse
    from poodle_async_full.models.mod_lti_update_tool_type_response import ModLtiUpdateToolTypeResponse as ModLtiUpdateToolTypeResponse
    from poodle_async_full.models.mod_lti_view_lti_response import ModLtiViewLtiResponse as ModLtiViewLtiResponse
    from poodle_async_full.models.mod_page_get_pages_by_courses_response import ModPageGetPagesByCoursesResponse as ModPageGetPagesByCoursesResponse
    from poodle_async_full.models.mod_page_get_pages_by_courses_response_pages_inner import ModPageGetPagesByCoursesResponsePagesInner as ModPageGetPagesByCoursesResponsePagesInner
    from poodle_async_full.models.mod_page_view_page_response import ModPageViewPageResponse as ModPageViewPageResponse
    from poodle_async_full.models.mod_quiz_add_random_questions_response import ModQuizAddRandomQuestionsResponse as ModQuizAddRandomQuestionsResponse
    from poodle_async_full.models.mod_quiz_create_grade_items_parameters_quizgradeitems_inner import ModQuizCreateGradeItemsParametersQuizgradeitemsInner as ModQuizCreateGradeItemsParametersQuizgradeitemsInner
    from poodle_async_full.models.mod_quiz_delete_grade_items_parameters_quizgradeitems_inner import ModQuizDeleteGradeItemsParametersQuizgradeitemsInner as ModQuizDeleteGradeItemsParametersQuizgradeitemsInner
    from poodle_async_full.models.mod_quiz_delete_overrides_parameters_data import ModQuizDeleteOverridesParametersData as ModQuizDeleteOverridesParametersData
    from poodle_async_full.models.mod_quiz_delete_overrides_response import ModQuizDeleteOverridesResponse as ModQuizDeleteOverridesResponse
    from poodle_async_full.models.mod_quiz_get_attempt_access_information_response import ModQuizGetAttemptAccessInformationResponse as ModQuizGetAttemptAccessInformationResponse
    from poodle_async_full.models.mod_quiz_get_attempt_data_response import ModQuizGetAttemptDataResponse as ModQuizGetAttemptDataResponse
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt import ModQuizGetAttemptDataResponseAttempt as ModQuizGetAttemptDataResponseAttempt
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt_gradeitemmarks_inner import ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner as ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner import ModQuizGetAttemptDataResponseQuestionsInner as ModQuizGetAttemptDataResponseQuestionsInner
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner_responsefileareas_inner import ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner as ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner
    from poodle_async_full.models.mod_quiz_get_attempt_review_response import ModQuizGetAttemptReviewResponse as ModQuizGetAttemptReviewResponse
    from poodle_async_full.models.mod_quiz_get_attempt_review_response_additionaldata_inner import ModQuizGetAttemptReviewResponseAdditionaldataInner as ModQuizGetAttemptReviewResponseAdditionaldataInner
    from poodle_async_full.models.mod_quiz_get_attempt_summary_response import ModQuizGetAttemptSummaryResponse as ModQuizGetAttemptSummaryResponse
    from poodle_async_full.models.mod_quiz_get_combined_review_options_response import ModQuizGetCombinedReviewOptionsResponse as ModQuizGetCombinedReviewOptionsResponse
    from poodle_async_full.models.mod_quiz_get_combined_review_options_response_alloptions_inner import ModQuizGetCombinedReviewOptionsResponseAlloptionsInner as ModQuizGetCombinedReviewOptionsResponseAlloptionsInner
    from poodle_async_full.models.mod_quiz_get_overrides_response import ModQuizGetOverridesResponse as ModQuizGetOverridesResponse
    from poodle_async_full.models.mod_quiz_get_overrides_response_overrides_inner import ModQuizGetOverridesResponseOverridesInner as ModQuizGetOverridesResponseOverridesInner
    from poodle_async_full.models.mod_quiz_get_quiz_access_information_response import ModQuizGetQuizAccessInformationResponse as ModQuizGetQuizAccessInformationResponse
    from poodle_async_full.models.mod_quiz_get_quiz_feedback_for_grade_response import ModQuizGetQuizFeedbackForGradeResponse as ModQuizGetQuizFeedbackForGradeResponse
    from poodle_async_full.models.mod_quiz_get_quiz_required_qtypes_response import ModQuizGetQuizRequiredQtypesResponse as ModQuizGetQuizRequiredQtypesResponse
    from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response import ModQuizGetQuizzesByCoursesResponse as ModQuizGetQuizzesByCoursesResponse
    from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response_quizzes_inner import ModQuizGetQuizzesByCoursesResponseQuizzesInner as ModQuizGetQuizzesByCoursesResponseQuizzesInner
    from poodle_async_full.models.mod_quiz_get_user_attempts_response import ModQuizGetUserAttemptsResponse as ModQuizGetUserAttemptsResponse
    from poodle_async_full.models.mod_quiz_get_user_attempts_response_attempts_inner import ModQuizGetUserAttemptsResponseAttemptsInner as ModQuizGetUserAttemptsResponseAttemptsInner
    from poodle_async_full.models.mod_quiz_get_user_best_grade_response import ModQuizGetUserBestGradeResponse as ModQuizGetUserBestGradeResponse
    from poodle_async_full.models.mod_quiz_get_user_quiz_attempts_response import ModQuizGetUserQuizAttemptsResponse as ModQuizGetUserQuizAttemptsResponse
    from poodle_async_full.models.mod_quiz_process_attempt_response import ModQuizProcessAttemptResponse as ModQuizProcessAttemptResponse
    from poodle_async_full.models.mod_quiz_save_attempt_response import ModQuizSaveAttemptResponse as ModQuizSaveAttemptResponse
    from poodle_async_full.models.mod_quiz_save_overrides_parameters_data import ModQuizSaveOverridesParametersData as ModQuizSaveOverridesParametersData
    from poodle_async_full.models.mod_quiz_save_overrides_parameters_data_overrides_inner import ModQuizSaveOverridesParametersDataOverridesInner as ModQuizSaveOverridesParametersDataOverridesInner
    from poodle_async_full.models.mod_quiz_save_overrides_response import ModQuizSaveOverridesResponse as ModQuizSaveOverridesResponse
    from poodle_async_full.models.mod_quiz_set_question_version_response import ModQuizSetQuestionVersionResponse as ModQuizSetQuestionVersionResponse
    from poodle_async_full.models.mod_quiz_start_attempt_response import ModQuizStartAttemptResponse as ModQuizStartAttemptResponse
    from poodle_async_full.models.mod_quiz_update_filter_condition_response import ModQuizUpdateFilterConditionResponse as ModQuizUpdateFilterConditionResponse
    from poodle_async_full.models.mod_quiz_update_grade_items_parameters_quizgradeitems_inner import ModQuizUpdateGradeItemsParametersQuizgradeitemsInner as ModQuizUpdateGradeItemsParametersQuizgradeitemsInner
    from poodle_async_full.models.mod_quiz_update_slots_parameters_slots_inner import ModQuizUpdateSlotsParametersSlotsInner as ModQuizUpdateSlotsParametersSlotsInner
    from poodle_async_full.models.mod_quiz_view_attempt_response import ModQuizViewAttemptResponse as ModQuizViewAttemptResponse
    from poodle_async_full.models.mod_quiz_view_attempt_review_response import ModQuizViewAttemptReviewResponse as ModQuizViewAttemptReviewResponse
    from poodle_async_full.models.mod_quiz_view_attempt_summary_response import ModQuizViewAttemptSummaryResponse as ModQuizViewAttemptSummaryResponse
    from poodle_async_full.models.mod_quiz_view_quiz_response import ModQuizViewQuizResponse as ModQuizViewQuizResponse
    from poodle_async_full.models.mod_resource_get_resources_by_courses_response import ModResourceGetResourcesByCoursesResponse as ModResourceGetResourcesByCoursesResponse
    from poodle_async_full.models.mod_resource_get_resources_by_courses_response_resources_inner import ModResourceGetResourcesByCoursesResponseResourcesInner as ModResourceGetResourcesByCoursesResponseResourcesInner
    from poodle_async_full.models.mod_resource_view_resource_response import ModResourceViewResourceResponse as ModResourceViewResourceResponse
    from poodle_async_full.models.mod_scorm_get_scorm_access_information_response import ModScormGetScormAccessInformationResponse as ModScormGetScormAccessInformationResponse
    from poodle_async_full.models.mod_scorm_get_scorm_attempt_count_response import ModScormGetScormAttemptCountResponse as ModScormGetScormAttemptCountResponse
    from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response import ModScormGetScormScoTracksResponse as ModScormGetScormScoTracksResponse
    from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data import ModScormGetScormScoTracksResponseData as ModScormGetScormScoTracksResponseData
    from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data_tracks_inner import ModScormGetScormScoTracksResponseDataTracksInner as ModScormGetScormScoTracksResponseDataTracksInner
    from poodle_async_full.models.mod_scorm_get_scorm_scoes_response import ModScormGetScormScoesResponse as ModScormGetScormScoesResponse
    from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner import ModScormGetScormScoesResponseScoesInner as ModScormGetScormScoesResponseScoesInner
    from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner_extradata_inner import ModScormGetScormScoesResponseScoesInnerExtradataInner as ModScormGetScormScoesResponseScoesInnerExtradataInner
    from poodle_async_full.models.mod_scorm_get_scorm_user_data_response import ModScormGetScormUserDataResponse as ModScormGetScormUserDataResponse
    from poodle_async_full.models.mod_scorm_get_scorm_user_data_response_data_inner import ModScormGetScormUserDataResponseDataInner as ModScormGetScormUserDataResponseDataInner
    from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response import ModScormGetScormsByCoursesResponse as ModScormGetScormsByCoursesResponse
    from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_options_inner import ModScormGetScormsByCoursesResponseOptionsInner as ModScormGetScormsByCoursesResponseOptionsInner
    from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_scorms_inner import ModScormGetScormsByCoursesResponseScormsInner as ModScormGetScormsByCoursesResponseScormsInner
    from poodle_async_full.models.mod_scorm_insert_scorm_tracks_response import ModScormInsertScormTracksResponse as ModScormInsertScormTracksResponse
    from poodle_async_full.models.mod_scorm_launch_sco_response import ModScormLaunchScoResponse as ModScormLaunchScoResponse
    from poodle_async_full.models.mod_scorm_view_scorm_response import ModScormViewScormResponse as ModScormViewScormResponse
    from poodle_async_full.models.mod_url_get_urls_by_courses_response import ModUrlGetUrlsByCoursesResponse as ModUrlGetUrlsByCoursesResponse
    from poodle_async_full.models.mod_url_get_urls_by_courses_response_urls_inner import ModUrlGetUrlsByCoursesResponseUrlsInner as ModUrlGetUrlsByCoursesResponseUrlsInner
    from poodle_async_full.models.mod_url_view_url_response import ModUrlViewUrlResponse as ModUrlViewUrlResponse
    from poodle_async_full.models.mod_wiki_edit_page_response import ModWikiEditPageResponse as ModWikiEditPageResponse
    from poodle_async_full.models.mod_wiki_get_page_contents_response import ModWikiGetPageContentsResponse as ModWikiGetPageContentsResponse
    from poodle_async_full.models.mod_wiki_get_page_contents_response_page import ModWikiGetPageContentsResponsePage as ModWikiGetPageContentsResponsePage
    from poodle_async_full.models.mod_wiki_get_page_for_editing_response import ModWikiGetPageForEditingResponse as ModWikiGetPageForEditingResponse
    from poodle_async_full.models.mod_wiki_get_page_for_editing_response_pagesection import ModWikiGetPageForEditingResponsePagesection as ModWikiGetPageForEditingResponsePagesection
    from poodle_async_full.models.mod_wiki_get_subwiki_files_response import ModWikiGetSubwikiFilesResponse as ModWikiGetSubwikiFilesResponse
    from poodle_async_full.models.mod_wiki_get_subwiki_pages_parameters_options import ModWikiGetSubwikiPagesParametersOptions as ModWikiGetSubwikiPagesParametersOptions
    from poodle_async_full.models.mod_wiki_get_subwiki_pages_response import ModWikiGetSubwikiPagesResponse as ModWikiGetSubwikiPagesResponse
    from poodle_async_full.models.mod_wiki_get_subwiki_pages_response_pages_inner import ModWikiGetSubwikiPagesResponsePagesInner as ModWikiGetSubwikiPagesResponsePagesInner
    from poodle_async_full.models.mod_wiki_get_subwikis_response import ModWikiGetSubwikisResponse as ModWikiGetSubwikisResponse
    from poodle_async_full.models.mod_wiki_get_subwikis_response_subwikis_inner import ModWikiGetSubwikisResponseSubwikisInner as ModWikiGetSubwikisResponseSubwikisInner
    from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response import ModWikiGetWikisByCoursesResponse as ModWikiGetWikisByCoursesResponse
    from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response_wikis_inner import ModWikiGetWikisByCoursesResponseWikisInner as ModWikiGetWikisByCoursesResponseWikisInner
    from poodle_async_full.models.mod_wiki_new_page_response import ModWikiNewPageResponse as ModWikiNewPageResponse
    from poodle_async_full.models.mod_wiki_view_page_response import ModWikiViewPageResponse as ModWikiViewPageResponse
    from poodle_async_full.models.mod_wiki_view_wiki_response import ModWikiViewWikiResponse as ModWikiViewWikiResponse
    from poodle_async_full.models.mod_workshop_add_submission_response import ModWorkshopAddSubmissionResponse as ModWorkshopAddSubmissionResponse
    from poodle_async_full.models.mod_workshop_delete_submission_response import ModWorkshopDeleteSubmissionResponse as ModWorkshopDeleteSubmissionResponse
    from poodle_async_full.models.mod_workshop_evaluate_assessment_response import ModWorkshopEvaluateAssessmentResponse as ModWorkshopEvaluateAssessmentResponse
    from poodle_async_full.models.mod_workshop_evaluate_submission_response import ModWorkshopEvaluateSubmissionResponse as ModWorkshopEvaluateSubmissionResponse
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response import ModWorkshopGetAssessmentFormDefinitionResponse as ModWorkshopGetAssessmentFormDefinitionResponse
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_current_inner import ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner as ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_dimensionsinfo_inner import ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner as ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_fields_inner import ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner as ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_options_inner import ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner as ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner
    from poodle_async_full.models.mod_workshop_get_assessment_response import ModWorkshopGetAssessmentResponse as ModWorkshopGetAssessmentResponse
    from poodle_async_full.models.mod_workshop_get_assessment_response_assessment import ModWorkshopGetAssessmentResponseAssessment as ModWorkshopGetAssessmentResponseAssessment
    from poodle_async_full.models.mod_workshop_get_grades_report_response import ModWorkshopGetGradesReportResponse as ModWorkshopGetGradesReportResponse
    from poodle_async_full.models.mod_workshop_get_grades_report_response_report import ModWorkshopGetGradesReportResponseReport as ModWorkshopGetGradesReportResponseReport
    from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner import ModWorkshopGetGradesReportResponseReportGradesInner as ModWorkshopGetGradesReportResponseReportGradesInner
    from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner_reviewedby_inner import ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner as ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner
    from poodle_async_full.models.mod_workshop_get_grades_response import ModWorkshopGetGradesResponse as ModWorkshopGetGradesResponse
    from poodle_async_full.models.mod_workshop_get_reviewer_assessments_response import ModWorkshopGetReviewerAssessmentsResponse as ModWorkshopGetReviewerAssessmentsResponse
    from poodle_async_full.models.mod_workshop_get_submission_assessments_response import ModWorkshopGetSubmissionAssessmentsResponse as ModWorkshopGetSubmissionAssessmentsResponse
    from poodle_async_full.models.mod_workshop_get_submission_response import ModWorkshopGetSubmissionResponse as ModWorkshopGetSubmissionResponse
    from poodle_async_full.models.mod_workshop_get_submission_response_submission import ModWorkshopGetSubmissionResponseSubmission as ModWorkshopGetSubmissionResponseSubmission
    from poodle_async_full.models.mod_workshop_get_submissions_response import ModWorkshopGetSubmissionsResponse as ModWorkshopGetSubmissionsResponse
    from poodle_async_full.models.mod_workshop_get_user_plan_response import ModWorkshopGetUserPlanResponse as ModWorkshopGetUserPlanResponse
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan import ModWorkshopGetUserPlanResponseUserplan as ModWorkshopGetUserPlanResponseUserplan
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_examples_inner import ModWorkshopGetUserPlanResponseUserplanExamplesInner as ModWorkshopGetUserPlanResponseUserplanExamplesInner
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInner as ModWorkshopGetUserPlanResponseUserplanPhasesInner
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_actions_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner as ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_tasks_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner as ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner
    from poodle_async_full.models.mod_workshop_get_workshop_access_information_response import ModWorkshopGetWorkshopAccessInformationResponse as ModWorkshopGetWorkshopAccessInformationResponse
    from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response import ModWorkshopGetWorkshopsByCoursesResponse as ModWorkshopGetWorkshopsByCoursesResponse
    from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response_workshops_inner import ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner as ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner
    from poodle_async_full.models.mod_workshop_update_assessment_parameters_data_inner import ModWorkshopUpdateAssessmentParametersDataInner as ModWorkshopUpdateAssessmentParametersDataInner
    from poodle_async_full.models.mod_workshop_update_assessment_response import ModWorkshopUpdateAssessmentResponse as ModWorkshopUpdateAssessmentResponse
    from poodle_async_full.models.mod_workshop_update_submission_response import ModWorkshopUpdateSubmissionResponse as ModWorkshopUpdateSubmissionResponse
    from poodle_async_full.models.mod_workshop_view_submission_response import ModWorkshopViewSubmissionResponse as ModWorkshopViewSubmissionResponse
    from poodle_async_full.models.mod_workshop_view_workshop_response import ModWorkshopViewWorkshopResponse as ModWorkshopViewWorkshopResponse
    from poodle_async_full.models.paygw_paypal_create_transaction_complete_parameters import PaygwPaypalCreateTransactionCompleteParameters as PaygwPaypalCreateTransactionCompleteParameters
    from poodle_async_full.models.paygw_paypal_create_transaction_complete_response import PaygwPaypalCreateTransactionCompleteResponse as PaygwPaypalCreateTransactionCompleteResponse
    from poodle_async_full.models.paygw_paypal_get_config_for_js_response import PaygwPaypalGetConfigForJsResponse as PaygwPaypalGetConfigForJsResponse
    from poodle_async_full.models.qbank_editquestion_set_status_response import QbankEditquestionSetStatusResponse as QbankEditquestionSetStatusResponse
    from poodle_async_full.models.qbank_managecategories_move_category_response_inner import QbankManagecategoriesMoveCategoryResponseInner as QbankManagecategoriesMoveCategoryResponseInner
    from poodle_async_full.models.qbank_managecategories_move_category_response_inner_fields import QbankManagecategoriesMoveCategoryResponseInnerFields as QbankManagecategoriesMoveCategoryResponseInnerFields
    from poodle_async_full.models.qbank_tagquestion_submit_tags_form_response import QbankTagquestionSubmitTagsFormResponse as QbankTagquestionSubmitTagsFormResponse
    from poodle_async_full.models.quizaccess_seb_validate_quiz_keys_response import QuizaccessSebValidateQuizKeysResponse as QuizaccessSebValidateQuizKeysResponse
    from poodle_async_full.models.report_competency_data_for_report_response import ReportCompetencyDataForReportResponse as ReportCompetencyDataForReportResponse
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner import ReportCompetencyDataForReportResponseUsercompetenciesInner as ReportCompetencyDataForReportResponseUsercompetenciesInner
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency as ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath as ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath_ancestors_inner import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner as ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_usercompetencycourse import ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse as ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse
    from poodle_async_full.models.report_insights_action_executed_response import ReportInsightsActionExecutedResponse as ReportInsightsActionExecutedResponse
    from poodle_async_full.models.tiny_autosave_reset_session_parameters import TinyAutosaveResetSessionParameters as TinyAutosaveResetSessionParameters
    from poodle_async_full.models.tiny_autosave_resume_session_parameters import TinyAutosaveResumeSessionParameters as TinyAutosaveResumeSessionParameters
    from poodle_async_full.models.tiny_autosave_resume_session_response import TinyAutosaveResumeSessionResponse as TinyAutosaveResumeSessionResponse
    from poodle_async_full.models.tiny_autosave_update_session_parameters import TinyAutosaveUpdateSessionParameters as TinyAutosaveUpdateSessionParameters
    from poodle_async_full.models.tiny_equation_filter_response import TinyEquationFilterResponse as TinyEquationFilterResponse
    from poodle_async_full.models.tiny_media_preview_response import TinyMediaPreviewResponse as TinyMediaPreviewResponse
    from poodle_async_full.models.tiny_premium_get_api_key_response import TinyPremiumGetApiKeyResponse as TinyPremiumGetApiKeyResponse
    from poodle_async_full.models.tool_analytics_potential_contexts_response_inner import ToolAnalyticsPotentialContextsResponseInner as ToolAnalyticsPotentialContextsResponseInner
    from poodle_async_full.models.tool_behat_get_entity_generator_response import ToolBehatGetEntityGeneratorResponse as ToolBehatGetEntityGeneratorResponse
    from poodle_async_full.models.tool_dataprivacy_approve_data_request_response import ToolDataprivacyApproveDataRequestResponse as ToolDataprivacyApproveDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_bulk_approve_data_requests_response import ToolDataprivacyBulkApproveDataRequestsResponse as ToolDataprivacyBulkApproveDataRequestsResponse
    from poodle_async_full.models.tool_dataprivacy_bulk_deny_data_requests_response import ToolDataprivacyBulkDenyDataRequestsResponse as ToolDataprivacyBulkDenyDataRequestsResponse
    from poodle_async_full.models.tool_dataprivacy_cancel_data_request_response import ToolDataprivacyCancelDataRequestResponse as ToolDataprivacyCancelDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_confirm_contexts_for_deletion_response import ToolDataprivacyConfirmContextsForDeletionResponse as ToolDataprivacyConfirmContextsForDeletionResponse
    from poodle_async_full.models.tool_dataprivacy_contact_dpo_response import ToolDataprivacyContactDpoResponse as ToolDataprivacyContactDpoResponse
    from poodle_async_full.models.tool_dataprivacy_create_category_form_response import ToolDataprivacyCreateCategoryFormResponse as ToolDataprivacyCreateCategoryFormResponse
    from poodle_async_full.models.tool_dataprivacy_create_category_form_response_category import ToolDataprivacyCreateCategoryFormResponseCategory as ToolDataprivacyCreateCategoryFormResponseCategory
    from poodle_async_full.models.tool_dataprivacy_create_data_request_response import ToolDataprivacyCreateDataRequestResponse as ToolDataprivacyCreateDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response import ToolDataprivacyCreatePurposeFormResponse as ToolDataprivacyCreatePurposeFormResponse
    from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose import ToolDataprivacyCreatePurposeFormResponsePurpose as ToolDataprivacyCreatePurposeFormResponsePurpose
    from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose_formattedlawfulbases_inner import ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner as ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner
    from poodle_async_full.models.tool_dataprivacy_delete_category_response import ToolDataprivacyDeleteCategoryResponse as ToolDataprivacyDeleteCategoryResponse
    from poodle_async_full.models.tool_dataprivacy_delete_purpose_response import ToolDataprivacyDeletePurposeResponse as ToolDataprivacyDeletePurposeResponse
    from poodle_async_full.models.tool_dataprivacy_deny_data_request_response import ToolDataprivacyDenyDataRequestResponse as ToolDataprivacyDenyDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_get_access_information_response import ToolDataprivacyGetAccessInformationResponse as ToolDataprivacyGetAccessInformationResponse
    from poodle_async_full.models.tool_dataprivacy_get_activity_options_response import ToolDataprivacyGetActivityOptionsResponse as ToolDataprivacyGetActivityOptionsResponse
    from poodle_async_full.models.tool_dataprivacy_get_activity_options_response_options_inner import ToolDataprivacyGetActivityOptionsResponseOptionsInner as ToolDataprivacyGetActivityOptionsResponseOptionsInner
    from poodle_async_full.models.tool_dataprivacy_get_category_options_response import ToolDataprivacyGetCategoryOptionsResponse as ToolDataprivacyGetCategoryOptionsResponse
    from poodle_async_full.models.tool_dataprivacy_get_category_options_response_options_inner import ToolDataprivacyGetCategoryOptionsResponseOptionsInner as ToolDataprivacyGetCategoryOptionsResponseOptionsInner
    from poodle_async_full.models.tool_dataprivacy_get_data_request_response import ToolDataprivacyGetDataRequestResponse as ToolDataprivacyGetDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_get_data_request_response_result import ToolDataprivacyGetDataRequestResponseResult as ToolDataprivacyGetDataRequestResponseResult
    from poodle_async_full.models.tool_dataprivacy_get_data_requests_response import ToolDataprivacyGetDataRequestsResponse as ToolDataprivacyGetDataRequestsResponse
    from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response import ToolDataprivacyGetPurposeOptionsResponse as ToolDataprivacyGetPurposeOptionsResponse
    from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response_options_inner import ToolDataprivacyGetPurposeOptionsResponseOptionsInner as ToolDataprivacyGetPurposeOptionsResponseOptionsInner
    from poodle_async_full.models.tool_dataprivacy_mark_complete_response import ToolDataprivacyMarkCompleteResponse as ToolDataprivacyMarkCompleteResponse
    from poodle_async_full.models.tool_dataprivacy_set_context_defaults_response import ToolDataprivacySetContextDefaultsResponse as ToolDataprivacySetContextDefaultsResponse
    from poodle_async_full.models.tool_dataprivacy_set_context_form_response import ToolDataprivacySetContextFormResponse as ToolDataprivacySetContextFormResponse
    from poodle_async_full.models.tool_dataprivacy_set_contextlevel_form_response import ToolDataprivacySetContextlevelFormResponse as ToolDataprivacySetContextlevelFormResponse
    from poodle_async_full.models.tool_dataprivacy_submit_selected_courses_form_response import ToolDataprivacySubmitSelectedCoursesFormResponse as ToolDataprivacySubmitSelectedCoursesFormResponse
    from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response import ToolDataprivacyTreeExtraBranchesResponse as ToolDataprivacyTreeExtraBranchesResponse
    from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInner as ToolDataprivacyTreeExtraBranchesResponseBranchesInner
    from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner as ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner
    from poodle_async_full.models.tool_lp_data_for_competencies_manage_page_response import ToolLpDataForCompetenciesManagePageResponse as ToolLpDataForCompetenciesManagePageResponse
    from poodle_async_full.models.tool_lp_data_for_competency_frameworks_manage_page_response import ToolLpDataForCompetencyFrameworksManagePageResponse as ToolLpDataForCompetencyFrameworksManagePageResponse
    from poodle_async_full.models.tool_lp_data_for_competency_summary_response import ToolLpDataForCompetencySummaryResponse as ToolLpDataForCompetencySummaryResponse
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response import ToolLpDataForCourseCompetenciesPageResponse as ToolLpDataForCourseCompetenciesPageResponse
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner as ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_coursemodules_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner as ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_ruleoutcomeoptions_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner as ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_settings import ToolLpDataForCourseCompetenciesPageResponseSettings as ToolLpDataForCourseCompetenciesPageResponseSettings
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_statistics import ToolLpDataForCourseCompetenciesPageResponseStatistics as ToolLpDataForCourseCompetenciesPageResponseStatistics
    from poodle_async_full.models.tool_lp_data_for_plan_page_response import ToolLpDataForPlanPageResponse as ToolLpDataForPlanPageResponse
    from poodle_async_full.models.tool_lp_data_for_plan_page_response_competencies_inner import ToolLpDataForPlanPageResponseCompetenciesInner as ToolLpDataForPlanPageResponseCompetenciesInner
    from poodle_async_full.models.tool_lp_data_for_plans_page_response import ToolLpDataForPlansPageResponse as ToolLpDataForPlansPageResponse
    from poodle_async_full.models.tool_lp_data_for_related_competencies_section_response import ToolLpDataForRelatedCompetenciesSectionResponse as ToolLpDataForRelatedCompetenciesSectionResponse
    from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response import ToolLpDataForTemplateCompetenciesPageResponse as ToolLpDataForTemplateCompetenciesPageResponse
    from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response_statistics import ToolLpDataForTemplateCompetenciesPageResponseStatistics as ToolLpDataForTemplateCompetenciesPageResponseStatistics
    from poodle_async_full.models.tool_lp_data_for_templates_manage_page_response import ToolLpDataForTemplatesManagePageResponse as ToolLpDataForTemplatesManagePageResponse
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response import ToolLpDataForUserCompetencySummaryInCourseResponse as ToolLpDataForUserCompetencySummaryInCourseResponse
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary as ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary_evidence_inner import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner as ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_plan_response import ToolLpDataForUserCompetencySummaryInPlanResponse as ToolLpDataForUserCompetencySummaryInPlanResponse
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_response import ToolLpDataForUserCompetencySummaryResponse as ToolLpDataForUserCompetencySummaryResponse
    from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response import ToolLpDataForUserEvidenceListPageResponse as ToolLpDataForUserEvidenceListPageResponse
    from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInner as ToolLpDataForUserEvidenceListPageResponseEvidenceInner
    from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner_usercompetencies_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner as ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner
    from poodle_async_full.models.tool_lp_data_for_user_evidence_page_response import ToolLpDataForUserEvidencePageResponse as ToolLpDataForUserEvidencePageResponse
    from poodle_async_full.models.tool_lp_search_cohorts_response import ToolLpSearchCohortsResponse as ToolLpSearchCohortsResponse
    from poodle_async_full.models.tool_lp_search_users_response import ToolLpSearchUsersResponse as ToolLpSearchUsersResponse
    from poodle_async_full.models.tool_mobile_call_external_functions_parameters_requests_inner import ToolMobileCallExternalFunctionsParametersRequestsInner as ToolMobileCallExternalFunctionsParametersRequestsInner
    from poodle_async_full.models.tool_mobile_call_external_functions_response import ToolMobileCallExternalFunctionsResponse as ToolMobileCallExternalFunctionsResponse
    from poodle_async_full.models.tool_mobile_call_external_functions_response_responses_inner import ToolMobileCallExternalFunctionsResponseResponsesInner as ToolMobileCallExternalFunctionsResponseResponsesInner
    from poodle_async_full.models.tool_mobile_get_autologin_key_response import ToolMobileGetAutologinKeyResponse as ToolMobileGetAutologinKeyResponse
    from poodle_async_full.models.tool_mobile_get_config_response import ToolMobileGetConfigResponse as ToolMobileGetConfigResponse
    from poodle_async_full.models.tool_mobile_get_config_response_settings_inner import ToolMobileGetConfigResponseSettingsInner as ToolMobileGetConfigResponseSettingsInner
    from poodle_async_full.models.tool_mobile_get_content_parameters_args_inner import ToolMobileGetContentParametersArgsInner as ToolMobileGetContentParametersArgsInner
    from poodle_async_full.models.tool_mobile_get_content_response import ToolMobileGetContentResponse as ToolMobileGetContentResponse
    from poodle_async_full.models.tool_mobile_get_content_response_otherdata_inner import ToolMobileGetContentResponseOtherdataInner as ToolMobileGetContentResponseOtherdataInner
    from poodle_async_full.models.tool_mobile_get_content_response_restrict import ToolMobileGetContentResponseRestrict as ToolMobileGetContentResponseRestrict
    from poodle_async_full.models.tool_mobile_get_content_response_templates_inner import ToolMobileGetContentResponseTemplatesInner as ToolMobileGetContentResponseTemplatesInner
    from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response import ToolMobileGetPluginsSupportingMobileResponse as ToolMobileGetPluginsSupportingMobileResponse
    from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response_plugins_inner import ToolMobileGetPluginsSupportingMobileResponsePluginsInner as ToolMobileGetPluginsSupportingMobileResponsePluginsInner
    from poodle_async_full.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse as ToolMobileGetPublicConfigResponse
    from poodle_async_full.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner as ToolMobileGetPublicConfigResponseIdentityprovidersInner
    from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_parameters import ToolMobileGetTokensForQrLoginParameters as ToolMobileGetTokensForQrLoginParameters
    from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_response import ToolMobileGetTokensForQrLoginResponse as ToolMobileGetTokensForQrLoginResponse
    from poodle_async_full.models.tool_mobile_validate_subscription_key_parameters import ToolMobileValidateSubscriptionKeyParameters as ToolMobileValidateSubscriptionKeyParameters
    from poodle_async_full.models.tool_mobile_validate_subscription_key_response import ToolMobileValidateSubscriptionKeyResponse as ToolMobileValidateSubscriptionKeyResponse
    from poodle_async_full.models.tool_moodlenet_search_courses_response import ToolMoodlenetSearchCoursesResponse as ToolMoodlenetSearchCoursesResponse
    from poodle_async_full.models.tool_moodlenet_search_courses_response_courses_inner import ToolMoodlenetSearchCoursesResponseCoursesInner as ToolMoodlenetSearchCoursesResponseCoursesInner
    from poodle_async_full.models.tool_moodlenet_verify_webfinger_response import ToolMoodlenetVerifyWebfingerResponse as ToolMoodlenetVerifyWebfingerResponse
    from poodle_async_full.models.tool_policy_get_policy_version_parameters import ToolPolicyGetPolicyVersionParameters as ToolPolicyGetPolicyVersionParameters
    from poodle_async_full.models.tool_policy_get_policy_version_response import ToolPolicyGetPolicyVersionResponse as ToolPolicyGetPolicyVersionResponse
    from poodle_async_full.models.tool_policy_get_policy_version_response_result import ToolPolicyGetPolicyVersionResponseResult as ToolPolicyGetPolicyVersionResponseResult
    from poodle_async_full.models.tool_policy_get_policy_version_response_result_policy import ToolPolicyGetPolicyVersionResponseResultPolicy as ToolPolicyGetPolicyVersionResponseResultPolicy
    from poodle_async_full.models.tool_policy_get_user_acceptances_response import ToolPolicyGetUserAcceptancesResponse as ToolPolicyGetUserAcceptancesResponse
    from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner import ToolPolicyGetUserAcceptancesResponsePoliciesInner as ToolPolicyGetUserAcceptancesResponsePoliciesInner
    from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner_acceptance import ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance as ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance
    from poodle_async_full.models.tool_policy_set_acceptances_status_parameters_policies_inner import ToolPolicySetAcceptancesStatusParametersPoliciesInner as ToolPolicySetAcceptancesStatusParametersPoliciesInner
    from poodle_async_full.models.tool_policy_set_acceptances_status_response import ToolPolicySetAcceptancesStatusResponse as ToolPolicySetAcceptancesStatusResponse
    from poodle_async_full.models.tool_templatelibrary_list_templates_parameters import ToolTemplatelibraryListTemplatesParameters as ToolTemplatelibraryListTemplatesParameters
    from poodle_async_full.models.tool_templatelibrary_load_canonical_template_parameters import ToolTemplatelibraryLoadCanonicalTemplateParameters as ToolTemplatelibraryLoadCanonicalTemplateParameters
    from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response import ToolUsertoursFetchAndStartTourResponse as ToolUsertoursFetchAndStartTourResponse
    from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig import ToolUsertoursFetchAndStartTourResponseTourconfig as ToolUsertoursFetchAndStartTourResponseTourconfig
    from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig_steps_inner import ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner as ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner
    from poodle_async_full.models.tool_usertours_reset_tour_response import ToolUsertoursResetTourResponse as ToolUsertoursResetTourResponse
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            ("__version__", __version__),
            ("__all__", __all__),
            """# import apis into sdk package
from poodle_async_full.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from poodle_async_full.api_response import ApiResponse as ApiResponse
from poodle_async_full.api_client import ApiClient as ApiClient
from poodle_async_full.configuration import Configuration as Configuration
from poodle_async_full.configuration import settings as settings
from poodle_async_full.exceptions import OpenApiException as OpenApiException
from poodle_async_full.exceptions import ApiTypeError as ApiTypeError
from poodle_async_full.exceptions import ApiValueError as ApiValueError
from poodle_async_full.exceptions import ApiKeyError as ApiKeyError
from poodle_async_full.exceptions import ApiAttributeError as ApiAttributeError
from poodle_async_full.exceptions import ApiException as ApiException

# import models into sdk package
from poodle_async_full.models.aiplacement_courseassist_explain_text_response import AiplacementCourseassistExplainTextResponse as AiplacementCourseassistExplainTextResponse
from poodle_async_full.models.aiplacement_courseassist_summarise_text_response import AiplacementCourseassistSummariseTextResponse as AiplacementCourseassistSummariseTextResponse
from poodle_async_full.models.aiplacement_editor_generate_image_response import AiplacementEditorGenerateImageResponse as AiplacementEditorGenerateImageResponse
from poodle_async_full.models.aiplacement_editor_generate_text_response import AiplacementEditorGenerateTextResponse as AiplacementEditorGenerateTextResponse
from poodle_async_full.models.auth_email_get_signup_settings_response import AuthEmailGetSignupSettingsResponse as AuthEmailGetSignupSettingsResponse
from poodle_async_full.models.auth_email_get_signup_settings_response_profilefields_inner import AuthEmailGetSignupSettingsResponseProfilefieldsInner as AuthEmailGetSignupSettingsResponseProfilefieldsInner
from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner as AuthEmailGetSignupSettingsResponseWarningsInner
from poodle_async_full.models.auth_email_signup_user_parameters import AuthEmailSignupUserParameters as AuthEmailSignupUserParameters
from poodle_async_full.models.auth_email_signup_user_parameters_customprofilefields_inner import AuthEmailSignupUserParametersCustomprofilefieldsInner as AuthEmailSignupUserParametersCustomprofilefieldsInner
from poodle_async_full.models.auth_email_signup_user_response import AuthEmailSignupUserResponse as AuthEmailSignupUserResponse
from poodle_async_full.models.block_accessreview_get_module_data_response_inner import BlockAccessreviewGetModuleDataResponseInner as BlockAccessreviewGetModuleDataResponseInner
from poodle_async_full.models.block_accessreview_get_section_data_response_inner import BlockAccessreviewGetSectionDataResponseInner as BlockAccessreviewGetSectionDataResponseInner
from poodle_async_full.models.block_recentlyaccesseditems_get_recent_items_response_inner import BlockRecentlyaccesseditemsGetRecentItemsResponseInner as BlockRecentlyaccesseditemsGetRecentItemsResponseInner
from poodle_async_full.models.block_starredcourses_get_starred_courses_response_inner import BlockStarredcoursesGetStarredCoursesResponseInner as BlockStarredcoursesGetStarredCoursesResponseInner
from poodle_async_full.models.core_ai_delete_provider_instance_response import CoreAiDeleteProviderInstanceResponse as CoreAiDeleteProviderInstanceResponse
from poodle_async_full.models.core_ai_get_policy_status_response import CoreAiGetPolicyStatusResponse as CoreAiGetPolicyStatusResponse
from poodle_async_full.models.core_ai_set_policy_status_response import CoreAiSetPolicyStatusResponse as CoreAiSetPolicyStatusResponse
from poodle_async_full.models.core_ai_set_provider_status_response import CoreAiSetProviderStatusResponse as CoreAiSetProviderStatusResponse
from poodle_async_full.models.core_auth_confirm_user_parameters import CoreAuthConfirmUserParameters as CoreAuthConfirmUserParameters
from poodle_async_full.models.core_auth_confirm_user_response import CoreAuthConfirmUserResponse as CoreAuthConfirmUserResponse
from poodle_async_full.models.core_auth_is_age_digital_consent_verification_enabled_response import CoreAuthIsAgeDigitalConsentVerificationEnabledResponse as CoreAuthIsAgeDigitalConsentVerificationEnabledResponse
from poodle_async_full.models.core_auth_is_minor_parameters import CoreAuthIsMinorParameters as CoreAuthIsMinorParameters
from poodle_async_full.models.core_auth_is_minor_response import CoreAuthIsMinorResponse as CoreAuthIsMinorResponse
from poodle_async_full.models.core_auth_request_password_reset_parameters import CoreAuthRequestPasswordResetParameters as CoreAuthRequestPasswordResetParameters
from poodle_async_full.models.core_auth_request_password_reset_response import CoreAuthRequestPasswordResetResponse as CoreAuthRequestPasswordResetResponse
from poodle_async_full.models.core_auth_resend_confirmation_email_parameters import CoreAuthResendConfirmationEmailParameters as CoreAuthResendConfirmationEmailParameters
from poodle_async_full.models.core_auth_resend_confirmation_email_response import CoreAuthResendConfirmationEmailResponse as CoreAuthResendConfirmationEmailResponse
from poodle_async_full.models.core_backup_get_async_backup_links_backup_response import CoreBackupGetAsyncBackupLinksBackupResponse as CoreBackupGetAsyncBackupLinksBackupResponse
from poodle_async_full.models.core_backup_get_async_backup_links_restore_response import CoreBackupGetAsyncBackupLinksRestoreResponse as CoreBackupGetAsyncBackupLinksRestoreResponse
from poodle_async_full.models.core_backup_get_async_backup_progress_response_inner import CoreBackupGetAsyncBackupProgressResponseInner as CoreBackupGetAsyncBackupProgressResponseInner
from poodle_async_full.models.core_backup_get_copy_progress_parameters_copies_inner import CoreBackupGetCopyProgressParametersCopiesInner as CoreBackupGetCopyProgressParametersCopiesInner
from poodle_async_full.models.core_backup_get_copy_progress_response_inner import CoreBackupGetCopyProgressResponseInner as CoreBackupGetCopyProgressResponseInner
from poodle_async_full.models.core_badges_disable_badges_response import CoreBadgesDisableBadgesResponse as CoreBadgesDisableBadgesResponse
from poodle_async_full.models.core_badges_enable_badges_response import CoreBadgesEnableBadgesResponse as CoreBadgesEnableBadgesResponse
from poodle_async_full.models.core_badges_enable_badges_response_result_inner import CoreBadgesEnableBadgesResponseResultInner as CoreBadgesEnableBadgesResponseResultInner
from poodle_async_full.models.core_badges_get_badge_response import CoreBadgesGetBadgeResponse as CoreBadgesGetBadgeResponse
from poodle_async_full.models.core_badges_get_badge_response_badge import CoreBadgesGetBadgeResponseBadge as CoreBadgesGetBadgeResponseBadge
from poodle_async_full.models.core_badges_get_badge_response_badge_alignment_inner import CoreBadgesGetBadgeResponseBadgeAlignmentInner as CoreBadgesGetBadgeResponseBadgeAlignmentInner
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response import CoreBadgesGetUserBadgeByHashResponse as CoreBadgesGetUserBadgeByHashResponse
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInner as CoreBadgesGetUserBadgeByHashResponseBadgeInner
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_endorsement import CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement as CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_relatedbadges_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner as CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner
from poodle_async_full.models.core_badges_get_user_badges_response import CoreBadgesGetUserBadgesResponse as CoreBadgesGetUserBadgesResponse
from poodle_async_full.models.core_block_fetch_addable_blocks_response_inner import CoreBlockFetchAddableBlocksResponseInner as CoreBlockFetchAddableBlocksResponseInner
from poodle_async_full.models.core_block_get_course_blocks_response import CoreBlockGetCourseBlocksResponse as CoreBlockGetCourseBlocksResponse
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner import CoreBlockGetCourseBlocksResponseBlocksInner as CoreBlockGetCourseBlocksResponseBlocksInner
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_configs_inner import CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner as CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents import CoreBlockGetCourseBlocksResponseBlocksInnerContents as CoreBlockGetCourseBlocksResponseBlocksInnerContents
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner as CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from poodle_async_full.models.core_block_get_dashboard_blocks_response import CoreBlockGetDashboardBlocksResponse as CoreBlockGetDashboardBlocksResponse
from poodle_async_full.models.core_blog_add_entry_parameters_options_inner import CoreBlogAddEntryParametersOptionsInner as CoreBlogAddEntryParametersOptionsInner
from poodle_async_full.models.core_blog_add_entry_response import CoreBlogAddEntryResponse as CoreBlogAddEntryResponse
from poodle_async_full.models.core_blog_delete_entry_response import CoreBlogDeleteEntryResponse as CoreBlogDeleteEntryResponse
from poodle_async_full.models.core_blog_get_access_information_response import CoreBlogGetAccessInformationResponse as CoreBlogGetAccessInformationResponse
from poodle_async_full.models.core_blog_get_entries_parameters import CoreBlogGetEntriesParameters as CoreBlogGetEntriesParameters
from poodle_async_full.models.core_blog_get_entries_parameters_filters_inner import CoreBlogGetEntriesParametersFiltersInner as CoreBlogGetEntriesParametersFiltersInner
from poodle_async_full.models.core_blog_get_entries_response import CoreBlogGetEntriesResponse as CoreBlogGetEntriesResponse
from poodle_async_full.models.core_blog_get_entries_response_entries_inner import CoreBlogGetEntriesResponseEntriesInner as CoreBlogGetEntriesResponseEntriesInner
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner as CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner as CoreBlogGetEntriesResponseEntriesInnerTagsInner
from poodle_async_full.models.core_blog_prepare_entry_for_edition_response import CoreBlogPrepareEntryForEditionResponse as CoreBlogPrepareEntryForEditionResponse
from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner import CoreBlogPrepareEntryForEditionResponseAreasInner as CoreBlogPrepareEntryForEditionResponseAreasInner
from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner_options_inner import CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner as CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner
from poodle_async_full.models.core_blog_update_entry_response import CoreBlogUpdateEntryResponse as CoreBlogUpdateEntryResponse
from poodle_async_full.models.core_blog_view_entries_parameters import CoreBlogViewEntriesParameters as CoreBlogViewEntriesParameters
from poodle_async_full.models.core_blog_view_entries_parameters_filters_inner import CoreBlogViewEntriesParametersFiltersInner as CoreBlogViewEntriesParametersFiltersInner
from poodle_async_full.models.core_blog_view_entries_response import CoreBlogViewEntriesResponse as CoreBlogViewEntriesResponse
from poodle_async_full.models.core_calendar_create_calendar_events_parameters_events_inner import CoreCalendarCreateCalendarEventsParametersEventsInner as CoreCalendarCreateCalendarEventsParametersEventsInner
from poodle_async_full.models.core_calendar_create_calendar_events_response import CoreCalendarCreateCalendarEventsResponse as CoreCalendarCreateCalendarEventsResponse
from poodle_async_full.models.core_calendar_create_calendar_events_response_events_inner import CoreCalendarCreateCalendarEventsResponseEventsInner as CoreCalendarCreateCalendarEventsResponseEventsInner
from poodle_async_full.models.core_calendar_delete_calendar_events_parameters_events_inner import CoreCalendarDeleteCalendarEventsParametersEventsInner as CoreCalendarDeleteCalendarEventsParametersEventsInner
from poodle_async_full.models.core_calendar_delete_subscription_response import CoreCalendarDeleteSubscriptionResponse as CoreCalendarDeleteSubscriptionResponse
from poodle_async_full.models.core_calendar_get_action_events_by_course_response import CoreCalendarGetActionEventsByCourseResponse as CoreCalendarGetActionEventsByCourseResponse
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner import CoreCalendarGetActionEventsByCourseResponseEventsInner as CoreCalendarGetActionEventsByCourseResponseEventsInner
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_action import CoreCalendarGetActionEventsByCourseResponseEventsInnerAction as CoreCalendarGetActionEventsByCourseResponseEventsInnerAction
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_category import CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory as CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_icon import CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon as CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_subscription import CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription as CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription
from poodle_async_full.models.core_calendar_get_action_events_by_courses_response import CoreCalendarGetActionEventsByCoursesResponse as CoreCalendarGetActionEventsByCoursesResponse
from poodle_async_full.models.core_calendar_get_action_events_by_courses_response_groupedbycourse_inner import CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner as CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner
from poodle_async_full.models.core_calendar_get_action_events_by_timesort_response import CoreCalendarGetActionEventsByTimesortResponse as CoreCalendarGetActionEventsByTimesortResponse
from poodle_async_full.models.core_calendar_get_allowed_event_types_response import CoreCalendarGetAllowedEventTypesResponse as CoreCalendarGetAllowedEventTypesResponse
from poodle_async_full.models.core_calendar_get_calendar_access_information_response import CoreCalendarGetCalendarAccessInformationResponse as CoreCalendarGetCalendarAccessInformationResponse
from poodle_async_full.models.core_calendar_get_calendar_day_view_response import CoreCalendarGetCalendarDayViewResponse as CoreCalendarGetCalendarDayViewResponse
from poodle_async_full.models.core_calendar_get_calendar_day_view_response_date import CoreCalendarGetCalendarDayViewResponseDate as CoreCalendarGetCalendarDayViewResponseDate
from poodle_async_full.models.core_calendar_get_calendar_day_view_response_events_inner import CoreCalendarGetCalendarDayViewResponseEventsInner as CoreCalendarGetCalendarDayViewResponseEventsInner
from poodle_async_full.models.core_calendar_get_calendar_event_by_id_response import CoreCalendarGetCalendarEventByIdResponse as CoreCalendarGetCalendarEventByIdResponse
from poodle_async_full.models.core_calendar_get_calendar_events_parameters_events import CoreCalendarGetCalendarEventsParametersEvents as CoreCalendarGetCalendarEventsParametersEvents
from poodle_async_full.models.core_calendar_get_calendar_events_parameters_options import CoreCalendarGetCalendarEventsParametersOptions as CoreCalendarGetCalendarEventsParametersOptions
from poodle_async_full.models.core_calendar_get_calendar_events_response import CoreCalendarGetCalendarEventsResponse as CoreCalendarGetCalendarEventsResponse
from poodle_async_full.models.core_calendar_get_calendar_events_response_events_inner import CoreCalendarGetCalendarEventsResponseEventsInner as CoreCalendarGetCalendarEventsResponseEventsInner
from poodle_async_full.models.core_calendar_get_calendar_export_token_response import CoreCalendarGetCalendarExportTokenResponse as CoreCalendarGetCalendarExportTokenResponse
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response import CoreCalendarGetCalendarMonthlyViewResponse as CoreCalendarGetCalendarMonthlyViewResponse
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_daynames_inner import CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner as CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInner as CoreCalendarGetCalendarMonthlyViewResponseWeeksInner
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner_days_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner as CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner
from poodle_async_full.models.core_calendar_get_calendar_upcoming_view_response import CoreCalendarGetCalendarUpcomingViewResponse as CoreCalendarGetCalendarUpcomingViewResponse
from poodle_async_full.models.core_calendar_get_timestamps_parameters_data_inner import CoreCalendarGetTimestampsParametersDataInner as CoreCalendarGetTimestampsParametersDataInner
from poodle_async_full.models.core_calendar_get_timestamps_response import CoreCalendarGetTimestampsResponse as CoreCalendarGetTimestampsResponse
from poodle_async_full.models.core_calendar_get_timestamps_response_timestamps_inner import CoreCalendarGetTimestampsResponseTimestampsInner as CoreCalendarGetTimestampsResponseTimestampsInner
from poodle_async_full.models.core_calendar_submit_create_update_form_response import CoreCalendarSubmitCreateUpdateFormResponse as CoreCalendarSubmitCreateUpdateFormResponse
from poodle_async_full.models.core_calendar_update_event_start_day_response import CoreCalendarUpdateEventStartDayResponse as CoreCalendarUpdateEventStartDayResponse
from poodle_async_full.models.core_change_editmode_response import CoreChangeEditmodeResponse as CoreChangeEditmodeResponse
from poodle_async_full.models.core_check_get_result_admintree_response import CoreCheckGetResultAdmintreeResponse as CoreCheckGetResultAdmintreeResponse
from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner import CoreCohortAddCohortMembersParametersMembersInner as CoreCohortAddCohortMembersParametersMembersInner
from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_cohorttype import CoreCohortAddCohortMembersParametersMembersInnerCohorttype as CoreCohortAddCohortMembersParametersMembersInnerCohorttype
from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_usertype import CoreCohortAddCohortMembersParametersMembersInnerUsertype as CoreCohortAddCohortMembersParametersMembersInnerUsertype
from poodle_async_full.models.core_cohort_add_cohort_members_response import CoreCohortAddCohortMembersResponse as CoreCohortAddCohortMembersResponse
from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner import CoreCohortCreateCohortsParametersCohortsInner as CoreCohortCreateCohortsParametersCohortsInner
from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_categorytype import CoreCohortCreateCohortsParametersCohortsInnerCategorytype as CoreCohortCreateCohortsParametersCohortsInnerCategorytype
from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_customfields_inner import CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner as CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner
from poodle_async_full.models.core_cohort_create_cohorts_response_inner import CoreCohortCreateCohortsResponseInner as CoreCohortCreateCohortsResponseInner
from poodle_async_full.models.core_cohort_delete_cohort_members_parameters_members_inner import CoreCohortDeleteCohortMembersParametersMembersInner as CoreCohortDeleteCohortMembersParametersMembersInner
from poodle_async_full.models.core_cohort_get_cohort_members_response_inner import CoreCohortGetCohortMembersResponseInner as CoreCohortGetCohortMembersResponseInner
from poodle_async_full.models.core_cohort_get_cohorts_response_inner import CoreCohortGetCohortsResponseInner as CoreCohortGetCohortsResponseInner
from poodle_async_full.models.core_cohort_get_cohorts_response_inner_customfields_inner import CoreCohortGetCohortsResponseInnerCustomfieldsInner as CoreCohortGetCohortsResponseInnerCustomfieldsInner
from poodle_async_full.models.core_cohort_search_cohorts_parameters_context import CoreCohortSearchCohortsParametersContext as CoreCohortSearchCohortsParametersContext
from poodle_async_full.models.core_cohort_search_cohorts_response import CoreCohortSearchCohortsResponse as CoreCohortSearchCohortsResponse
from poodle_async_full.models.core_cohort_update_cohorts_parameters_cohorts_inner import CoreCohortUpdateCohortsParametersCohortsInner as CoreCohortUpdateCohortsParametersCohortsInner
from poodle_async_full.models.core_comment_add_comments_parameters_comments_inner import CoreCommentAddCommentsParametersCommentsInner as CoreCommentAddCommentsParametersCommentsInner
from poodle_async_full.models.core_comment_add_comments_response_inner import CoreCommentAddCommentsResponseInner as CoreCommentAddCommentsResponseInner
from poodle_async_full.models.core_comment_get_comments_response import CoreCommentGetCommentsResponse as CoreCommentGetCommentsResponse
from poodle_async_full.models.core_competency_count_competencies_parameters_filters_inner import CoreCompetencyCountCompetenciesParametersFiltersInner as CoreCompetencyCountCompetenciesParametersFiltersInner
from poodle_async_full.models.core_competency_create_competency_framework_parameters_competencyframework import CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework as CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework
from poodle_async_full.models.core_competency_create_competency_framework_response import CoreCompetencyCreateCompetencyFrameworkResponse as CoreCompetencyCreateCompetencyFrameworkResponse
from poodle_async_full.models.core_competency_create_competency_parameters_competency import CoreCompetencyCreateCompetencyParametersCompetency as CoreCompetencyCreateCompetencyParametersCompetency
from poodle_async_full.models.core_competency_create_competency_response import CoreCompetencyCreateCompetencyResponse as CoreCompetencyCreateCompetencyResponse
from poodle_async_full.models.core_competency_create_plan_parameters_plan import CoreCompetencyCreatePlanParametersPlan as CoreCompetencyCreatePlanParametersPlan
from poodle_async_full.models.core_competency_create_plan_response import CoreCompetencyCreatePlanResponse as CoreCompetencyCreatePlanResponse
from poodle_async_full.models.core_competency_create_plan_response_commentarea import CoreCompetencyCreatePlanResponseCommentarea as CoreCompetencyCreatePlanResponseCommentarea
from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer as CoreCompetencyCreatePlanResponseReviewer
from poodle_async_full.models.core_competency_create_plan_response_template import CoreCompetencyCreatePlanResponseTemplate as CoreCompetencyCreatePlanResponseTemplate
from poodle_async_full.models.core_competency_create_template_parameters_template import CoreCompetencyCreateTemplateParametersTemplate as CoreCompetencyCreateTemplateParametersTemplate
from poodle_async_full.models.core_competency_create_template_response import CoreCompetencyCreateTemplateResponse as CoreCompetencyCreateTemplateResponse
from poodle_async_full.models.core_competency_create_user_evidence_competency_response import CoreCompetencyCreateUserEvidenceCompetencyResponse as CoreCompetencyCreateUserEvidenceCompetencyResponse
from poodle_async_full.models.core_competency_duplicate_competency_framework_response import CoreCompetencyDuplicateCompetencyFrameworkResponse as CoreCompetencyDuplicateCompetencyFrameworkResponse
from poodle_async_full.models.core_competency_duplicate_template_response import CoreCompetencyDuplicateTemplateResponse as CoreCompetencyDuplicateTemplateResponse
from poodle_async_full.models.core_competency_get_scale_values_response_inner import CoreCompetencyGetScaleValuesResponseInner as CoreCompetencyGetScaleValuesResponseInner
from poodle_async_full.models.core_competency_grade_competency_in_course_response import CoreCompetencyGradeCompetencyInCourseResponse as CoreCompetencyGradeCompetencyInCourseResponse
from poodle_async_full.models.core_competency_grade_competency_in_plan_response import CoreCompetencyGradeCompetencyInPlanResponse as CoreCompetencyGradeCompetencyInPlanResponse
from poodle_async_full.models.core_competency_grade_competency_response import CoreCompetencyGradeCompetencyResponse as CoreCompetencyGradeCompetencyResponse
from poodle_async_full.models.core_competency_list_competencies_in_template_response_inner import CoreCompetencyListCompetenciesInTemplateResponseInner as CoreCompetencyListCompetenciesInTemplateResponseInner
from poodle_async_full.models.core_competency_list_competency_frameworks_response_inner import CoreCompetencyListCompetencyFrameworksResponseInner as CoreCompetencyListCompetencyFrameworksResponseInner
from poodle_async_full.models.core_competency_list_course_competencies_response_inner import CoreCompetencyListCourseCompetenciesResponseInner as CoreCompetencyListCourseCompetenciesResponseInner
from poodle_async_full.models.core_competency_list_course_competencies_response_inner_coursecompetency import CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency as CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency
from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner import CoreCompetencyListCourseModuleCompetenciesResponseInner as CoreCompetencyListCourseModuleCompetenciesResponseInner
from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner_coursemodulecompetency import CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency as CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency
from poodle_async_full.models.core_competency_list_plan_competencies_response_inner import CoreCompetencyListPlanCompetenciesResponseInner as CoreCompetencyListPlanCompetenciesResponseInner
from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetency import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency as CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency
from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetencyplan import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan as CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan
from poodle_async_full.models.core_competency_list_user_plans_response_inner import CoreCompetencyListUserPlansResponseInner as CoreCompetencyListUserPlansResponseInner
from poodle_async_full.models.core_competency_read_competency_framework_response import CoreCompetencyReadCompetencyFrameworkResponse as CoreCompetencyReadCompetencyFrameworkResponse
from poodle_async_full.models.core_competency_read_competency_response import CoreCompetencyReadCompetencyResponse as CoreCompetencyReadCompetencyResponse
from poodle_async_full.models.core_competency_read_plan_response import CoreCompetencyReadPlanResponse as CoreCompetencyReadPlanResponse
from poodle_async_full.models.core_competency_read_template_response import CoreCompetencyReadTemplateResponse as CoreCompetencyReadTemplateResponse
from poodle_async_full.models.core_competency_read_user_evidence_response import CoreCompetencyReadUserEvidenceResponse as CoreCompetencyReadUserEvidenceResponse
from poodle_async_full.models.core_competency_read_user_evidence_response_files_inner import CoreCompetencyReadUserEvidenceResponseFilesInner as CoreCompetencyReadUserEvidenceResponseFilesInner
from poodle_async_full.models.core_competency_update_competency_framework_parameters_competencyframework import CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework as CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework
from poodle_async_full.models.core_competency_update_competency_parameters_competency import CoreCompetencyUpdateCompetencyParametersCompetency as CoreCompetencyUpdateCompetencyParametersCompetency
from poodle_async_full.models.core_competency_update_course_competency_settings_parameters_settings import CoreCompetencyUpdateCourseCompetencySettingsParametersSettings as CoreCompetencyUpdateCourseCompetencySettingsParametersSettings
from poodle_async_full.models.core_competency_update_plan_parameters_plan import CoreCompetencyUpdatePlanParametersPlan as CoreCompetencyUpdatePlanParametersPlan
from poodle_async_full.models.core_competency_update_plan_response import CoreCompetencyUpdatePlanResponse as CoreCompetencyUpdatePlanResponse
from poodle_async_full.models.core_competency_update_template_parameters_template import CoreCompetencyUpdateTemplateParametersTemplate as CoreCompetencyUpdateTemplateParametersTemplate
from poodle_async_full.models.core_completion_get_activities_completion_status_response import CoreCompletionGetActivitiesCompletionStatusResponse as CoreCompletionGetActivitiesCompletionStatusResponse
from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner as CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner
from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner as CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner
from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner_rulevalue import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue as CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue
from poodle_async_full.models.core_completion_get_course_completion_status_response import CoreCompletionGetCourseCompletionStatusResponse as CoreCompletionGetCourseCompletionStatusResponse
from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus import CoreCompletionGetCourseCompletionStatusResponseCompletionstatus as CoreCompletionGetCourseCompletionStatusResponseCompletionstatus
from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner as CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner
from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner_details import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails as CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails
from poodle_async_full.models.core_completion_mark_course_self_completed_response import CoreCompletionMarkCourseSelfCompletedResponse as CoreCompletionMarkCourseSelfCompletedResponse
from poodle_async_full.models.core_completion_override_activity_completion_status_response import CoreCompletionOverrideActivityCompletionStatusResponse as CoreCompletionOverrideActivityCompletionStatusResponse
from poodle_async_full.models.core_completion_update_activity_completion_status_manually_response import CoreCompletionUpdateActivityCompletionStatusManuallyResponse as CoreCompletionUpdateActivityCompletionStatusManuallyResponse
from poodle_async_full.models.core_contentbank_copy_content_response import CoreContentbankCopyContentResponse as CoreContentbankCopyContentResponse
from poodle_async_full.models.core_contentbank_delete_content_response import CoreContentbankDeleteContentResponse as CoreContentbankDeleteContentResponse
from poodle_async_full.models.core_contentbank_rename_content_response import CoreContentbankRenameContentResponse as CoreContentbankRenameContentResponse
from poodle_async_full.models.core_contentbank_set_content_visibility_response import CoreContentbankSetContentVisibilityResponse as CoreContentbankSetContentVisibilityResponse
from poodle_async_full.models.core_course_add_content_item_to_user_favourites_response import CoreCourseAddContentItemToUserFavouritesResponse as CoreCourseAddContentItemToUserFavouritesResponse
from poodle_async_full.models.core_course_check_updates_parameters_tocheck_inner import CoreCourseCheckUpdatesParametersTocheckInner as CoreCourseCheckUpdatesParametersTocheckInner
from poodle_async_full.models.core_course_check_updates_response import CoreCourseCheckUpdatesResponse as CoreCourseCheckUpdatesResponse
from poodle_async_full.models.core_course_check_updates_response_instances_inner import CoreCourseCheckUpdatesResponseInstancesInner as CoreCourseCheckUpdatesResponseInstancesInner
from poodle_async_full.models.core_course_check_updates_response_instances_inner_updates_inner import CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner as CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner
from poodle_async_full.models.core_course_create_categories_parameters_categories_inner import CoreCourseCreateCategoriesParametersCategoriesInner as CoreCourseCreateCategoriesParametersCategoriesInner
from poodle_async_full.models.core_course_create_categories_response_inner import CoreCourseCreateCategoriesResponseInner as CoreCourseCreateCategoriesResponseInner
from poodle_async_full.models.core_course_create_courses_parameters_courses_inner import CoreCourseCreateCoursesParametersCoursesInner as CoreCourseCreateCoursesParametersCoursesInner
from poodle_async_full.models.core_course_create_courses_parameters_courses_inner_courseformatoptions_inner import CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner as CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner
from poodle_async_full.models.core_course_create_courses_response_inner import CoreCourseCreateCoursesResponseInner as CoreCourseCreateCoursesResponseInner
from poodle_async_full.models.core_course_delete_categories_parameters_categories_inner import CoreCourseDeleteCategoriesParametersCategoriesInner as CoreCourseDeleteCategoriesParametersCategoriesInner
from poodle_async_full.models.core_course_delete_courses_response import CoreCourseDeleteCoursesResponse as CoreCourseDeleteCoursesResponse
from poodle_async_full.models.core_course_duplicate_course_parameters_options_inner import CoreCourseDuplicateCourseParametersOptionsInner as CoreCourseDuplicateCourseParametersOptionsInner
from poodle_async_full.models.core_course_duplicate_course_response import CoreCourseDuplicateCourseResponse as CoreCourseDuplicateCourseResponse
from poodle_async_full.models.core_course_get_activity_chooser_footer_response import CoreCourseGetActivityChooserFooterResponse as CoreCourseGetActivityChooserFooterResponse
from poodle_async_full.models.core_course_get_categories_parameters_criteria_inner import CoreCourseGetCategoriesParametersCriteriaInner as CoreCourseGetCategoriesParametersCriteriaInner
from poodle_async_full.models.core_course_get_categories_response_inner import CoreCourseGetCategoriesResponseInner as CoreCourseGetCategoriesResponseInner
from poodle_async_full.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner as CoreCourseGetContentsParametersOptionsInner
from poodle_async_full.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner as CoreCourseGetContentsResponseInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner as CoreCourseGetContentsResponseInnerModulesInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge as CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata as CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo as CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner as CoreCourseGetContentsResponseInnerModulesInnerDatesInner
from poodle_async_full.models.core_course_get_course_content_items_response import CoreCourseGetCourseContentItemsResponse as CoreCourseGetCourseContentItemsResponse
from poodle_async_full.models.core_course_get_course_content_items_response_content_items_inner import CoreCourseGetCourseContentItemsResponseContentItemsInner as CoreCourseGetCourseContentItemsResponseContentItemsInner
from poodle_async_full.models.core_course_get_course_module_by_instance_response import CoreCourseGetCourseModuleByInstanceResponse as CoreCourseGetCourseModuleByInstanceResponse
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm import CoreCourseGetCourseModuleByInstanceResponseCm as CoreCourseGetCourseModuleByInstanceResponseCm
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_advancedgrading_inner import CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner as CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_outcomes_inner import CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner as CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner
from poodle_async_full.models.core_course_get_course_module_response import CoreCourseGetCourseModuleResponse as CoreCourseGetCourseModuleResponse
from poodle_async_full.models.core_course_get_courses_by_field_response import CoreCourseGetCoursesByFieldResponse as CoreCourseGetCoursesByFieldResponse
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner import CoreCourseGetCoursesByFieldResponseCoursesInner as CoreCourseGetCoursesByFieldResponseCoursesInner
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_contacts_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner as CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_courseformatoptions_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner as CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_filters_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner as CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner
from poodle_async_full.models.core_course_get_courses_parameters_options import CoreCourseGetCoursesParametersOptions as CoreCourseGetCoursesParametersOptions
from poodle_async_full.models.core_course_get_courses_response_inner import CoreCourseGetCoursesResponseInner as CoreCourseGetCoursesResponseInner
from poodle_async_full.models.core_course_get_courses_response_inner_customfields_inner import CoreCourseGetCoursesResponseInnerCustomfieldsInner as CoreCourseGetCoursesResponseInnerCustomfieldsInner
from poodle_async_full.models.core_course_get_enrolled_courses_by_timeline_classification_response import CoreCourseGetEnrolledCoursesByTimelineClassificationResponse as CoreCourseGetEnrolledCoursesByTimelineClassificationResponse
from poodle_async_full.models.core_course_get_enrolled_courses_with_action_events_by_timeline_classification_response import CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse as CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse
from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response import CoreCourseGetEnrolledUsersByCmidResponse as CoreCourseGetEnrolledUsersByCmidResponse
from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response_users_inner import CoreCourseGetEnrolledUsersByCmidResponseUsersInner as CoreCourseGetEnrolledUsersByCmidResponseUsersInner
from poodle_async_full.models.core_course_get_updates_since_response import CoreCourseGetUpdatesSinceResponse as CoreCourseGetUpdatesSinceResponse
from poodle_async_full.models.core_course_get_user_administration_options_response import CoreCourseGetUserAdministrationOptionsResponse as CoreCourseGetUserAdministrationOptionsResponse
from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInner as CoreCourseGetUserAdministrationOptionsResponseCoursesInner
from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner_options_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner as CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner
from poodle_async_full.models.core_course_get_user_navigation_options_response import CoreCourseGetUserNavigationOptionsResponse as CoreCourseGetUserNavigationOptionsResponse
from poodle_async_full.models.core_course_import_course_parameters_options_inner import CoreCourseImportCourseParametersOptionsInner as CoreCourseImportCourseParametersOptionsInner
from poodle_async_full.models.core_course_remove_content_item_from_user_favourites_response import CoreCourseRemoveContentItemFromUserFavouritesResponse as CoreCourseRemoveContentItemFromUserFavouritesResponse
from poodle_async_full.models.core_course_search_courses_response import CoreCourseSearchCoursesResponse as CoreCourseSearchCoursesResponse
from poodle_async_full.models.core_course_search_courses_response_courses_inner import CoreCourseSearchCoursesResponseCoursesInner as CoreCourseSearchCoursesResponseCoursesInner
from poodle_async_full.models.core_course_set_favourite_courses_parameters_courses_inner import CoreCourseSetFavouriteCoursesParametersCoursesInner as CoreCourseSetFavouriteCoursesParametersCoursesInner
from poodle_async_full.models.core_course_set_favourite_courses_response import CoreCourseSetFavouriteCoursesResponse as CoreCourseSetFavouriteCoursesResponse
from poodle_async_full.models.core_course_toggle_activity_recommendation_response import CoreCourseToggleActivityRecommendationResponse as CoreCourseToggleActivityRecommendationResponse
from poodle_async_full.models.core_course_update_categories_parameters_categories_inner import CoreCourseUpdateCategoriesParametersCategoriesInner as CoreCourseUpdateCategoriesParametersCategoriesInner
from poodle_async_full.models.core_course_update_courses_parameters_courses_inner import CoreCourseUpdateCoursesParametersCoursesInner as CoreCourseUpdateCoursesParametersCoursesInner
from poodle_async_full.models.core_course_update_courses_response import CoreCourseUpdateCoursesResponse as CoreCourseUpdateCoursesResponse
from poodle_async_full.models.core_course_view_course_response import CoreCourseViewCourseResponse as CoreCourseViewCourseResponse
from poodle_async_full.models.core_courseformat_file_handlers_response_inner import CoreCourseformatFileHandlersResponseInner as CoreCourseformatFileHandlersResponseInner
from poodle_async_full.models.core_customfield_reload_template_response import CoreCustomfieldReloadTemplateResponse as CoreCustomfieldReloadTemplateResponse
from poodle_async_full.models.core_customfield_reload_template_response_categories_inner import CoreCustomfieldReloadTemplateResponseCategoriesInner as CoreCustomfieldReloadTemplateResponseCategoriesInner
from poodle_async_full.models.core_customfield_reload_template_response_categories_inner_fields_inner import CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner as CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner
from poodle_async_full.models.core_dynamic_tabs_get_content_response import CoreDynamicTabsGetContentResponse as CoreDynamicTabsGetContentResponse
from poodle_async_full.models.core_enrol_get_course_enrolment_methods_response_inner import CoreEnrolGetCourseEnrolmentMethodsResponseInner as CoreEnrolGetCourseEnrolmentMethodsResponseInner
from poodle_async_full.models.core_enrol_get_enrolled_users_parameters_options_inner import CoreEnrolGetEnrolledUsersParametersOptionsInner as CoreEnrolGetEnrolledUsersParametersOptionsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner import CoreEnrolGetEnrolledUsersResponseInner as CoreEnrolGetEnrolledUsersResponseInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_customfields_inner import CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner as CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_enrolledcourses_inner import CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner as CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_groups_inner import CoreEnrolGetEnrolledUsersResponseInnerGroupsInner as CoreEnrolGetEnrolledUsersResponseInnerGroupsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_preferences_inner import CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner as CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_roles_inner import CoreEnrolGetEnrolledUsersResponseInnerRolesInner as CoreEnrolGetEnrolledUsersResponseInnerRolesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_parameters_coursecapabilities_inner import CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner as CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_customfields_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_groups_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner as CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner import CoreEnrolGetPotentialUsersResponseInner as CoreEnrolGetPotentialUsersResponseInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner_customfields_inner import CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner as CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner_preferences_inner import CoreEnrolGetPotentialUsersResponseInnerPreferencesInner as CoreEnrolGetPotentialUsersResponseInnerPreferencesInner
from poodle_async_full.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner as CoreEnrolGetUsersCoursesResponseInner
from poodle_async_full.models.core_enrol_submit_user_enrolment_form_response import CoreEnrolSubmitUserEnrolmentFormResponse as CoreEnrolSubmitUserEnrolmentFormResponse
from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response import CoreEnrolUnenrolUserEnrolmentResponse as CoreEnrolUnenrolUserEnrolmentResponse
from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response_errors_inner import CoreEnrolUnenrolUserEnrolmentResponseErrorsInner as CoreEnrolUnenrolUserEnrolmentResponseErrorsInner
from poodle_async_full.models.core_fetch_notifications_parameters import CoreFetchNotificationsParameters as CoreFetchNotificationsParameters
from poodle_async_full.models.core_fetch_notifications_response_inner import CoreFetchNotificationsResponseInner as CoreFetchNotificationsResponseInner
from poodle_async_full.models.core_fetch_notifications_response_inner_variables import CoreFetchNotificationsResponseInnerVariables as CoreFetchNotificationsResponseInnerVariables
from poodle_async_full.models.core_files_delete_draft_files_parameters_files_inner import CoreFilesDeleteDraftFilesParametersFilesInner as CoreFilesDeleteDraftFilesParametersFilesInner
from poodle_async_full.models.core_files_delete_draft_files_response import CoreFilesDeleteDraftFilesResponse as CoreFilesDeleteDraftFilesResponse
from poodle_async_full.models.core_files_get_files_response import CoreFilesGetFilesResponse as CoreFilesGetFilesResponse
from poodle_async_full.models.core_files_get_files_response_files_inner import CoreFilesGetFilesResponseFilesInner as CoreFilesGetFilesResponseFilesInner
from poodle_async_full.models.core_files_get_files_response_parents_inner import CoreFilesGetFilesResponseParentsInner as CoreFilesGetFilesResponseParentsInner
from poodle_async_full.models.core_files_get_unused_draft_itemid_response import CoreFilesGetUnusedDraftItemidResponse as CoreFilesGetUnusedDraftItemidResponse
from poodle_async_full.models.core_files_upload_response import CoreFilesUploadResponse as CoreFilesUploadResponse
from poodle_async_full.models.core_filters_get_all_states_response import CoreFiltersGetAllStatesResponse as CoreFiltersGetAllStatesResponse
from poodle_async_full.models.core_filters_get_all_states_response_filters_inner import CoreFiltersGetAllStatesResponseFiltersInner as CoreFiltersGetAllStatesResponseFiltersInner
from poodle_async_full.models.core_filters_get_available_in_context_parameters_contexts_inner import CoreFiltersGetAvailableInContextParametersContextsInner as CoreFiltersGetAvailableInContextParametersContextsInner
from poodle_async_full.models.core_filters_get_available_in_context_response import CoreFiltersGetAvailableInContextResponse as CoreFiltersGetAvailableInContextResponse
from poodle_async_full.models.core_filters_get_available_in_context_response_filters_inner import CoreFiltersGetAvailableInContextResponseFiltersInner as CoreFiltersGetAvailableInContextResponseFiltersInner
from poodle_async_full.models.core_form_dynamic_form_response import CoreFormDynamicFormResponse as CoreFormDynamicFormResponse
from poodle_async_full.models.core_form_get_filetypes_browser_data_parameters import CoreFormGetFiletypesBrowserDataParameters as CoreFormGetFiletypesBrowserDataParameters
from poodle_async_full.models.core_form_get_filetypes_browser_data_response import CoreFormGetFiletypesBrowserDataResponse as CoreFormGetFiletypesBrowserDataResponse
from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInner as CoreFormGetFiletypesBrowserDataResponseGroupsInner
from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner_types_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner as CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner
from poodle_async_full.models.core_get_component_strings_parameters import CoreGetComponentStringsParameters as CoreGetComponentStringsParameters
from poodle_async_full.models.core_get_component_strings_response_inner import CoreGetComponentStringsResponseInner as CoreGetComponentStringsResponseInner
from poodle_async_full.models.core_get_fragment_parameters_args_inner import CoreGetFragmentParametersArgsInner as CoreGetFragmentParametersArgsInner
from poodle_async_full.models.core_get_fragment_response import CoreGetFragmentResponse as CoreGetFragmentResponse
from poodle_async_full.models.core_get_string_parameters import CoreGetStringParameters as CoreGetStringParameters
from poodle_async_full.models.core_get_string_parameters_stringparams_inner import CoreGetStringParametersStringparamsInner as CoreGetStringParametersStringparamsInner
from poodle_async_full.models.core_get_strings_parameters import CoreGetStringsParameters as CoreGetStringsParameters
from poodle_async_full.models.core_get_strings_parameters_strings_inner import CoreGetStringsParametersStringsInner as CoreGetStringsParametersStringsInner
from poodle_async_full.models.core_get_strings_parameters_strings_inner_stringparams_inner import CoreGetStringsParametersStringsInnerStringparamsInner as CoreGetStringsParametersStringsInnerStringparamsInner
from poodle_async_full.models.core_get_strings_response_inner import CoreGetStringsResponseInner as CoreGetStringsResponseInner
from poodle_async_full.models.core_get_user_dates_parameters_timestamps_inner import CoreGetUserDatesParametersTimestampsInner as CoreGetUserDatesParametersTimestampsInner
from poodle_async_full.models.core_get_user_dates_response import CoreGetUserDatesResponse as CoreGetUserDatesResponse
from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner import CoreGradesCreateGradecategoriesParametersCategoriesInner as CoreGradesCreateGradecategoriesParametersCategoriesInner
from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner_options import CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions as CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions
from poodle_async_full.models.core_grades_create_gradecategories_response import CoreGradesCreateGradecategoriesResponse as CoreGradesCreateGradecategoriesResponse
from poodle_async_full.models.core_grades_get_enrolled_users_for_selector_response import CoreGradesGetEnrolledUsersForSelectorResponse as CoreGradesGetEnrolledUsersForSelectorResponse
from poodle_async_full.models.core_grades_get_feedback_response import CoreGradesGetFeedbackResponse as CoreGradesGetFeedbackResponse
from poodle_async_full.models.core_grades_get_gradable_users_response import CoreGradesGetGradableUsersResponse as CoreGradesGetGradableUsersResponse
from poodle_async_full.models.core_grades_get_gradeitems_response import CoreGradesGetGradeitemsResponse as CoreGradesGetGradeitemsResponse
from poodle_async_full.models.core_grades_get_gradeitems_response_grade_items_inner import CoreGradesGetGradeitemsResponseGradeItemsInner as CoreGradesGetGradeitemsResponseGradeItemsInner
from poodle_async_full.models.core_grades_get_groups_for_selector_response import CoreGradesGetGroupsForSelectorResponse as CoreGradesGetGroupsForSelectorResponse
from poodle_async_full.models.core_grades_get_groups_for_selector_response_groups_inner import CoreGradesGetGroupsForSelectorResponseGroupsInner as CoreGradesGetGroupsForSelectorResponseGroupsInner
from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response import CoreGradesGraderGradingpanelPointFetchResponse as CoreGradesGraderGradingpanelPointFetchResponse
from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response_grade import CoreGradesGraderGradingpanelPointFetchResponseGrade as CoreGradesGraderGradingpanelPointFetchResponseGrade
from poodle_async_full.models.core_grades_grader_gradingpanel_point_store_response import CoreGradesGraderGradingpanelPointStoreResponse as CoreGradesGraderGradingpanelPointStoreResponse
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response import CoreGradesGraderGradingpanelScaleFetchResponse as CoreGradesGraderGradingpanelScaleFetchResponse
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade import CoreGradesGraderGradingpanelScaleFetchResponseGrade as CoreGradesGraderGradingpanelScaleFetchResponseGrade
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade_options_inner import CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner as CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_store_response import CoreGradesGraderGradingpanelScaleStoreResponse as CoreGradesGraderGradingpanelScaleStoreResponse
from poodle_async_full.models.core_grades_update_grades_parameters_grades_inner import CoreGradesUpdateGradesParametersGradesInner as CoreGradesUpdateGradesParametersGradesInner
from poodle_async_full.models.core_grades_update_grades_parameters_itemdetails import CoreGradesUpdateGradesParametersItemdetails as CoreGradesUpdateGradesParametersItemdetails
from poodle_async_full.models.core_grading_get_definitions_response import CoreGradingGetDefinitionsResponse as CoreGradingGetDefinitionsResponse
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner import CoreGradingGetDefinitionsResponseAreasInner as CoreGradingGetDefinitionsResponseAreasInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_comments_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner_levels_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner as CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner
from poodle_async_full.models.core_grading_get_gradingform_instances_response import CoreGradingGetGradingformInstancesResponse as CoreGradingGetGradingformInstancesResponse
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner import CoreGradingGetGradingformInstancesResponseInstancesInner as CoreGradingGetGradingformInstancesResponseInstancesInner
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide import CoreGradingGetGradingformInstancesResponseInstancesInnerGuide as CoreGradingGetGradingformInstancesResponseInstancesInnerGuide
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner as CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric import CoreGradingGetGradingformInstancesResponseInstancesInnerRubric as CoreGradingGetGradingformInstancesResponseInstancesInnerRubric
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner as CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner
from poodle_async_full.models.core_group_add_group_members_parameters_members_inner import CoreGroupAddGroupMembersParametersMembersInner as CoreGroupAddGroupMembersParametersMembersInner
from poodle_async_full.models.core_group_assign_grouping_parameters_assignments_inner import CoreGroupAssignGroupingParametersAssignmentsInner as CoreGroupAssignGroupingParametersAssignmentsInner
from poodle_async_full.models.core_group_create_groupings_parameters_groupings_inner import CoreGroupCreateGroupingsParametersGroupingsInner as CoreGroupCreateGroupingsParametersGroupingsInner
from poodle_async_full.models.core_group_create_groupings_response_inner import CoreGroupCreateGroupingsResponseInner as CoreGroupCreateGroupingsResponseInner
from poodle_async_full.models.core_group_create_groups_parameters_groups_inner import CoreGroupCreateGroupsParametersGroupsInner as CoreGroupCreateGroupsParametersGroupsInner
from poodle_async_full.models.core_group_create_groups_response_inner import CoreGroupCreateGroupsResponseInner as CoreGroupCreateGroupsResponseInner
from poodle_async_full.models.core_group_get_activity_allowed_groups_response import CoreGroupGetActivityAllowedGroupsResponse as CoreGroupGetActivityAllowedGroupsResponse
from poodle_async_full.models.core_group_get_activity_allowed_groups_response_groups_inner import CoreGroupGetActivityAllowedGroupsResponseGroupsInner as CoreGroupGetActivityAllowedGroupsResponseGroupsInner
from poodle_async_full.models.core_group_get_activity_groupmode_response import CoreGroupGetActivityGroupmodeResponse as CoreGroupGetActivityGroupmodeResponse
from poodle_async_full.models.core_group_get_course_groupings_response_inner import CoreGroupGetCourseGroupingsResponseInner as CoreGroupGetCourseGroupingsResponseInner
from poodle_async_full.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner as CoreGroupGetCourseGroupsResponseInner
from poodle_async_full.models.core_group_get_course_user_groups_response import CoreGroupGetCourseUserGroupsResponse as CoreGroupGetCourseUserGroupsResponse
from poodle_async_full.models.core_group_get_group_members_response_inner import CoreGroupGetGroupMembersResponseInner as CoreGroupGetGroupMembersResponseInner
from poodle_async_full.models.core_group_get_groupings_response_inner import CoreGroupGetGroupingsResponseInner as CoreGroupGetGroupingsResponseInner
from poodle_async_full.models.core_group_get_groupings_response_inner_groups_inner import CoreGroupGetGroupingsResponseInnerGroupsInner as CoreGroupGetGroupingsResponseInnerGroupsInner
from poodle_async_full.models.core_group_get_groups_for_selector_response import CoreGroupGetGroupsForSelectorResponse as CoreGroupGetGroupsForSelectorResponse
from poodle_async_full.models.core_group_get_groups_response_inner import CoreGroupGetGroupsResponseInner as CoreGroupGetGroupsResponseInner
from poodle_async_full.models.core_group_update_groupings_parameters_groupings_inner import CoreGroupUpdateGroupingsParametersGroupingsInner as CoreGroupUpdateGroupingsParametersGroupingsInner
from poodle_async_full.models.core_group_update_groups_parameters_groups_inner import CoreGroupUpdateGroupsParametersGroupsInner as CoreGroupUpdateGroupsParametersGroupsInner
from poodle_async_full.models.core_h5p_get_trusted_h5p_file_response import CoreH5pGetTrustedH5pFileResponse as CoreH5pGetTrustedH5pFileResponse
from poodle_async_full.models.core_message_create_contact_request_response import CoreMessageCreateContactRequestResponse as CoreMessageCreateContactRequestResponse
from poodle_async_full.models.core_message_create_contact_request_response_request import CoreMessageCreateContactRequestResponseRequest as CoreMessageCreateContactRequestResponseRequest
from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response import CoreMessageDataForMessageareaSearchMessagesResponse as CoreMessageDataForMessageareaSearchMessagesResponse
from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response_contacts_inner import CoreMessageDataForMessageareaSearchMessagesResponseContactsInner as CoreMessageDataForMessageareaSearchMessagesResponseContactsInner
from poodle_async_full.models.core_message_delete_message_response import CoreMessageDeleteMessageResponse as CoreMessageDeleteMessageResponse
from poodle_async_full.models.core_message_get_blocked_users_response import CoreMessageGetBlockedUsersResponse as CoreMessageGetBlockedUsersResponse
from poodle_async_full.models.core_message_get_blocked_users_response_users_inner import CoreMessageGetBlockedUsersResponseUsersInner as CoreMessageGetBlockedUsersResponseUsersInner
from poodle_async_full.models.core_message_get_contact_requests_response_inner import CoreMessageGetContactRequestsResponseInner as CoreMessageGetContactRequestsResponseInner
from poodle_async_full.models.core_message_get_contact_requests_response_inner_contactrequests_inner import CoreMessageGetContactRequestsResponseInnerContactrequestsInner as CoreMessageGetContactRequestsResponseInnerContactrequestsInner
from poodle_async_full.models.core_message_get_contact_requests_response_inner_conversations_inner import CoreMessageGetContactRequestsResponseInnerConversationsInner as CoreMessageGetContactRequestsResponseInnerConversationsInner
from poodle_async_full.models.core_message_get_conversation_between_users_response import CoreMessageGetConversationBetweenUsersResponse as CoreMessageGetConversationBetweenUsersResponse
from poodle_async_full.models.core_message_get_conversation_between_users_response_messages_inner import CoreMessageGetConversationBetweenUsersResponseMessagesInner as CoreMessageGetConversationBetweenUsersResponseMessagesInner
from poodle_async_full.models.core_message_get_conversation_counts_response import CoreMessageGetConversationCountsResponse as CoreMessageGetConversationCountsResponse
from poodle_async_full.models.core_message_get_conversation_counts_response_types import CoreMessageGetConversationCountsResponseTypes as CoreMessageGetConversationCountsResponseTypes
from poodle_async_full.models.core_message_get_conversation_messages_response import CoreMessageGetConversationMessagesResponse as CoreMessageGetConversationMessagesResponse
from poodle_async_full.models.core_message_get_conversation_response import CoreMessageGetConversationResponse as CoreMessageGetConversationResponse
from poodle_async_full.models.core_message_get_conversations_response import CoreMessageGetConversationsResponse as CoreMessageGetConversationsResponse
from poodle_async_full.models.core_message_get_conversations_response_conversations_inner import CoreMessageGetConversationsResponseConversationsInner as CoreMessageGetConversationsResponseConversationsInner
from poodle_async_full.models.core_message_get_message_processor_response import CoreMessageGetMessageProcessorResponse as CoreMessageGetMessageProcessorResponse
from poodle_async_full.models.core_message_get_messages_response import CoreMessageGetMessagesResponse as CoreMessageGetMessagesResponse
from poodle_async_full.models.core_message_get_messages_response_messages_inner import CoreMessageGetMessagesResponseMessagesInner as CoreMessageGetMessagesResponseMessagesInner
from poodle_async_full.models.core_message_get_self_conversation_response import CoreMessageGetSelfConversationResponse as CoreMessageGetSelfConversationResponse
from poodle_async_full.models.core_message_get_unread_conversation_counts_response import CoreMessageGetUnreadConversationCountsResponse as CoreMessageGetUnreadConversationCountsResponse
from poodle_async_full.models.core_message_get_unread_conversation_counts_response_types import CoreMessageGetUnreadConversationCountsResponseTypes as CoreMessageGetUnreadConversationCountsResponseTypes
from poodle_async_full.models.core_message_get_unsent_message_response import CoreMessageGetUnsentMessageResponse as CoreMessageGetUnsentMessageResponse
from poodle_async_full.models.core_message_get_user_message_preferences_response import CoreMessageGetUserMessagePreferencesResponse as CoreMessageGetUserMessagePreferencesResponse
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences import CoreMessageGetUserMessagePreferencesResponsePreferences as CoreMessageGetUserMessagePreferencesResponsePreferences
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner as CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner
from poodle_async_full.models.core_message_get_user_notification_preferences_response import CoreMessageGetUserNotificationPreferencesResponse as CoreMessageGetUserNotificationPreferencesResponse
from poodle_async_full.models.core_message_mark_message_read_response import CoreMessageMarkMessageReadResponse as CoreMessageMarkMessageReadResponse
from poodle_async_full.models.core_message_mark_notification_read_response import CoreMessageMarkNotificationReadResponse as CoreMessageMarkNotificationReadResponse
from poodle_async_full.models.core_message_message_processor_config_form_parameters_formvalues_inner import CoreMessageMessageProcessorConfigFormParametersFormvaluesInner as CoreMessageMessageProcessorConfigFormParametersFormvaluesInner
from poodle_async_full.models.core_message_message_search_users_response import CoreMessageMessageSearchUsersResponse as CoreMessageMessageSearchUsersResponse
from poodle_async_full.models.core_message_search_contacts_response_inner import CoreMessageSearchContactsResponseInner as CoreMessageSearchContactsResponseInner
from poodle_async_full.models.core_message_send_instant_messages_parameters_messages_inner import CoreMessageSendInstantMessagesParametersMessagesInner as CoreMessageSendInstantMessagesParametersMessagesInner
from poodle_async_full.models.core_message_send_instant_messages_response_inner import CoreMessageSendInstantMessagesResponseInner as CoreMessageSendInstantMessagesResponseInner
from poodle_async_full.models.core_message_send_messages_to_conversation_parameters_messages_inner import CoreMessageSendMessagesToConversationParametersMessagesInner as CoreMessageSendMessagesToConversationParametersMessagesInner
from poodle_async_full.models.core_message_set_default_notification_response import CoreMessageSetDefaultNotificationResponse as CoreMessageSetDefaultNotificationResponse
from poodle_async_full.models.core_moodlenet_auth_check_response import CoreMoodlenetAuthCheckResponse as CoreMoodlenetAuthCheckResponse
from poodle_async_full.models.core_moodlenet_get_share_info_activity_response import CoreMoodlenetGetShareInfoActivityResponse as CoreMoodlenetGetShareInfoActivityResponse
from poodle_async_full.models.core_moodlenet_get_shared_course_info_response import CoreMoodlenetGetSharedCourseInfoResponse as CoreMoodlenetGetSharedCourseInfoResponse
from poodle_async_full.models.core_moodlenet_send_activity_response import CoreMoodlenetSendActivityResponse as CoreMoodlenetSendActivityResponse
from poodle_async_full.models.core_moodlenet_send_course_response import CoreMoodlenetSendCourseResponse as CoreMoodlenetSendCourseResponse
from poodle_async_full.models.core_my_view_page_response import CoreMyViewPageResponse as CoreMyViewPageResponse
from poodle_async_full.models.core_notes_create_notes_parameters_notes_inner import CoreNotesCreateNotesParametersNotesInner as CoreNotesCreateNotesParametersNotesInner
from poodle_async_full.models.core_notes_create_notes_response_inner import CoreNotesCreateNotesResponseInner as CoreNotesCreateNotesResponseInner
from poodle_async_full.models.core_notes_delete_notes_response_inner import CoreNotesDeleteNotesResponseInner as CoreNotesDeleteNotesResponseInner
from poodle_async_full.models.core_notes_get_course_notes_response import CoreNotesGetCourseNotesResponse as CoreNotesGetCourseNotesResponse
from poodle_async_full.models.core_notes_get_course_notes_response_coursenotes_inner import CoreNotesGetCourseNotesResponseCoursenotesInner as CoreNotesGetCourseNotesResponseCoursenotesInner
from poodle_async_full.models.core_notes_get_notes_response import CoreNotesGetNotesResponse as CoreNotesGetNotesResponse
from poodle_async_full.models.core_notes_get_notes_response_notes_inner import CoreNotesGetNotesResponseNotesInner as CoreNotesGetNotesResponseNotesInner
from poodle_async_full.models.core_notes_update_notes_parameters_notes_inner import CoreNotesUpdateNotesParametersNotesInner as CoreNotesUpdateNotesParametersNotesInner
from poodle_async_full.models.core_notes_view_notes_response import CoreNotesViewNotesResponse as CoreNotesViewNotesResponse
from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_parameters import CoreOutputLoadFontawesomeIconSystemMapParameters as CoreOutputLoadFontawesomeIconSystemMapParameters
from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_response_inner import CoreOutputLoadFontawesomeIconSystemMapResponseInner as CoreOutputLoadFontawesomeIconSystemMapResponseInner
from poodle_async_full.models.core_output_load_template_parameters import CoreOutputLoadTemplateParameters as CoreOutputLoadTemplateParameters
from poodle_async_full.models.core_output_load_template_with_dependencies_parameters import CoreOutputLoadTemplateWithDependenciesParameters as CoreOutputLoadTemplateWithDependenciesParameters
from poodle_async_full.models.core_output_load_template_with_dependencies_response import CoreOutputLoadTemplateWithDependenciesResponse as CoreOutputLoadTemplateWithDependenciesResponse
from poodle_async_full.models.core_output_load_template_with_dependencies_response_strings_inner import CoreOutputLoadTemplateWithDependenciesResponseStringsInner as CoreOutputLoadTemplateWithDependenciesResponseStringsInner
from poodle_async_full.models.core_output_poll_stored_progress_response_inner import CoreOutputPollStoredProgressResponseInner as CoreOutputPollStoredProgressResponseInner
from poodle_async_full.models.core_payment_get_available_gateways_response_inner import CorePaymentGetAvailableGatewaysResponseInner as CorePaymentGetAvailableGatewaysResponseInner
from poodle_async_full.models.core_question_get_random_question_summaries_response import CoreQuestionGetRandomQuestionSummariesResponse as CoreQuestionGetRandomQuestionSummariesResponse
from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner as CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner
from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner_icon import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon as CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon
from poodle_async_full.models.core_question_search_shared_banks_response import CoreQuestionSearchSharedBanksResponse as CoreQuestionSearchSharedBanksResponse
from poodle_async_full.models.core_question_search_shared_banks_response_sharedbanks_inner import CoreQuestionSearchSharedBanksResponseSharedbanksInner as CoreQuestionSearchSharedBanksResponseSharedbanksInner
from poodle_async_full.models.core_question_update_flag_response import CoreQuestionUpdateFlagResponse as CoreQuestionUpdateFlagResponse
from poodle_async_full.models.core_rating_add_rating_response import CoreRatingAddRatingResponse as CoreRatingAddRatingResponse
from poodle_async_full.models.core_rating_get_item_ratings_response import CoreRatingGetItemRatingsResponse as CoreRatingGetItemRatingsResponse
from poodle_async_full.models.core_rating_get_item_ratings_response_ratings_inner import CoreRatingGetItemRatingsResponseRatingsInner as CoreRatingGetItemRatingsResponseRatingsInner
from poodle_async_full.models.core_reportbuilder_can_view_system_report_parameters_parameters_inner import CoreReportbuilderCanViewSystemReportParametersParametersInner as CoreReportbuilderCanViewSystemReportParametersParametersInner
from poodle_async_full.models.core_reportbuilder_columns_add_response import CoreReportbuilderColumnsAddResponse as CoreReportbuilderColumnsAddResponse
from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner import CoreReportbuilderColumnsAddResponseSortablecolumnsInner as CoreReportbuilderColumnsAddResponseSortablecolumnsInner
from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner_sorticon import CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon as CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon
from poodle_async_full.models.core_reportbuilder_columns_delete_response import CoreReportbuilderColumnsDeleteResponse as CoreReportbuilderColumnsDeleteResponse
from poodle_async_full.models.core_reportbuilder_columns_sort_get_response import CoreReportbuilderColumnsSortGetResponse as CoreReportbuilderColumnsSortGetResponse
from poodle_async_full.models.core_reportbuilder_columns_sort_reorder_response import CoreReportbuilderColumnsSortReorderResponse as CoreReportbuilderColumnsSortReorderResponse
from poodle_async_full.models.core_reportbuilder_columns_sort_toggle_response import CoreReportbuilderColumnsSortToggleResponse as CoreReportbuilderColumnsSortToggleResponse
from poodle_async_full.models.core_reportbuilder_conditions_add_response import CoreReportbuilderConditionsAddResponse as CoreReportbuilderConditionsAddResponse
from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInner as CoreReportbuilderConditionsAddResponseAvailableconditionsInner
from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup as CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup
from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup_values_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner as CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner
from poodle_async_full.models.core_reportbuilder_conditions_delete_response import CoreReportbuilderConditionsDeleteResponse as CoreReportbuilderConditionsDeleteResponse
from poodle_async_full.models.core_reportbuilder_conditions_reorder_response import CoreReportbuilderConditionsReorderResponse as CoreReportbuilderConditionsReorderResponse
from poodle_async_full.models.core_reportbuilder_conditions_reset_response import CoreReportbuilderConditionsResetResponse as CoreReportbuilderConditionsResetResponse
from poodle_async_full.models.core_reportbuilder_filters_add_response import CoreReportbuilderFiltersAddResponse as CoreReportbuilderFiltersAddResponse
from poodle_async_full.models.core_reportbuilder_filters_add_response_activefilters_inner import CoreReportbuilderFiltersAddResponseActivefiltersInner as CoreReportbuilderFiltersAddResponseActivefiltersInner
from poodle_async_full.models.core_reportbuilder_filters_delete_response import CoreReportbuilderFiltersDeleteResponse as CoreReportbuilderFiltersDeleteResponse
from poodle_async_full.models.core_reportbuilder_filters_reorder_response import CoreReportbuilderFiltersReorderResponse as CoreReportbuilderFiltersReorderResponse
from poodle_async_full.models.core_reportbuilder_list_reports_response import CoreReportbuilderListReportsResponse as CoreReportbuilderListReportsResponse
from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner import CoreReportbuilderListReportsResponseReportsInner as CoreReportbuilderListReportsResponseReportsInner
from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields import CoreReportbuilderListReportsResponseReportsInnerCustomfields as CoreReportbuilderListReportsResponseReportsInnerCustomfields
from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields_data_inner import CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner as CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner
from poodle_async_full.models.core_reportbuilder_reports_get_response import CoreReportbuilderReportsGetResponse as CoreReportbuilderReportsGetResponse
from poodle_async_full.models.core_reportbuilder_reports_get_response_attributes_inner import CoreReportbuilderReportsGetResponseAttributesInner as CoreReportbuilderReportsGetResponseAttributesInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_button import CoreReportbuilderReportsGetResponseButton as CoreReportbuilderReportsGetResponseButton
from poodle_async_full.models.core_reportbuilder_reports_get_response_button_attributes_inner import CoreReportbuilderReportsGetResponseButtonAttributesInner as CoreReportbuilderReportsGetResponseButtonAttributesInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_cardview import CoreReportbuilderReportsGetResponseCardview as CoreReportbuilderReportsGetResponseCardview
from poodle_async_full.models.core_reportbuilder_reports_get_response_conditions import CoreReportbuilderReportsGetResponseConditions as CoreReportbuilderReportsGetResponseConditions
from poodle_async_full.models.core_reportbuilder_reports_get_response_filters import CoreReportbuilderReportsGetResponseFilters as CoreReportbuilderReportsGetResponseFilters
from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards import CoreReportbuilderReportsGetResponseSidebarmenucards as CoreReportbuilderReportsGetResponseSidebarmenucards
from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner as CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner_items_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner as CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_sorting import CoreReportbuilderReportsGetResponseSorting as CoreReportbuilderReportsGetResponseSorting
from poodle_async_full.models.core_reportbuilder_retrieve_report_response import CoreReportbuilderRetrieveReportResponse as CoreReportbuilderRetrieveReportResponse
from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data import CoreReportbuilderRetrieveReportResponseData as CoreReportbuilderRetrieveReportResponseData
from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data_rows_inner import CoreReportbuilderRetrieveReportResponseDataRowsInner as CoreReportbuilderRetrieveReportResponseDataRowsInner
from poodle_async_full.models.core_reportbuilder_retrieve_system_report_response import CoreReportbuilderRetrieveSystemReportResponse as CoreReportbuilderRetrieveSystemReportResponse
from poodle_async_full.models.core_reportbuilder_view_report_response import CoreReportbuilderViewReportResponse as CoreReportbuilderViewReportResponse
from poodle_async_full.models.core_role_assign_roles_parameters_assignments_inner import CoreRoleAssignRolesParametersAssignmentsInner as CoreRoleAssignRolesParametersAssignmentsInner
from poodle_async_full.models.core_role_unassign_roles_parameters_unassignments_inner import CoreRoleUnassignRolesParametersUnassignmentsInner as CoreRoleUnassignRolesParametersUnassignmentsInner
from poodle_async_full.models.core_search_get_relevant_users_response_inner import CoreSearchGetRelevantUsersResponseInner as CoreSearchGetRelevantUsersResponseInner
from poodle_async_full.models.core_search_get_results_parameters_filters import CoreSearchGetResultsParametersFilters as CoreSearchGetResultsParametersFilters
from poodle_async_full.models.core_search_get_results_response import CoreSearchGetResultsResponse as CoreSearchGetResultsResponse
from poodle_async_full.models.core_search_get_results_response_results_inner import CoreSearchGetResultsResponseResultsInner as CoreSearchGetResultsResponseResultsInner
from poodle_async_full.models.core_search_get_search_areas_list_response import CoreSearchGetSearchAreasListResponse as CoreSearchGetSearchAreasListResponse
from poodle_async_full.models.core_search_get_search_areas_list_response_areas_inner import CoreSearchGetSearchAreasListResponseAreasInner as CoreSearchGetSearchAreasListResponseAreasInner
from poodle_async_full.models.core_search_get_top_results_response import CoreSearchGetTopResultsResponse as CoreSearchGetTopResultsResponse
from poodle_async_full.models.core_search_view_results_parameters_filters import CoreSearchViewResultsParametersFilters as CoreSearchViewResultsParametersFilters
from poodle_async_full.models.core_search_view_results_response import CoreSearchViewResultsResponse as CoreSearchViewResultsResponse
from poodle_async_full.models.core_session_time_remaining_response import CoreSessionTimeRemainingResponse as CoreSessionTimeRemainingResponse
from poodle_async_full.models.core_sms_set_gateway_status_response import CoreSmsSetGatewayStatusResponse as CoreSmsSetGatewayStatusResponse
from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner import CoreTableGetDynamicTableContentParametersFiltersInner as CoreTableGetDynamicTableContentParametersFiltersInner
from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner_filteroptions_inner import CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner as CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner
from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_sortdata_inner import CoreTableGetDynamicTableContentParametersSortdataInner as CoreTableGetDynamicTableContentParametersSortdataInner
from poodle_async_full.models.core_table_get_dynamic_table_content_response import CoreTableGetDynamicTableContentResponse as CoreTableGetDynamicTableContentResponse
from poodle_async_full.models.core_tag_get_tag_areas_response import CoreTagGetTagAreasResponse as CoreTagGetTagAreasResponse
from poodle_async_full.models.core_tag_get_tag_areas_response_areas_inner import CoreTagGetTagAreasResponseAreasInner as CoreTagGetTagAreasResponseAreasInner
from poodle_async_full.models.core_tag_get_tag_cloud_response import CoreTagGetTagCloudResponse as CoreTagGetTagCloudResponse
from poodle_async_full.models.core_tag_get_tag_cloud_response_tags_inner import CoreTagGetTagCloudResponseTagsInner as CoreTagGetTagCloudResponseTagsInner
from poodle_async_full.models.core_tag_get_tag_collections_response import CoreTagGetTagCollectionsResponse as CoreTagGetTagCollectionsResponse
from poodle_async_full.models.core_tag_get_tag_collections_response_collections_inner import CoreTagGetTagCollectionsResponseCollectionsInner as CoreTagGetTagCollectionsResponseCollectionsInner
from poodle_async_full.models.core_tag_get_tagindex_parameters_tagindex import CoreTagGetTagindexParametersTagindex as CoreTagGetTagindexParametersTagindex
from poodle_async_full.models.core_tag_get_tagindex_per_area_parameters_tagindex import CoreTagGetTagindexPerAreaParametersTagindex as CoreTagGetTagindexPerAreaParametersTagindex
from poodle_async_full.models.core_tag_get_tagindex_per_area_response_inner import CoreTagGetTagindexPerAreaResponseInner as CoreTagGetTagindexPerAreaResponseInner
from poodle_async_full.models.core_tag_get_tagindex_response import CoreTagGetTagindexResponse as CoreTagGetTagindexResponse
from poodle_async_full.models.core_tag_get_tags_parameters_tags_inner import CoreTagGetTagsParametersTagsInner as CoreTagGetTagsParametersTagsInner
from poodle_async_full.models.core_tag_get_tags_response import CoreTagGetTagsResponse as CoreTagGetTagsResponse
from poodle_async_full.models.core_tag_get_tags_response_tags_inner import CoreTagGetTagsResponseTagsInner as CoreTagGetTagsResponseTagsInner
from poodle_async_full.models.core_tag_update_tags_parameters_tags_inner import CoreTagUpdateTagsParametersTagsInner as CoreTagUpdateTagsParametersTagsInner
from poodle_async_full.models.core_tag_update_tags_response import CoreTagUpdateTagsResponse as CoreTagUpdateTagsResponse
from poodle_async_full.models.core_update_inplace_editable_response import CoreUpdateInplaceEditableResponse as CoreUpdateInplaceEditableResponse
from poodle_async_full.models.core_update_inplace_editable_response_editicon import CoreUpdateInplaceEditableResponseEditicon as CoreUpdateInplaceEditableResponseEditicon
from poodle_async_full.models.core_user_agree_site_policy_response import CoreUserAgreeSitePolicyResponse as CoreUserAgreeSitePolicyResponse
from poodle_async_full.models.core_user_create_users_parameters_users_inner import CoreUserCreateUsersParametersUsersInner as CoreUserCreateUsersParametersUsersInner
from poodle_async_full.models.core_user_create_users_parameters_users_inner_customfields_inner import CoreUserCreateUsersParametersUsersInnerCustomfieldsInner as CoreUserCreateUsersParametersUsersInnerCustomfieldsInner
from poodle_async_full.models.core_user_create_users_parameters_users_inner_preferences_inner import CoreUserCreateUsersParametersUsersInnerPreferencesInner as CoreUserCreateUsersParametersUsersInnerPreferencesInner
from poodle_async_full.models.core_user_create_users_response_inner import CoreUserCreateUsersResponseInner as CoreUserCreateUsersResponseInner
from poodle_async_full.models.core_user_get_course_user_profiles_parameters_userlist_inner import CoreUserGetCourseUserProfilesParametersUserlistInner as CoreUserGetCourseUserProfilesParametersUserlistInner
from poodle_async_full.models.core_user_get_course_user_profiles_response_inner import CoreUserGetCourseUserProfilesResponseInner as CoreUserGetCourseUserProfilesResponseInner
from poodle_async_full.models.core_user_get_private_files_info_response import CoreUserGetPrivateFilesInfoResponse as CoreUserGetPrivateFilesInfoResponse
from poodle_async_full.models.core_user_get_user_preferences_response import CoreUserGetUserPreferencesResponse as CoreUserGetUserPreferencesResponse
from poodle_async_full.models.core_user_get_user_preferences_response_preferences_inner import CoreUserGetUserPreferencesResponsePreferencesInner as CoreUserGetUserPreferencesResponsePreferencesInner
from poodle_async_full.models.core_user_get_users_parameters_criteria_inner import CoreUserGetUsersParametersCriteriaInner as CoreUserGetUsersParametersCriteriaInner
from poodle_async_full.models.core_user_get_users_response import CoreUserGetUsersResponse as CoreUserGetUsersResponse
from poodle_async_full.models.core_user_get_users_response_warnings_inner import CoreUserGetUsersResponseWarningsInner as CoreUserGetUsersResponseWarningsInner
from poodle_async_full.models.core_user_prepare_private_files_for_edition_response import CoreUserPreparePrivateFilesForEditionResponse as CoreUserPreparePrivateFilesForEditionResponse
from poodle_async_full.models.core_user_remove_user_device_response import CoreUserRemoveUserDeviceResponse as CoreUserRemoveUserDeviceResponse
from poodle_async_full.models.core_user_search_identity_response import CoreUserSearchIdentityResponse as CoreUserSearchIdentityResponse
from poodle_async_full.models.core_user_search_identity_response_list_inner import CoreUserSearchIdentityResponseListInner as CoreUserSearchIdentityResponseListInner
from poodle_async_full.models.core_user_search_identity_response_list_inner_extrafields_inner import CoreUserSearchIdentityResponseListInnerExtrafieldsInner as CoreUserSearchIdentityResponseListInnerExtrafieldsInner
from poodle_async_full.models.core_user_set_user_preferences_parameters import CoreUserSetUserPreferencesParameters as CoreUserSetUserPreferencesParameters
from poodle_async_full.models.core_user_set_user_preferences_parameters_preferences_inner import CoreUserSetUserPreferencesParametersPreferencesInner as CoreUserSetUserPreferencesParametersPreferencesInner
from poodle_async_full.models.core_user_set_user_preferences_response import CoreUserSetUserPreferencesResponse as CoreUserSetUserPreferencesResponse
from poodle_async_full.models.core_user_set_user_preferences_response_saved_inner import CoreUserSetUserPreferencesResponseSavedInner as CoreUserSetUserPreferencesResponseSavedInner
from poodle_async_full.models.core_user_update_picture_response import CoreUserUpdatePictureResponse as CoreUserUpdatePictureResponse
from poodle_async_full.models.core_user_update_private_files_response import CoreUserUpdatePrivateFilesResponse as CoreUserUpdatePrivateFilesResponse
from poodle_async_full.models.core_user_update_user_device_public_key_response import CoreUserUpdateUserDevicePublicKeyResponse as CoreUserUpdateUserDevicePublicKeyResponse
from poodle_async_full.models.core_user_update_user_preferences_parameters_preferences_inner import CoreUserUpdateUserPreferencesParametersPreferencesInner as CoreUserUpdateUserPreferencesParametersPreferencesInner
from poodle_async_full.models.core_user_update_users_parameters_users_inner import CoreUserUpdateUsersParametersUsersInner as CoreUserUpdateUsersParametersUsersInner
from poodle_async_full.models.core_user_update_users_response import CoreUserUpdateUsersResponse as CoreUserUpdateUsersResponse
from poodle_async_full.models.core_user_view_user_list_response import CoreUserViewUserListResponse as CoreUserViewUserListResponse
from poodle_async_full.models.core_user_view_user_profile_response import CoreUserViewUserProfileResponse as CoreUserViewUserProfileResponse
from poodle_async_full.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse as CoreWebserviceGetSiteInfoResponse
from poodle_async_full.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner as CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
from poodle_async_full.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner as CoreWebserviceGetSiteInfoResponseFunctionsInner
from poodle_async_full.models.customfield_number_recalculate_value_response import CustomfieldNumberRecalculateValueResponse as CustomfieldNumberRecalculateValueResponse
from poodle_async_full.models.editor_tiny_get_configuration_response import EditorTinyGetConfigurationResponse as EditorTinyGetConfigurationResponse
from poodle_async_full.models.editor_tiny_get_configuration_response_installedlanguages_inner import EditorTinyGetConfigurationResponseInstalledlanguagesInner as EditorTinyGetConfigurationResponseInstalledlanguagesInner
from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner import EditorTinyGetConfigurationResponsePluginsInner as EditorTinyGetConfigurationResponsePluginsInner
from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner_settings_inner import EditorTinyGetConfigurationResponsePluginsInnerSettingsInner as EditorTinyGetConfigurationResponsePluginsInnerSettingsInner
from poodle_async_full.models.enrol_guest_get_instance_info_response import EnrolGuestGetInstanceInfoResponse as EnrolGuestGetInstanceInfoResponse
from poodle_async_full.models.enrol_guest_get_instance_info_response_instanceinfo import EnrolGuestGetInstanceInfoResponseInstanceinfo as EnrolGuestGetInstanceInfoResponseInstanceinfo
from poodle_async_full.models.enrol_guest_validate_password_response import EnrolGuestValidatePasswordResponse as EnrolGuestValidatePasswordResponse
from poodle_async_full.models.enrol_manual_enrol_users_parameters_enrolments_inner import EnrolManualEnrolUsersParametersEnrolmentsInner as EnrolManualEnrolUsersParametersEnrolmentsInner
from poodle_async_full.models.enrol_manual_unenrol_users_parameters_enrolments_inner import EnrolManualUnenrolUsersParametersEnrolmentsInner as EnrolManualUnenrolUsersParametersEnrolmentsInner
from poodle_async_full.models.enrol_meta_add_instances_parameters_instances_inner import EnrolMetaAddInstancesParametersInstancesInner as EnrolMetaAddInstancesParametersInstancesInner
from poodle_async_full.models.enrol_meta_add_instances_response_inner import EnrolMetaAddInstancesResponseInner as EnrolMetaAddInstancesResponseInner
from poodle_async_full.models.enrol_meta_delete_instances_parameters_instances_inner import EnrolMetaDeleteInstancesParametersInstancesInner as EnrolMetaDeleteInstancesParametersInstancesInner
from poodle_async_full.models.enrol_meta_delete_instances_response_inner import EnrolMetaDeleteInstancesResponseInner as EnrolMetaDeleteInstancesResponseInner
from poodle_async_full.models.enrol_self_enrol_user_response import EnrolSelfEnrolUserResponse as EnrolSelfEnrolUserResponse
from poodle_async_full.models.enrol_self_get_instance_info_response import EnrolSelfGetInstanceInfoResponse as EnrolSelfGetInstanceInfoResponse
from poodle_async_full.models.gradereport_grader_get_users_in_report_response import GradereportGraderGetUsersInReportResponse as GradereportGraderGetUsersInReportResponse
from poodle_async_full.models.gradereport_overview_get_course_grades_response import GradereportOverviewGetCourseGradesResponse as GradereportOverviewGetCourseGradesResponse
from poodle_async_full.models.gradereport_overview_get_course_grades_response_grades_inner import GradereportOverviewGetCourseGradesResponseGradesInner as GradereportOverviewGetCourseGradesResponseGradesInner
from poodle_async_full.models.gradereport_overview_view_grade_report_response import GradereportOverviewViewGradeReportResponse as GradereportOverviewViewGradeReportResponse
from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response import GradereportSingleviewGetGradeItemsForSearchWidgetResponse as GradereportSingleviewGetGradeItemsForSearchWidgetResponse
from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response_gradeitems_inner import GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner as GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner
from poodle_async_full.models.gradereport_user_get_access_information_response import GradereportUserGetAccessInformationResponse as GradereportUserGetAccessInformationResponse
from poodle_async_full.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse as GradereportUserGetGradeItemsResponse
from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner as GradereportUserGetGradeItemsResponseUsergradesInner
from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner as GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
from poodle_async_full.models.gradereport_user_get_grades_table_response import GradereportUserGetGradesTableResponse as GradereportUserGetGradesTableResponse
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner import GradereportUserGetGradesTableResponseTablesInner as GradereportUserGetGradesTableResponseTablesInner
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner import GradereportUserGetGradesTableResponseTablesInnerTabledataInner as GradereportUserGetGradesTableResponseTablesInnerTabledataInner
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_average import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_contributiontocoursetotal import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_feedback import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_grade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_itemname import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_leader import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_lettergrade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_percentage import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_range import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_rank import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_weight import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight as GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight
from poodle_async_full.models.gradereport_user_view_grade_report_response import GradereportUserViewGradeReportResponse as GradereportUserViewGradeReportResponse
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response import GradingformGuideGraderGradingpanelFetchResponse as GradingformGuideGraderGradingpanelFetchResponse
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade import GradingformGuideGraderGradingpanelFetchResponseGrade as GradingformGuideGraderGradingpanelFetchResponseGrade
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_comments_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner as GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_criterion_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner as GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_store_response import GradingformGuideGraderGradingpanelStoreResponse as GradingformGuideGraderGradingpanelStoreResponse
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response import GradingformRubricGraderGradingpanelFetchResponse as GradingformRubricGraderGradingpanelFetchResponse
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade import GradingformRubricGraderGradingpanelFetchResponseGrade as GradingformRubricGraderGradingpanelFetchResponseGrade
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner as GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner_levels_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner as GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_store_response import GradingformRubricGraderGradingpanelStoreResponse as GradingformRubricGraderGradingpanelStoreResponse
from poodle_async_full.models.login_token200_response import LoginToken200Response as LoginToken200Response
from poodle_async_full.models.media_videojs_get_language_parameters import MediaVideojsGetLanguageParameters as MediaVideojsGetLanguageParameters
from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response import MessageAirnotifierAreNotificationPreferencesConfiguredResponse as MessageAirnotifierAreNotificationPreferencesConfiguredResponse
from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response_users_inner import MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner as MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner
from poodle_async_full.models.message_airnotifier_enable_device_response import MessageAirnotifierEnableDeviceResponse as MessageAirnotifierEnableDeviceResponse
from poodle_async_full.models.message_airnotifier_get_user_devices_response import MessageAirnotifierGetUserDevicesResponse as MessageAirnotifierGetUserDevicesResponse
from poodle_async_full.models.message_airnotifier_get_user_devices_response_devices_inner import MessageAirnotifierGetUserDevicesResponseDevicesInner as MessageAirnotifierGetUserDevicesResponseDevicesInner
from poodle_async_full.models.message_popup_get_popup_notifications_response import MessagePopupGetPopupNotificationsResponse as MessagePopupGetPopupNotificationsResponse
from poodle_async_full.models.message_popup_get_popup_notifications_response_notifications_inner import MessagePopupGetPopupNotificationsResponseNotificationsInner as MessagePopupGetPopupNotificationsResponseNotificationsInner
from poodle_async_full.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse as ModAssignGetAssignmentsResponse
from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner as ModAssignGetAssignmentsResponseCoursesInner
from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
from poodle_async_full.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner as ModAssignGetAssignmentsResponseWarningsInner
from poodle_async_full.models.mod_assign_get_grades_response import ModAssignGetGradesResponse as ModAssignGetGradesResponse
from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner import ModAssignGetGradesResponseAssignmentsInner as ModAssignGetGradesResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner_grades_inner import ModAssignGetGradesResponseAssignmentsInnerGradesInner as ModAssignGetGradesResponseAssignmentsInnerGradesInner
from poodle_async_full.models.mod_assign_get_grades_response_warnings_inner import ModAssignGetGradesResponseWarningsInner as ModAssignGetGradesResponseWarningsInner
from poodle_async_full.models.mod_assign_get_participant_response import ModAssignGetParticipantResponse as ModAssignGetParticipantResponse
from poodle_async_full.models.mod_assign_get_submission_status_response import ModAssignGetSubmissionStatusResponse as ModAssignGetSubmissionStatusResponse
from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata import ModAssignGetSubmissionStatusResponseAssignmentdata as ModAssignGetSubmissionStatusResponseAssignmentdata
from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata_attachments import ModAssignGetSubmissionStatusResponseAssignmentdataAttachments as ModAssignGetSubmissionStatusResponseAssignmentdataAttachments
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback import ModAssignGetSubmissionStatusResponseFeedback as ModAssignGetSubmissionStatusResponseFeedback
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInner as ModAssignGetSubmissionStatusResponseFeedbackPluginsInner
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_editorfields_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner as ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_fileareas_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner as ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner
from poodle_async_full.models.mod_assign_get_submission_status_response_gradingsummary import ModAssignGetSubmissionStatusResponseGradingsummary as ModAssignGetSubmissionStatusResponseGradingsummary
from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt import ModAssignGetSubmissionStatusResponseLastattempt as ModAssignGetSubmissionStatusResponseLastattempt
from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt_submission import ModAssignGetSubmissionStatusResponseLastattemptSubmission as ModAssignGetSubmissionStatusResponseLastattemptSubmission
from poodle_async_full.models.mod_assign_get_submission_status_response_previousattempts_inner import ModAssignGetSubmissionStatusResponsePreviousattemptsInner as ModAssignGetSubmissionStatusResponsePreviousattemptsInner
from poodle_async_full.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse as ModAssignGetSubmissionsResponse
from poodle_async_full.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner as ModAssignGetSubmissionsResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_user_flags_response import ModAssignGetUserFlagsResponse as ModAssignGetUserFlagsResponse
from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner import ModAssignGetUserFlagsResponseAssignmentsInner as ModAssignGetUserFlagsResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner_userflags_inner import ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner as ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner
from poodle_async_full.models.mod_assign_get_user_flags_response_warnings_inner import ModAssignGetUserFlagsResponseWarningsInner as ModAssignGetUserFlagsResponseWarningsInner
from poodle_async_full.models.mod_assign_get_user_mappings_response import ModAssignGetUserMappingsResponse as ModAssignGetUserMappingsResponse
from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner import ModAssignGetUserMappingsResponseAssignmentsInner as ModAssignGetUserMappingsResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner_mappings_inner import ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner as ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner
from poodle_async_full.models.mod_assign_get_user_mappings_response_warnings_inner import ModAssignGetUserMappingsResponseWarningsInner as ModAssignGetUserMappingsResponseWarningsInner
from poodle_async_full.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner as ModAssignListParticipantsResponseInner
from poodle_async_full.models.mod_assign_remove_submission_response import ModAssignRemoveSubmissionResponse as ModAssignRemoveSubmissionResponse
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata import ModAssignSaveGradeParametersAdvancedgradingdata as ModAssignSaveGradeParametersAdvancedgradingdata
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide import ModAssignSaveGradeParametersAdvancedgradingdataGuide as ModAssignSaveGradeParametersAdvancedgradingdataGuide
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner as ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner as ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric import ModAssignSaveGradeParametersAdvancedgradingdataRubric as ModAssignSaveGradeParametersAdvancedgradingdataRubric
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner as ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner as ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner
from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata import ModAssignSaveGradeParametersPlugindata as ModAssignSaveGradeParametersPlugindata
from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata_assignfeedbackcomments_editor import ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor as ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor
from poodle_async_full.models.mod_assign_save_grades_parameters_grades_inner import ModAssignSaveGradesParametersGradesInner as ModAssignSaveGradesParametersGradesInner
from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata import ModAssignSaveSubmissionParametersPlugindata as ModAssignSaveSubmissionParametersPlugindata
from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata_onlinetext_editor import ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor as ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor
from poodle_async_full.models.mod_assign_set_user_flags_parameters_userflags_inner import ModAssignSetUserFlagsParametersUserflagsInner as ModAssignSetUserFlagsParametersUserflagsInner
from poodle_async_full.models.mod_assign_set_user_flags_response_inner import ModAssignSetUserFlagsResponseInner as ModAssignSetUserFlagsResponseInner
from poodle_async_full.models.mod_assign_start_submission_response import ModAssignStartSubmissionResponse as ModAssignStartSubmissionResponse
from poodle_async_full.models.mod_assign_view_assign_response import ModAssignViewAssignResponse as ModAssignViewAssignResponse
from poodle_async_full.models.mod_assign_view_grading_table_response import ModAssignViewGradingTableResponse as ModAssignViewGradingTableResponse
from poodle_async_full.models.mod_assign_view_submission_status_response import ModAssignViewSubmissionStatusResponse as ModAssignViewSubmissionStatusResponse
from poodle_async_full.models.mod_bigbluebuttonbn_can_join_response import ModBigbluebuttonbnCanJoinResponse as ModBigbluebuttonbnCanJoinResponse
from poodle_async_full.models.mod_bigbluebuttonbn_completion_validate_response import ModBigbluebuttonbnCompletionValidateResponse as ModBigbluebuttonbnCompletionValidateResponse
from poodle_async_full.models.mod_bigbluebuttonbn_end_meeting_response import ModBigbluebuttonbnEndMeetingResponse as ModBigbluebuttonbnEndMeetingResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse as ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response_bigbluebuttonbns_inner import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner as ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner
from poodle_async_full.models.mod_bigbluebuttonbn_get_join_url_response import ModBigbluebuttonbnGetJoinUrlResponse as ModBigbluebuttonbnGetJoinUrlResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response import ModBigbluebuttonbnGetRecordingsResponse as ModBigbluebuttonbnGetRecordingsResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata import ModBigbluebuttonbnGetRecordingsResponseTabledata as ModBigbluebuttonbnGetRecordingsResponseTabledata
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata_columns_inner import ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner as ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_to_import_response import ModBigbluebuttonbnGetRecordingsToImportResponse as ModBigbluebuttonbnGetRecordingsToImportResponse
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response import ModBigbluebuttonbnMeetingInfoResponse as ModBigbluebuttonbnMeetingInfoResponse
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_features_inner import ModBigbluebuttonbnMeetingInfoResponseFeaturesInner as ModBigbluebuttonbnMeetingInfoResponseFeaturesInner
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_presentations_inner import ModBigbluebuttonbnMeetingInfoResponsePresentationsInner as ModBigbluebuttonbnMeetingInfoResponsePresentationsInner
from poodle_async_full.models.mod_bigbluebuttonbn_view_bigbluebuttonbn_response import ModBigbluebuttonbnViewBigbluebuttonbnResponse as ModBigbluebuttonbnViewBigbluebuttonbnResponse
from poodle_async_full.models.mod_book_get_books_by_courses_response import ModBookGetBooksByCoursesResponse as ModBookGetBooksByCoursesResponse
from poodle_async_full.models.mod_book_get_books_by_courses_response_books_inner import ModBookGetBooksByCoursesResponseBooksInner as ModBookGetBooksByCoursesResponseBooksInner
from poodle_async_full.models.mod_book_view_book_response import ModBookViewBookResponse as ModBookViewBookResponse
from poodle_async_full.models.mod_choice_delete_choice_responses_response import ModChoiceDeleteChoiceResponsesResponse as ModChoiceDeleteChoiceResponsesResponse
from poodle_async_full.models.mod_choice_get_choice_options_response import ModChoiceGetChoiceOptionsResponse as ModChoiceGetChoiceOptionsResponse
from poodle_async_full.models.mod_choice_get_choice_options_response_options_inner import ModChoiceGetChoiceOptionsResponseOptionsInner as ModChoiceGetChoiceOptionsResponseOptionsInner
from poodle_async_full.models.mod_choice_get_choice_results_response import ModChoiceGetChoiceResultsResponse as ModChoiceGetChoiceResultsResponse
from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner import ModChoiceGetChoiceResultsResponseOptionsInner as ModChoiceGetChoiceResultsResponseOptionsInner
from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner_userresponses_inner import ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner as ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner
from poodle_async_full.models.mod_choice_get_choices_by_courses_response import ModChoiceGetChoicesByCoursesResponse as ModChoiceGetChoicesByCoursesResponse
from poodle_async_full.models.mod_choice_get_choices_by_courses_response_choices_inner import ModChoiceGetChoicesByCoursesResponseChoicesInner as ModChoiceGetChoicesByCoursesResponseChoicesInner
from poodle_async_full.models.mod_choice_submit_choice_response_response import ModChoiceSubmitChoiceResponseResponse as ModChoiceSubmitChoiceResponseResponse
from poodle_async_full.models.mod_choice_submit_choice_response_response_answers_inner import ModChoiceSubmitChoiceResponseResponseAnswersInner as ModChoiceSubmitChoiceResponseResponseAnswersInner
from poodle_async_full.models.mod_choice_view_choice_response import ModChoiceViewChoiceResponse as ModChoiceViewChoiceResponse
from poodle_async_full.models.mod_data_add_entry_parameters_data_inner import ModDataAddEntryParametersDataInner as ModDataAddEntryParametersDataInner
from poodle_async_full.models.mod_data_add_entry_response import ModDataAddEntryResponse as ModDataAddEntryResponse
from poodle_async_full.models.mod_data_add_entry_response_fieldnotifications_inner import ModDataAddEntryResponseFieldnotificationsInner as ModDataAddEntryResponseFieldnotificationsInner
from poodle_async_full.models.mod_data_approve_entry_response import ModDataApproveEntryResponse as ModDataApproveEntryResponse
from poodle_async_full.models.mod_data_delete_entry_response import ModDataDeleteEntryResponse as ModDataDeleteEntryResponse
from poodle_async_full.models.mod_data_delete_saved_preset_response import ModDataDeleteSavedPresetResponse as ModDataDeleteSavedPresetResponse
from poodle_async_full.models.mod_data_get_data_access_information_response import ModDataGetDataAccessInformationResponse as ModDataGetDataAccessInformationResponse
from poodle_async_full.models.mod_data_get_databases_by_courses_response import ModDataGetDatabasesByCoursesResponse as ModDataGetDatabasesByCoursesResponse
from poodle_async_full.models.mod_data_get_databases_by_courses_response_databases_inner import ModDataGetDatabasesByCoursesResponseDatabasesInner as ModDataGetDatabasesByCoursesResponseDatabasesInner
from poodle_async_full.models.mod_data_get_entries_response import ModDataGetEntriesResponse as ModDataGetEntriesResponse
from poodle_async_full.models.mod_data_get_entries_response_entries_inner import ModDataGetEntriesResponseEntriesInner as ModDataGetEntriesResponseEntriesInner
from poodle_async_full.models.mod_data_get_entries_response_entries_inner_contents_inner import ModDataGetEntriesResponseEntriesInnerContentsInner as ModDataGetEntriesResponseEntriesInnerContentsInner
from poodle_async_full.models.mod_data_get_entry_response import ModDataGetEntryResponse as ModDataGetEntryResponse
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo import ModDataGetEntryResponseRatinginfo as ModDataGetEntryResponseRatinginfo
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_ratings_inner import ModDataGetEntryResponseRatinginfoRatingsInner as ModDataGetEntryResponseRatinginfoRatingsInner
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner import ModDataGetEntryResponseRatinginfoScalesInner as ModDataGetEntryResponseRatinginfoScalesInner
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner_items_inner import ModDataGetEntryResponseRatinginfoScalesInnerItemsInner as ModDataGetEntryResponseRatinginfoScalesInnerItemsInner
from poodle_async_full.models.mod_data_get_fields_response import ModDataGetFieldsResponse as ModDataGetFieldsResponse
from poodle_async_full.models.mod_data_get_fields_response_fields_inner import ModDataGetFieldsResponseFieldsInner as ModDataGetFieldsResponseFieldsInner
from poodle_async_full.models.mod_data_get_mapping_information_response import ModDataGetMappingInformationResponse as ModDataGetMappingInformationResponse
from poodle_async_full.models.mod_data_get_mapping_information_response_data import ModDataGetMappingInformationResponseData as ModDataGetMappingInformationResponseData
from poodle_async_full.models.mod_data_search_entries_parameters_advsearch_inner import ModDataSearchEntriesParametersAdvsearchInner as ModDataSearchEntriesParametersAdvsearchInner
from poodle_async_full.models.mod_data_search_entries_response import ModDataSearchEntriesResponse as ModDataSearchEntriesResponse
from poodle_async_full.models.mod_data_update_entry_parameters_data_inner import ModDataUpdateEntryParametersDataInner as ModDataUpdateEntryParametersDataInner
from poodle_async_full.models.mod_data_update_entry_response import ModDataUpdateEntryResponse as ModDataUpdateEntryResponse
from poodle_async_full.models.mod_data_view_database_response import ModDataViewDatabaseResponse as ModDataViewDatabaseResponse
from poodle_async_full.models.mod_feedback_get_analysis_response import ModFeedbackGetAnalysisResponse as ModFeedbackGetAnalysisResponse
from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner import ModFeedbackGetAnalysisResponseItemsdataInner as ModFeedbackGetAnalysisResponseItemsdataInner
from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner_item import ModFeedbackGetAnalysisResponseItemsdataInnerItem as ModFeedbackGetAnalysisResponseItemsdataInnerItem
from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response import ModFeedbackGetCurrentCompletedTmpResponse as ModFeedbackGetCurrentCompletedTmpResponse
from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response_feedback import ModFeedbackGetCurrentCompletedTmpResponseFeedback as ModFeedbackGetCurrentCompletedTmpResponseFeedback
from poodle_async_full.models.mod_feedback_get_feedback_access_information_response import ModFeedbackGetFeedbackAccessInformationResponse as ModFeedbackGetFeedbackAccessInformationResponse
from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response import ModFeedbackGetFeedbacksByCoursesResponse as ModFeedbackGetFeedbacksByCoursesResponse
from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response_feedbacks_inner import ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner as ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner
from poodle_async_full.models.mod_feedback_get_finished_responses_response import ModFeedbackGetFinishedResponsesResponse as ModFeedbackGetFinishedResponsesResponse
from poodle_async_full.models.mod_feedback_get_finished_responses_response_responses_inner import ModFeedbackGetFinishedResponsesResponseResponsesInner as ModFeedbackGetFinishedResponsesResponseResponsesInner
from poodle_async_full.models.mod_feedback_get_items_response import ModFeedbackGetItemsResponse as ModFeedbackGetItemsResponse
from poodle_async_full.models.mod_feedback_get_last_completed_response import ModFeedbackGetLastCompletedResponse as ModFeedbackGetLastCompletedResponse
from poodle_async_full.models.mod_feedback_get_last_completed_response_completed import ModFeedbackGetLastCompletedResponseCompleted as ModFeedbackGetLastCompletedResponseCompleted
from poodle_async_full.models.mod_feedback_get_non_respondents_response import ModFeedbackGetNonRespondentsResponse as ModFeedbackGetNonRespondentsResponse
from poodle_async_full.models.mod_feedback_get_non_respondents_response_users_inner import ModFeedbackGetNonRespondentsResponseUsersInner as ModFeedbackGetNonRespondentsResponseUsersInner
from poodle_async_full.models.mod_feedback_get_page_items_response import ModFeedbackGetPageItemsResponse as ModFeedbackGetPageItemsResponse
from poodle_async_full.models.mod_feedback_get_responses_analysis_response import ModFeedbackGetResponsesAnalysisResponse as ModFeedbackGetResponsesAnalysisResponse
from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner as ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner
from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner_responses_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner as ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner
from poodle_async_full.models.mod_feedback_get_responses_analysis_response_attempts_inner import ModFeedbackGetResponsesAnalysisResponseAttemptsInner as ModFeedbackGetResponsesAnalysisResponseAttemptsInner
from poodle_async_full.models.mod_feedback_get_unfinished_responses_response import ModFeedbackGetUnfinishedResponsesResponse as ModFeedbackGetUnfinishedResponsesResponse
from poodle_async_full.models.mod_feedback_get_unfinished_responses_response_responses_inner import ModFeedbackGetUnfinishedResponsesResponseResponsesInner as ModFeedbackGetUnfinishedResponsesResponseResponsesInner
from poodle_async_full.models.mod_feedback_launch_feedback_response import ModFeedbackLaunchFeedbackResponse as ModFeedbackLaunchFeedbackResponse
from poodle_async_full.models.mod_feedback_process_page_parameters_responses_inner import ModFeedbackProcessPageParametersResponsesInner as ModFeedbackProcessPageParametersResponsesInner
from poodle_async_full.models.mod_feedback_process_page_response import ModFeedbackProcessPageResponse as ModFeedbackProcessPageResponse
from poodle_async_full.models.mod_feedback_view_feedback_response import ModFeedbackViewFeedbackResponse as ModFeedbackViewFeedbackResponse
from poodle_async_full.models.mod_folder_get_folders_by_courses_response import ModFolderGetFoldersByCoursesResponse as ModFolderGetFoldersByCoursesResponse
from poodle_async_full.models.mod_folder_get_folders_by_courses_response_folders_inner import ModFolderGetFoldersByCoursesResponseFoldersInner as ModFolderGetFoldersByCoursesResponseFoldersInner
from poodle_async_full.models.mod_folder_view_folder_response import ModFolderViewFolderResponse as ModFolderViewFolderResponse
from poodle_async_full.models.mod_forum_add_discussion_parameters_options_inner import ModForumAddDiscussionParametersOptionsInner as ModForumAddDiscussionParametersOptionsInner
from poodle_async_full.models.mod_forum_add_discussion_post_parameters_options_inner import ModForumAddDiscussionPostParametersOptionsInner as ModForumAddDiscussionPostParametersOptionsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response import ModForumAddDiscussionPostResponse as ModForumAddDiscussionPostResponse
from poodle_async_full.models.mod_forum_add_discussion_post_response_messages_inner import ModForumAddDiscussionPostResponseMessagesInner as ModForumAddDiscussionPostResponseMessagesInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post import ModForumAddDiscussionPostResponsePost as ModForumAddDiscussionPostResponsePost
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner import ModForumAddDiscussionPostResponsePostAttachmentsInner as ModForumAddDiscussionPostResponsePostAttachmentsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_html import ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml as ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_urls import ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls as ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author import ModForumAddDiscussionPostResponsePostAuthor as ModForumAddDiscussionPostResponsePostAuthor
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner import ModForumAddDiscussionPostResponsePostAuthorGroupsInner as ModForumAddDiscussionPostResponsePostAuthorGroupsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner_urls import ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls as ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_urls import ModForumAddDiscussionPostResponsePostAuthorUrls as ModForumAddDiscussionPostResponsePostAuthorUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_capabilities import ModForumAddDiscussionPostResponsePostCapabilities as ModForumAddDiscussionPostResponsePostCapabilities
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_html import ModForumAddDiscussionPostResponsePostHtml as ModForumAddDiscussionPostResponsePostHtml
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner import ModForumAddDiscussionPostResponsePostTagsInner as ModForumAddDiscussionPostResponsePostTagsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner_urls import ModForumAddDiscussionPostResponsePostTagsInnerUrls as ModForumAddDiscussionPostResponsePostTagsInnerUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_urls import ModForumAddDiscussionPostResponsePostUrls as ModForumAddDiscussionPostResponsePostUrls
from poodle_async_full.models.mod_forum_add_discussion_response import ModForumAddDiscussionResponse as ModForumAddDiscussionResponse
from poodle_async_full.models.mod_forum_can_add_discussion_response import ModForumCanAddDiscussionResponse as ModForumCanAddDiscussionResponse
from poodle_async_full.models.mod_forum_delete_post_response import ModForumDeletePostResponse as ModForumDeletePostResponse
from poodle_async_full.models.mod_forum_get_discussion_post_response import ModForumGetDiscussionPostResponse as ModForumGetDiscussionPostResponse
from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response import ModForumGetDiscussionPostsByUseridResponse as ModForumGetDiscussionPostsByUseridResponse
from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner import ModForumGetDiscussionPostsByUseridResponseDiscussionsInner as ModForumGetDiscussionPostsByUseridResponseDiscussionsInner
from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner_posts import ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts as ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts
from poodle_async_full.models.mod_forum_get_discussion_posts_response import ModForumGetDiscussionPostsResponse as ModForumGetDiscussionPostsResponse
from poodle_async_full.models.mod_forum_get_forum_access_information_response import ModForumGetForumAccessInformationResponse as ModForumGetForumAccessInformationResponse
from poodle_async_full.models.mod_forum_get_forum_discussions_response import ModForumGetForumDiscussionsResponse as ModForumGetForumDiscussionsResponse
from poodle_async_full.models.mod_forum_get_forum_discussions_response_discussions_inner import ModForumGetForumDiscussionsResponseDiscussionsInner as ModForumGetForumDiscussionsResponseDiscussionsInner
from poodle_async_full.models.mod_forum_get_forums_by_courses_response_inner import ModForumGetForumsByCoursesResponseInner as ModForumGetForumsByCoursesResponseInner
from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_parameters_filestokeep_inner import ModForumPrepareDraftAreaForPostParametersFilestokeepInner as ModForumPrepareDraftAreaForPostParametersFilestokeepInner
from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_response import ModForumPrepareDraftAreaForPostResponse as ModForumPrepareDraftAreaForPostResponse
from poodle_async_full.models.mod_forum_set_lock_state_response import ModForumSetLockStateResponse as ModForumSetLockStateResponse
from poodle_async_full.models.mod_forum_set_lock_state_response_times import ModForumSetLockStateResponseTimes as ModForumSetLockStateResponseTimes
from poodle_async_full.models.mod_forum_set_pin_state_response import ModForumSetPinStateResponse as ModForumSetPinStateResponse
from poodle_async_full.models.mod_forum_set_pin_state_response_capabilities import ModForumSetPinStateResponseCapabilities as ModForumSetPinStateResponseCapabilities
from poodle_async_full.models.mod_forum_set_pin_state_response_group import ModForumSetPinStateResponseGroup as ModForumSetPinStateResponseGroup
from poodle_async_full.models.mod_forum_set_pin_state_response_group_urls import ModForumSetPinStateResponseGroupUrls as ModForumSetPinStateResponseGroupUrls
from poodle_async_full.models.mod_forum_set_pin_state_response_timed import ModForumSetPinStateResponseTimed as ModForumSetPinStateResponseTimed
from poodle_async_full.models.mod_forum_set_pin_state_response_times import ModForumSetPinStateResponseTimes as ModForumSetPinStateResponseTimes
from poodle_async_full.models.mod_forum_set_pin_state_response_urls import ModForumSetPinStateResponseUrls as ModForumSetPinStateResponseUrls
from poodle_async_full.models.mod_forum_set_pin_state_response_userstate import ModForumSetPinStateResponseUserstate as ModForumSetPinStateResponseUserstate
from poodle_async_full.models.mod_forum_set_subscription_state_response import ModForumSetSubscriptionStateResponse as ModForumSetSubscriptionStateResponse
from poodle_async_full.models.mod_forum_toggle_favourite_state_response import ModForumToggleFavouriteStateResponse as ModForumToggleFavouriteStateResponse
from poodle_async_full.models.mod_forum_update_discussion_post_parameters_options_inner import ModForumUpdateDiscussionPostParametersOptionsInner as ModForumUpdateDiscussionPostParametersOptionsInner
from poodle_async_full.models.mod_forum_update_discussion_post_response import ModForumUpdateDiscussionPostResponse as ModForumUpdateDiscussionPostResponse
from poodle_async_full.models.mod_forum_view_forum_discussion_response import ModForumViewForumDiscussionResponse as ModForumViewForumDiscussionResponse
from poodle_async_full.models.mod_forum_view_forum_response import ModForumViewForumResponse as ModForumViewForumResponse
from poodle_async_full.models.mod_glossary_add_entry_parameters_options_inner import ModGlossaryAddEntryParametersOptionsInner as ModGlossaryAddEntryParametersOptionsInner
from poodle_async_full.models.mod_glossary_add_entry_response import ModGlossaryAddEntryResponse as ModGlossaryAddEntryResponse
from poodle_async_full.models.mod_glossary_delete_entry_response import ModGlossaryDeleteEntryResponse as ModGlossaryDeleteEntryResponse
from poodle_async_full.models.mod_glossary_get_authors_parameters_options import ModGlossaryGetAuthorsParametersOptions as ModGlossaryGetAuthorsParametersOptions
from poodle_async_full.models.mod_glossary_get_authors_response import ModGlossaryGetAuthorsResponse as ModGlossaryGetAuthorsResponse
from poodle_async_full.models.mod_glossary_get_authors_response_authors_inner import ModGlossaryGetAuthorsResponseAuthorsInner as ModGlossaryGetAuthorsResponseAuthorsInner
from poodle_async_full.models.mod_glossary_get_categories_response import ModGlossaryGetCategoriesResponse as ModGlossaryGetCategoriesResponse
from poodle_async_full.models.mod_glossary_get_categories_response_categories_inner import ModGlossaryGetCategoriesResponseCategoriesInner as ModGlossaryGetCategoriesResponseCategoriesInner
from poodle_async_full.models.mod_glossary_get_entries_by_author_id_parameters_options import ModGlossaryGetEntriesByAuthorIdParametersOptions as ModGlossaryGetEntriesByAuthorIdParametersOptions
from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response import ModGlossaryGetEntriesByAuthorIdResponse as ModGlossaryGetEntriesByAuthorIdResponse
from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response_entries_inner import ModGlossaryGetEntriesByAuthorIdResponseEntriesInner as ModGlossaryGetEntriesByAuthorIdResponseEntriesInner
from poodle_async_full.models.mod_glossary_get_entries_by_author_response import ModGlossaryGetEntriesByAuthorResponse as ModGlossaryGetEntriesByAuthorResponse
from poodle_async_full.models.mod_glossary_get_entries_by_category_response import ModGlossaryGetEntriesByCategoryResponse as ModGlossaryGetEntriesByCategoryResponse
from poodle_async_full.models.mod_glossary_get_entries_by_category_response_entries_inner import ModGlossaryGetEntriesByCategoryResponseEntriesInner as ModGlossaryGetEntriesByCategoryResponseEntriesInner
from poodle_async_full.models.mod_glossary_get_entries_by_date_response import ModGlossaryGetEntriesByDateResponse as ModGlossaryGetEntriesByDateResponse
from poodle_async_full.models.mod_glossary_get_entries_by_letter_response import ModGlossaryGetEntriesByLetterResponse as ModGlossaryGetEntriesByLetterResponse
from poodle_async_full.models.mod_glossary_get_entries_by_search_response import ModGlossaryGetEntriesBySearchResponse as ModGlossaryGetEntriesBySearchResponse
from poodle_async_full.models.mod_glossary_get_entries_by_term_response import ModGlossaryGetEntriesByTermResponse as ModGlossaryGetEntriesByTermResponse
from poodle_async_full.models.mod_glossary_get_entries_to_approve_response import ModGlossaryGetEntriesToApproveResponse as ModGlossaryGetEntriesToApproveResponse
from poodle_async_full.models.mod_glossary_get_entry_by_id_response import ModGlossaryGetEntryByIdResponse as ModGlossaryGetEntryByIdResponse
from poodle_async_full.models.mod_glossary_get_entry_by_id_response_permissions import ModGlossaryGetEntryByIdResponsePermissions as ModGlossaryGetEntryByIdResponsePermissions
from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response import ModGlossaryGetGlossariesByCoursesResponse as ModGlossaryGetGlossariesByCoursesResponse
from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response_glossaries_inner import ModGlossaryGetGlossariesByCoursesResponseGlossariesInner as ModGlossaryGetGlossariesByCoursesResponseGlossariesInner
from poodle_async_full.models.mod_glossary_prepare_entry_for_edition_response import ModGlossaryPrepareEntryForEditionResponse as ModGlossaryPrepareEntryForEditionResponse
from poodle_async_full.models.mod_glossary_update_entry_response import ModGlossaryUpdateEntryResponse as ModGlossaryUpdateEntryResponse
from poodle_async_full.models.mod_glossary_view_entry_response import ModGlossaryViewEntryResponse as ModGlossaryViewEntryResponse
from poodle_async_full.models.mod_glossary_view_glossary_response import ModGlossaryViewGlossaryResponse as ModGlossaryViewGlossaryResponse
from poodle_async_full.models.mod_h5pactivity_get_attempts_response import ModH5pactivityGetAttemptsResponse as ModH5pactivityGetAttemptsResponse
from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInner as ModH5pactivityGetAttemptsResponseUsersattemptsInner
from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_attempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner as ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner
from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_scored import ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored as ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response import ModH5pactivityGetH5pactivitiesByCoursesResponse as ModH5pactivityGetH5pactivitiesByCoursesResponse
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner as ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner_deployedfile import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile as ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pglobalsettings import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings as ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings
from poodle_async_full.models.mod_h5pactivity_get_h5pactivity_access_information_response import ModH5pactivityGetH5pactivityAccessInformationResponse as ModH5pactivityGetH5pactivityAccessInformationResponse
from poodle_async_full.models.mod_h5pactivity_get_results_response import ModH5pactivityGetResultsResponse as ModH5pactivityGetResultsResponse
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner import ModH5pactivityGetResultsResponseAttemptsInner as ModH5pactivityGetResultsResponseAttemptsInner
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInner as ModH5pactivityGetResultsResponseAttemptsInnerResultsInner
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner as ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_correctanswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer as ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_useranswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer as ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer
from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response import ModH5pactivityGetUserAttemptsResponse as ModH5pactivityGetUserAttemptsResponse
from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner import ModH5pactivityGetUserAttemptsResponseUsersattemptsInner as ModH5pactivityGetUserAttemptsResponseUsersattemptsInner
from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner_scored import ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored as ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored
from poodle_async_full.models.mod_h5pactivity_log_report_viewed_response import ModH5pactivityLogReportViewedResponse as ModH5pactivityLogReportViewedResponse
from poodle_async_full.models.mod_h5pactivity_view_h5pactivity_response import ModH5pactivityViewH5pactivityResponse as ModH5pactivityViewH5pactivityResponse
from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response import ModImscpGetImscpsByCoursesResponse as ModImscpGetImscpsByCoursesResponse
from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response_imscps_inner import ModImscpGetImscpsByCoursesResponseImscpsInner as ModImscpGetImscpsByCoursesResponseImscpsInner
from poodle_async_full.models.mod_imscp_view_imscp_response import ModImscpViewImscpResponse as ModImscpViewImscpResponse
from poodle_async_full.models.mod_label_get_labels_by_courses_response import ModLabelGetLabelsByCoursesResponse as ModLabelGetLabelsByCoursesResponse
from poodle_async_full.models.mod_label_get_labels_by_courses_response_labels_inner import ModLabelGetLabelsByCoursesResponseLabelsInner as ModLabelGetLabelsByCoursesResponseLabelsInner
from poodle_async_full.models.mod_lesson_finish_attempt_response import ModLessonFinishAttemptResponse as ModLessonFinishAttemptResponse
from poodle_async_full.models.mod_lesson_finish_attempt_response_data_inner import ModLessonFinishAttemptResponseDataInner as ModLessonFinishAttemptResponseDataInner
from poodle_async_full.models.mod_lesson_finish_attempt_response_messages_inner import ModLessonFinishAttemptResponseMessagesInner as ModLessonFinishAttemptResponseMessagesInner
from poodle_async_full.models.mod_lesson_get_attempts_overview_response import ModLessonGetAttemptsOverviewResponse as ModLessonGetAttemptsOverviewResponse
from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data import ModLessonGetAttemptsOverviewResponseData as ModLessonGetAttemptsOverviewResponseData
from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInner as ModLessonGetAttemptsOverviewResponseDataStudentsInner
from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner_attempts_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner as ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner
from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response import ModLessonGetContentPagesViewedResponse as ModLessonGetContentPagesViewedResponse
from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response_pages_inner import ModLessonGetContentPagesViewedResponsePagesInner as ModLessonGetContentPagesViewedResponsePagesInner
from poodle_async_full.models.mod_lesson_get_lesson_access_information_response import ModLessonGetLessonAccessInformationResponse as ModLessonGetLessonAccessInformationResponse
from poodle_async_full.models.mod_lesson_get_lesson_access_information_response_preventaccessreasons_inner import ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner as ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner
from poodle_async_full.models.mod_lesson_get_lesson_response import ModLessonGetLessonResponse as ModLessonGetLessonResponse
from poodle_async_full.models.mod_lesson_get_lesson_response_lesson import ModLessonGetLessonResponseLesson as ModLessonGetLessonResponseLesson
from poodle_async_full.models.mod_lesson_get_lessons_by_courses_response import ModLessonGetLessonsByCoursesResponse as ModLessonGetLessonsByCoursesResponse
from poodle_async_full.models.mod_lesson_get_page_data_response import ModLessonGetPageDataResponse as ModLessonGetPageDataResponse
from poodle_async_full.models.mod_lesson_get_page_data_response_answers_inner import ModLessonGetPageDataResponseAnswersInner as ModLessonGetPageDataResponseAnswersInner
from poodle_async_full.models.mod_lesson_get_page_data_response_page import ModLessonGetPageDataResponsePage as ModLessonGetPageDataResponsePage
from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response import ModLessonGetPagesPossibleJumpsResponse as ModLessonGetPagesPossibleJumpsResponse
from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response_jumps_inner import ModLessonGetPagesPossibleJumpsResponseJumpsInner as ModLessonGetPagesPossibleJumpsResponseJumpsInner
from poodle_async_full.models.mod_lesson_get_pages_response import ModLessonGetPagesResponse as ModLessonGetPagesResponse
from poodle_async_full.models.mod_lesson_get_pages_response_pages_inner import ModLessonGetPagesResponsePagesInner as ModLessonGetPagesResponsePagesInner
from poodle_async_full.models.mod_lesson_get_questions_attempts_response import ModLessonGetQuestionsAttemptsResponse as ModLessonGetQuestionsAttemptsResponse
from poodle_async_full.models.mod_lesson_get_questions_attempts_response_attempts_inner import ModLessonGetQuestionsAttemptsResponseAttemptsInner as ModLessonGetQuestionsAttemptsResponseAttemptsInner
from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response import ModLessonGetUserAttemptGradeResponse as ModLessonGetUserAttemptGradeResponse
from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response_grade import ModLessonGetUserAttemptGradeResponseGrade as ModLessonGetUserAttemptGradeResponseGrade
from poodle_async_full.models.mod_lesson_get_user_attempt_response import ModLessonGetUserAttemptResponse as ModLessonGetUserAttemptResponse
from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner import ModLessonGetUserAttemptResponseAnswerpagesInner as ModLessonGetUserAttemptResponseAnswerpagesInner
from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner_answerdata import ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata as ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata
from poodle_async_full.models.mod_lesson_get_user_attempt_response_userstats import ModLessonGetUserAttemptResponseUserstats as ModLessonGetUserAttemptResponseUserstats
from poodle_async_full.models.mod_lesson_get_user_grade_response import ModLessonGetUserGradeResponse as ModLessonGetUserGradeResponse
from poodle_async_full.models.mod_lesson_get_user_timers_response import ModLessonGetUserTimersResponse as ModLessonGetUserTimersResponse
from poodle_async_full.models.mod_lesson_get_user_timers_response_timers_inner import ModLessonGetUserTimersResponseTimersInner as ModLessonGetUserTimersResponseTimersInner
from poodle_async_full.models.mod_lesson_launch_attempt_response import ModLessonLaunchAttemptResponse as ModLessonLaunchAttemptResponse
from poodle_async_full.models.mod_lesson_process_page_parameters_data_inner import ModLessonProcessPageParametersDataInner as ModLessonProcessPageParametersDataInner
from poodle_async_full.models.mod_lesson_process_page_response import ModLessonProcessPageResponse as ModLessonProcessPageResponse
from poodle_async_full.models.mod_lesson_view_lesson_response import ModLessonViewLessonResponse as ModLessonViewLessonResponse
from poodle_async_full.models.mod_lti_create_tool_proxy_response import ModLtiCreateToolProxyResponse as ModLtiCreateToolProxyResponse
from poodle_async_full.models.mod_lti_create_tool_type_response import ModLtiCreateToolTypeResponse as ModLtiCreateToolTypeResponse
from poodle_async_full.models.mod_lti_create_tool_type_response_state import ModLtiCreateToolTypeResponseState as ModLtiCreateToolTypeResponseState
from poodle_async_full.models.mod_lti_create_tool_type_response_urls import ModLtiCreateToolTypeResponseUrls as ModLtiCreateToolTypeResponseUrls
from poodle_async_full.models.mod_lti_delete_tool_proxy_response import ModLtiDeleteToolProxyResponse as ModLtiDeleteToolProxyResponse
from poodle_async_full.models.mod_lti_delete_tool_type_response import ModLtiDeleteToolTypeResponse as ModLtiDeleteToolTypeResponse
from poodle_async_full.models.mod_lti_get_ltis_by_courses_response import ModLtiGetLtisByCoursesResponse as ModLtiGetLtisByCoursesResponse
from poodle_async_full.models.mod_lti_get_ltis_by_courses_response_ltis_inner import ModLtiGetLtisByCoursesResponseLtisInner as ModLtiGetLtisByCoursesResponseLtisInner
from poodle_async_full.models.mod_lti_get_tool_launch_data_response import ModLtiGetToolLaunchDataResponse as ModLtiGetToolLaunchDataResponse
from poodle_async_full.models.mod_lti_get_tool_launch_data_response_parameters_inner import ModLtiGetToolLaunchDataResponseParametersInner as ModLtiGetToolLaunchDataResponseParametersInner
from poodle_async_full.models.mod_lti_get_tool_proxies_response_inner import ModLtiGetToolProxiesResponseInner as ModLtiGetToolProxiesResponseInner
from poodle_async_full.models.mod_lti_get_tool_proxy_registration_request_response import ModLtiGetToolProxyRegistrationRequestResponse as ModLtiGetToolProxyRegistrationRequestResponse
from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_count_response import ModLtiGetToolTypesAndProxiesCountResponse as ModLtiGetToolTypesAndProxiesCountResponse
from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response import ModLtiGetToolTypesAndProxiesResponse as ModLtiGetToolTypesAndProxiesResponse
from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response_types_inner import ModLtiGetToolTypesAndProxiesResponseTypesInner as ModLtiGetToolTypesAndProxiesResponseTypesInner
from poodle_async_full.models.mod_lti_is_cartridge_response import ModLtiIsCartridgeResponse as ModLtiIsCartridgeResponse
from poodle_async_full.models.mod_lti_update_tool_type_response import ModLtiUpdateToolTypeResponse as ModLtiUpdateToolTypeResponse
from poodle_async_full.models.mod_lti_view_lti_response import ModLtiViewLtiResponse as ModLtiViewLtiResponse
from poodle_async_full.models.mod_page_get_pages_by_courses_response import ModPageGetPagesByCoursesResponse as ModPageGetPagesByCoursesResponse
from poodle_async_full.models.mod_page_get_pages_by_courses_response_pages_inner import ModPageGetPagesByCoursesResponsePagesInner as ModPageGetPagesByCoursesResponsePagesInner
from poodle_async_full.models.mod_page_view_page_response import ModPageViewPageResponse as ModPageViewPageResponse
from poodle_async_full.models.mod_quiz_add_random_questions_response import ModQuizAddRandomQuestionsResponse as ModQuizAddRandomQuestionsResponse
from poodle_async_full.models.mod_quiz_create_grade_items_parameters_quizgradeitems_inner import ModQuizCreateGradeItemsParametersQuizgradeitemsInner as ModQuizCreateGradeItemsParametersQuizgradeitemsInner
from poodle_async_full.models.mod_quiz_delete_grade_items_parameters_quizgradeitems_inner import ModQuizDeleteGradeItemsParametersQuizgradeitemsInner as ModQuizDeleteGradeItemsParametersQuizgradeitemsInner
from poodle_async_full.models.mod_quiz_delete_overrides_parameters_data import ModQuizDeleteOverridesParametersData as ModQuizDeleteOverridesParametersData
from poodle_async_full.models.mod_quiz_delete_overrides_response import ModQuizDeleteOverridesResponse as ModQuizDeleteOverridesResponse
from poodle_async_full.models.mod_quiz_get_attempt_access_information_response import ModQuizGetAttemptAccessInformationResponse as ModQuizGetAttemptAccessInformationResponse
from poodle_async_full.models.mod_quiz_get_attempt_data_response import ModQuizGetAttemptDataResponse as ModQuizGetAttemptDataResponse
from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt import ModQuizGetAttemptDataResponseAttempt as ModQuizGetAttemptDataResponseAttempt
from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt_gradeitemmarks_inner import ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner as ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner
from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner import ModQuizGetAttemptDataResponseQuestionsInner as ModQuizGetAttemptDataResponseQuestionsInner
from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner_responsefileareas_inner import ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner as ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner
from poodle_async_full.models.mod_quiz_get_attempt_review_response import ModQuizGetAttemptReviewResponse as ModQuizGetAttemptReviewResponse
from poodle_async_full.models.mod_quiz_get_attempt_review_response_additionaldata_inner import ModQuizGetAttemptReviewResponseAdditionaldataInner as ModQuizGetAttemptReviewResponseAdditionaldataInner
from poodle_async_full.models.mod_quiz_get_attempt_summary_response import ModQuizGetAttemptSummaryResponse as ModQuizGetAttemptSummaryResponse
from poodle_async_full.models.mod_quiz_get_combined_review_options_response import ModQuizGetCombinedReviewOptionsResponse as ModQuizGetCombinedReviewOptionsResponse
from poodle_async_full.models.mod_quiz_get_combined_review_options_response_alloptions_inner import ModQuizGetCombinedReviewOptionsResponseAlloptionsInner as ModQuizGetCombinedReviewOptionsResponseAlloptionsInner
from poodle_async_full.models.mod_quiz_get_overrides_response import ModQuizGetOverridesResponse as ModQuizGetOverridesResponse
from poodle_async_full.models.mod_quiz_get_overrides_response_overrides_inner import ModQuizGetOverridesResponseOverridesInner as ModQuizGetOverridesResponseOverridesInner
from poodle_async_full.models.mod_quiz_get_quiz_access_information_response import ModQuizGetQuizAccessInformationResponse as ModQuizGetQuizAccessInformationResponse
from poodle_async_full.models.mod_quiz_get_quiz_feedback_for_grade_response import ModQuizGetQuizFeedbackForGradeResponse as ModQuizGetQuizFeedbackForGradeResponse
from poodle_async_full.models.mod_quiz_get_quiz_required_qtypes_response import ModQuizGetQuizRequiredQtypesResponse as ModQuizGetQuizRequiredQtypesResponse
from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response import ModQuizGetQuizzesByCoursesResponse as ModQuizGetQuizzesByCoursesResponse
from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response_quizzes_inner import ModQuizGetQuizzesByCoursesResponseQuizzesInner as ModQuizGetQuizzesByCoursesResponseQuizzesInner
from poodle_async_full.models.mod_quiz_get_user_attempts_response import ModQuizGetUserAttemptsResponse as ModQuizGetUserAttemptsResponse
from poodle_async_full.models.mod_quiz_get_user_attempts_response_attempts_inner import ModQuizGetUserAttemptsResponseAttemptsInner as ModQuizGetUserAttemptsResponseAttemptsInner
from poodle_async_full.models.mod_quiz_get_user_best_grade_response import ModQuizGetUserBestGradeResponse as ModQuizGetUserBestGradeResponse
from poodle_async_full.models.mod_quiz_get_user_quiz_attempts_response import ModQuizGetUserQuizAttemptsResponse as ModQuizGetUserQuizAttemptsResponse
from poodle_async_full.models.mod_quiz_process_attempt_response import ModQuizProcessAttemptResponse as ModQuizProcessAttemptResponse
from poodle_async_full.models.mod_quiz_save_attempt_response import ModQuizSaveAttemptResponse as ModQuizSaveAttemptResponse
from poodle_async_full.models.mod_quiz_save_overrides_parameters_data import ModQuizSaveOverridesParametersData as ModQuizSaveOverridesParametersData
from poodle_async_full.models.mod_quiz_save_overrides_parameters_data_overrides_inner import ModQuizSaveOverridesParametersDataOverridesInner as ModQuizSaveOverridesParametersDataOverridesInner
from poodle_async_full.models.mod_quiz_save_overrides_response import ModQuizSaveOverridesResponse as ModQuizSaveOverridesResponse
from poodle_async_full.models.mod_quiz_set_question_version_response import ModQuizSetQuestionVersionResponse as ModQuizSetQuestionVersionResponse
from poodle_async_full.models.mod_quiz_start_attempt_response import ModQuizStartAttemptResponse as ModQuizStartAttemptResponse
from poodle_async_full.models.mod_quiz_update_filter_condition_response import ModQuizUpdateFilterConditionResponse as ModQuizUpdateFilterConditionResponse
from poodle_async_full.models.mod_quiz_update_grade_items_parameters_quizgradeitems_inner import ModQuizUpdateGradeItemsParametersQuizgradeitemsInner as ModQuizUpdateGradeItemsParametersQuizgradeitemsInner
from poodle_async_full.models.mod_quiz_update_slots_parameters_slots_inner import ModQuizUpdateSlotsParametersSlotsInner as ModQuizUpdateSlotsParametersSlotsInner
from poodle_async_full.models.mod_quiz_view_attempt_response import ModQuizViewAttemptResponse as ModQuizViewAttemptResponse
from poodle_async_full.models.mod_quiz_view_attempt_review_response import ModQuizViewAttemptReviewResponse as ModQuizViewAttemptReviewResponse
from poodle_async_full.models.mod_quiz_view_attempt_summary_response import ModQuizViewAttemptSummaryResponse as ModQuizViewAttemptSummaryResponse
from poodle_async_full.models.mod_quiz_view_quiz_response import ModQuizViewQuizResponse as ModQuizViewQuizResponse
from poodle_async_full.models.mod_resource_get_resources_by_courses_response import ModResourceGetResourcesByCoursesResponse as ModResourceGetResourcesByCoursesResponse
from poodle_async_full.models.mod_resource_get_resources_by_courses_response_resources_inner import ModResourceGetResourcesByCoursesResponseResourcesInner as ModResourceGetResourcesByCoursesResponseResourcesInner
from poodle_async_full.models.mod_resource_view_resource_response import ModResourceViewResourceResponse as ModResourceViewResourceResponse
from poodle_async_full.models.mod_scorm_get_scorm_access_information_response import ModScormGetScormAccessInformationResponse as ModScormGetScormAccessInformationResponse
from poodle_async_full.models.mod_scorm_get_scorm_attempt_count_response import ModScormGetScormAttemptCountResponse as ModScormGetScormAttemptCountResponse
from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response import ModScormGetScormScoTracksResponse as ModScormGetScormScoTracksResponse
from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data import ModScormGetScormScoTracksResponseData as ModScormGetScormScoTracksResponseData
from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data_tracks_inner import ModScormGetScormScoTracksResponseDataTracksInner as ModScormGetScormScoTracksResponseDataTracksInner
from poodle_async_full.models.mod_scorm_get_scorm_scoes_response import ModScormGetScormScoesResponse as ModScormGetScormScoesResponse
from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner import ModScormGetScormScoesResponseScoesInner as ModScormGetScormScoesResponseScoesInner
from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner_extradata_inner import ModScormGetScormScoesResponseScoesInnerExtradataInner as ModScormGetScormScoesResponseScoesInnerExtradataInner
from poodle_async_full.models.mod_scorm_get_scorm_user_data_response import ModScormGetScormUserDataResponse as ModScormGetScormUserDataResponse
from poodle_async_full.models.mod_scorm_get_scorm_user_data_response_data_inner import ModScormGetScormUserDataResponseDataInner as ModScormGetScormUserDataResponseDataInner
from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response import ModScormGetScormsByCoursesResponse as ModScormGetScormsByCoursesResponse
from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_options_inner import ModScormGetScormsByCoursesResponseOptionsInner as ModScormGetScormsByCoursesResponseOptionsInner
from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_scorms_inner import ModScormGetScormsByCoursesResponseScormsInner as ModScormGetScormsByCoursesResponseScormsInner
from poodle_async_full.models.mod_scorm_insert_scorm_tracks_response import ModScormInsertScormTracksResponse as ModScormInsertScormTracksResponse
from poodle_async_full.models.mod_scorm_launch_sco_response import ModScormLaunchScoResponse as ModScormLaunchScoResponse
from poodle_async_full.models.mod_scorm_view_scorm_response import ModScormViewScormResponse as ModScormViewScormResponse
from poodle_async_full.models.mod_url_get_urls_by_courses_response import ModUrlGetUrlsByCoursesResponse as ModUrlGetUrlsByCoursesResponse
from poodle_async_full.models.mod_url_get_urls_by_courses_response_urls_inner import ModUrlGetUrlsByCoursesResponseUrlsInner as ModUrlGetUrlsByCoursesResponseUrlsInner
from poodle_async_full.models.mod_url_view_url_response import ModUrlViewUrlResponse as ModUrlViewUrlResponse
from poodle_async_full.models.mod_wiki_edit_page_response import ModWikiEditPageResponse as ModWikiEditPageResponse
from poodle_async_full.models.mod_wiki_get_page_contents_response import ModWikiGetPageContentsResponse as ModWikiGetPageContentsResponse
from poodle_async_full.models.mod_wiki_get_page_contents_response_page import ModWikiGetPageContentsResponsePage as ModWikiGetPageContentsResponsePage
from poodle_async_full.models.mod_wiki_get_page_for_editing_response import ModWikiGetPageForEditingResponse as ModWikiGetPageForEditingResponse
from poodle_async_full.models.mod_wiki_get_page_for_editing_response_pagesection import ModWikiGetPageForEditingResponsePagesection as ModWikiGetPageForEditingResponsePagesection
from poodle_async_full.models.mod_wiki_get_subwiki_files_response import ModWikiGetSubwikiFilesResponse as ModWikiGetSubwikiFilesResponse
from poodle_async_full.models.mod_wiki_get_subwiki_pages_parameters_options import ModWikiGetSubwikiPagesParametersOptions as ModWikiGetSubwikiPagesParametersOptions
from poodle_async_full.models.mod_wiki_get_subwiki_pages_response import ModWikiGetSubwikiPagesResponse as ModWikiGetSubwikiPagesResponse
from poodle_async_full.models.mod_wiki_get_subwiki_pages_response_pages_inner import ModWikiGetSubwikiPagesResponsePagesInner as ModWikiGetSubwikiPagesResponsePagesInner
from poodle_async_full.models.mod_wiki_get_subwikis_response import ModWikiGetSubwikisResponse as ModWikiGetSubwikisResponse
from poodle_async_full.models.mod_wiki_get_subwikis_response_subwikis_inner import ModWikiGetSubwikisResponseSubwikisInner as ModWikiGetSubwikisResponseSubwikisInner
from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response import ModWikiGetWikisByCoursesResponse as ModWikiGetWikisByCoursesResponse
from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response_wikis_inner import ModWikiGetWikisByCoursesResponseWikisInner as ModWikiGetWikisByCoursesResponseWikisInner
from poodle_async_full.models.mod_wiki_new_page_response import ModWikiNewPageResponse as ModWikiNewPageResponse
from poodle_async_full.models.mod_wiki_view_page_response import ModWikiViewPageResponse as ModWikiViewPageResponse
from poodle_async_full.models.mod_wiki_view_wiki_response import ModWikiViewWikiResponse as ModWikiViewWikiResponse
from poodle_async_full.models.mod_workshop_add_submission_response import ModWorkshopAddSubmissionResponse as ModWorkshopAddSubmissionResponse
from poodle_async_full.models.mod_workshop_delete_submission_response import ModWorkshopDeleteSubmissionResponse as ModWorkshopDeleteSubmissionResponse
from poodle_async_full.models.mod_workshop_evaluate_assessment_response import ModWorkshopEvaluateAssessmentResponse as ModWorkshopEvaluateAssessmentResponse
from poodle_async_full.models.mod_workshop_evaluate_submission_response import ModWorkshopEvaluateSubmissionResponse as ModWorkshopEvaluateSubmissionResponse
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response import ModWorkshopGetAssessmentFormDefinitionResponse as ModWorkshopGetAssessmentFormDefinitionResponse
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_current_inner import ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner as ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_dimensionsinfo_inner import ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner as ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_fields_inner import ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner as ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_options_inner import ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner as ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner
from poodle_async_full.models.mod_workshop_get_assessment_response import ModWorkshopGetAssessmentResponse as ModWorkshopGetAssessmentResponse
from poodle_async_full.models.mod_workshop_get_assessment_response_assessment import ModWorkshopGetAssessmentResponseAssessment as ModWorkshopGetAssessmentResponseAssessment
from poodle_async_full.models.mod_workshop_get_grades_report_response import ModWorkshopGetGradesReportResponse as ModWorkshopGetGradesReportResponse
from poodle_async_full.models.mod_workshop_get_grades_report_response_report import ModWorkshopGetGradesReportResponseReport as ModWorkshopGetGradesReportResponseReport
from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner import ModWorkshopGetGradesReportResponseReportGradesInner as ModWorkshopGetGradesReportResponseReportGradesInner
from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner_reviewedby_inner import ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner as ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner
from poodle_async_full.models.mod_workshop_get_grades_response import ModWorkshopGetGradesResponse as ModWorkshopGetGradesResponse
from poodle_async_full.models.mod_workshop_get_reviewer_assessments_response import ModWorkshopGetReviewerAssessmentsResponse as ModWorkshopGetReviewerAssessmentsResponse
from poodle_async_full.models.mod_workshop_get_submission_assessments_response import ModWorkshopGetSubmissionAssessmentsResponse as ModWorkshopGetSubmissionAssessmentsResponse
from poodle_async_full.models.mod_workshop_get_submission_response import ModWorkshopGetSubmissionResponse as ModWorkshopGetSubmissionResponse
from poodle_async_full.models.mod_workshop_get_submission_response_submission import ModWorkshopGetSubmissionResponseSubmission as ModWorkshopGetSubmissionResponseSubmission
from poodle_async_full.models.mod_workshop_get_submissions_response import ModWorkshopGetSubmissionsResponse as ModWorkshopGetSubmissionsResponse
from poodle_async_full.models.mod_workshop_get_user_plan_response import ModWorkshopGetUserPlanResponse as ModWorkshopGetUserPlanResponse
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan import ModWorkshopGetUserPlanResponseUserplan as ModWorkshopGetUserPlanResponseUserplan
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_examples_inner import ModWorkshopGetUserPlanResponseUserplanExamplesInner as ModWorkshopGetUserPlanResponseUserplanExamplesInner
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInner as ModWorkshopGetUserPlanResponseUserplanPhasesInner
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_actions_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner as ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_tasks_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner as ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner
from poodle_async_full.models.mod_workshop_get_workshop_access_information_response import ModWorkshopGetWorkshopAccessInformationResponse as ModWorkshopGetWorkshopAccessInformationResponse
from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response import ModWorkshopGetWorkshopsByCoursesResponse as ModWorkshopGetWorkshopsByCoursesResponse
from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response_workshops_inner import ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner as ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner
from poodle_async_full.models.mod_workshop_update_assessment_parameters_data_inner import ModWorkshopUpdateAssessmentParametersDataInner as ModWorkshopUpdateAssessmentParametersDataInner
from poodle_async_full.models.mod_workshop_update_assessment_response import ModWorkshopUpdateAssessmentResponse as ModWorkshopUpdateAssessmentResponse
from poodle_async_full.models.mod_workshop_update_submission_response import ModWorkshopUpdateSubmissionResponse as ModWorkshopUpdateSubmissionResponse
from poodle_async_full.models.mod_workshop_view_submission_response import ModWorkshopViewSubmissionResponse as ModWorkshopViewSubmissionResponse
from poodle_async_full.models.mod_workshop_view_workshop_response import ModWorkshopViewWorkshopResponse as ModWorkshopViewWorkshopResponse
from poodle_async_full.models.paygw_paypal_create_transaction_complete_parameters import PaygwPaypalCreateTransactionCompleteParameters as PaygwPaypalCreateTransactionCompleteParameters
from poodle_async_full.models.paygw_paypal_create_transaction_complete_response import PaygwPaypalCreateTransactionCompleteResponse as PaygwPaypalCreateTransactionCompleteResponse
from poodle_async_full.models.paygw_paypal_get_config_for_js_response import PaygwPaypalGetConfigForJsResponse as PaygwPaypalGetConfigForJsResponse
from poodle_async_full.models.qbank_editquestion_set_status_response import QbankEditquestionSetStatusResponse as QbankEditquestionSetStatusResponse
from poodle_async_full.models.qbank_managecategories_move_category_response_inner import QbankManagecategoriesMoveCategoryResponseInner as QbankManagecategoriesMoveCategoryResponseInner
from poodle_async_full.models.qbank_managecategories_move_category_response_inner_fields import QbankManagecategoriesMoveCategoryResponseInnerFields as QbankManagecategoriesMoveCategoryResponseInnerFields
from poodle_async_full.models.qbank_tagquestion_submit_tags_form_response import QbankTagquestionSubmitTagsFormResponse as QbankTagquestionSubmitTagsFormResponse
from poodle_async_full.models.quizaccess_seb_validate_quiz_keys_response import QuizaccessSebValidateQuizKeysResponse as QuizaccessSebValidateQuizKeysResponse
from poodle_async_full.models.report_competency_data_for_report_response import ReportCompetencyDataForReportResponse as ReportCompetencyDataForReportResponse
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner import ReportCompetencyDataForReportResponseUsercompetenciesInner as ReportCompetencyDataForReportResponseUsercompetenciesInner
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency as ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath as ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath_ancestors_inner import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner as ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_usercompetencycourse import ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse as ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse
from poodle_async_full.models.report_insights_action_executed_response import ReportInsightsActionExecutedResponse as ReportInsightsActionExecutedResponse
from poodle_async_full.models.tiny_autosave_reset_session_parameters import TinyAutosaveResetSessionParameters as TinyAutosaveResetSessionParameters
from poodle_async_full.models.tiny_autosave_resume_session_parameters import TinyAutosaveResumeSessionParameters as TinyAutosaveResumeSessionParameters
from poodle_async_full.models.tiny_autosave_resume_session_response import TinyAutosaveResumeSessionResponse as TinyAutosaveResumeSessionResponse
from poodle_async_full.models.tiny_autosave_update_session_parameters import TinyAutosaveUpdateSessionParameters as TinyAutosaveUpdateSessionParameters
from poodle_async_full.models.tiny_equation_filter_response import TinyEquationFilterResponse as TinyEquationFilterResponse
from poodle_async_full.models.tiny_media_preview_response import TinyMediaPreviewResponse as TinyMediaPreviewResponse
from poodle_async_full.models.tiny_premium_get_api_key_response import TinyPremiumGetApiKeyResponse as TinyPremiumGetApiKeyResponse
from poodle_async_full.models.tool_analytics_potential_contexts_response_inner import ToolAnalyticsPotentialContextsResponseInner as ToolAnalyticsPotentialContextsResponseInner
from poodle_async_full.models.tool_behat_get_entity_generator_response import ToolBehatGetEntityGeneratorResponse as ToolBehatGetEntityGeneratorResponse
from poodle_async_full.models.tool_dataprivacy_approve_data_request_response import ToolDataprivacyApproveDataRequestResponse as ToolDataprivacyApproveDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_bulk_approve_data_requests_response import ToolDataprivacyBulkApproveDataRequestsResponse as ToolDataprivacyBulkApproveDataRequestsResponse
from poodle_async_full.models.tool_dataprivacy_bulk_deny_data_requests_response import ToolDataprivacyBulkDenyDataRequestsResponse as ToolDataprivacyBulkDenyDataRequestsResponse
from poodle_async_full.models.tool_dataprivacy_cancel_data_request_response import ToolDataprivacyCancelDataRequestResponse as ToolDataprivacyCancelDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_confirm_contexts_for_deletion_response import ToolDataprivacyConfirmContextsForDeletionResponse as ToolDataprivacyConfirmContextsForDeletionResponse
from poodle_async_full.models.tool_dataprivacy_contact_dpo_response import ToolDataprivacyContactDpoResponse as ToolDataprivacyContactDpoResponse
from poodle_async_full.models.tool_dataprivacy_create_category_form_response import ToolDataprivacyCreateCategoryFormResponse as ToolDataprivacyCreateCategoryFormResponse
from poodle_async_full.models.tool_dataprivacy_create_category_form_response_category import ToolDataprivacyCreateCategoryFormResponseCategory as ToolDataprivacyCreateCategoryFormResponseCategory
from poodle_async_full.models.tool_dataprivacy_create_data_request_response import ToolDataprivacyCreateDataRequestResponse as ToolDataprivacyCreateDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response import ToolDataprivacyCreatePurposeFormResponse as ToolDataprivacyCreatePurposeFormResponse
from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose import ToolDataprivacyCreatePurposeFormResponsePurpose as ToolDataprivacyCreatePurposeFormResponsePurpose
from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose_formattedlawfulbases_inner import ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner as ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner
from poodle_async_full.models.tool_dataprivacy_delete_category_response import ToolDataprivacyDeleteCategoryResponse as ToolDataprivacyDeleteCategoryResponse
from poodle_async_full.models.tool_dataprivacy_delete_purpose_response import ToolDataprivacyDeletePurposeResponse as ToolDataprivacyDeletePurposeResponse
from poodle_async_full.models.tool_dataprivacy_deny_data_request_response import ToolDataprivacyDenyDataRequestResponse as ToolDataprivacyDenyDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_get_access_information_response import ToolDataprivacyGetAccessInformationResponse as ToolDataprivacyGetAccessInformationResponse
from poodle_async_full.models.tool_dataprivacy_get_activity_options_response import ToolDataprivacyGetActivityOptionsResponse as ToolDataprivacyGetActivityOptionsResponse
from poodle_async_full.models.tool_dataprivacy_get_activity_options_response_options_inner import ToolDataprivacyGetActivityOptionsResponseOptionsInner as ToolDataprivacyGetActivityOptionsResponseOptionsInner
from poodle_async_full.models.tool_dataprivacy_get_category_options_response import ToolDataprivacyGetCategoryOptionsResponse as ToolDataprivacyGetCategoryOptionsResponse
from poodle_async_full.models.tool_dataprivacy_get_category_options_response_options_inner import ToolDataprivacyGetCategoryOptionsResponseOptionsInner as ToolDataprivacyGetCategoryOptionsResponseOptionsInner
from poodle_async_full.models.tool_dataprivacy_get_data_request_response import ToolDataprivacyGetDataRequestResponse as ToolDataprivacyGetDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_get_data_request_response_result import ToolDataprivacyGetDataRequestResponseResult as ToolDataprivacyGetDataRequestResponseResult
from poodle_async_full.models.tool_dataprivacy_get_data_requests_response import ToolDataprivacyGetDataRequestsResponse as ToolDataprivacyGetDataRequestsResponse
from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response import ToolDataprivacyGetPurposeOptionsResponse as ToolDataprivacyGetPurposeOptionsResponse
from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response_options_inner import ToolDataprivacyGetPurposeOptionsResponseOptionsInner as ToolDataprivacyGetPurposeOptionsResponseOptionsInner
from poodle_async_full.models.tool_dataprivacy_mark_complete_response import ToolDataprivacyMarkCompleteResponse as ToolDataprivacyMarkCompleteResponse
from poodle_async_full.models.tool_dataprivacy_set_context_defaults_response import ToolDataprivacySetContextDefaultsResponse as ToolDataprivacySetContextDefaultsResponse
from poodle_async_full.models.tool_dataprivacy_set_context_form_response import ToolDataprivacySetContextFormResponse as ToolDataprivacySetContextFormResponse
from poodle_async_full.models.tool_dataprivacy_set_contextlevel_form_response import ToolDataprivacySetContextlevelFormResponse as ToolDataprivacySetContextlevelFormResponse
from poodle_async_full.models.tool_dataprivacy_submit_selected_courses_form_response import ToolDataprivacySubmitSelectedCoursesFormResponse as ToolDataprivacySubmitSelectedCoursesFormResponse
from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response import ToolDataprivacyTreeExtraBranchesResponse as ToolDataprivacyTreeExtraBranchesResponse
from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInner as ToolDataprivacyTreeExtraBranchesResponseBranchesInner
from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner as ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner
from poodle_async_full.models.tool_lp_data_for_competencies_manage_page_response import ToolLpDataForCompetenciesManagePageResponse as ToolLpDataForCompetenciesManagePageResponse
from poodle_async_full.models.tool_lp_data_for_competency_frameworks_manage_page_response import ToolLpDataForCompetencyFrameworksManagePageResponse as ToolLpDataForCompetencyFrameworksManagePageResponse
from poodle_async_full.models.tool_lp_data_for_competency_summary_response import ToolLpDataForCompetencySummaryResponse as ToolLpDataForCompetencySummaryResponse
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response import ToolLpDataForCourseCompetenciesPageResponse as ToolLpDataForCourseCompetenciesPageResponse
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner as ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_coursemodules_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner as ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_ruleoutcomeoptions_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner as ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_settings import ToolLpDataForCourseCompetenciesPageResponseSettings as ToolLpDataForCourseCompetenciesPageResponseSettings
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_statistics import ToolLpDataForCourseCompetenciesPageResponseStatistics as ToolLpDataForCourseCompetenciesPageResponseStatistics
from poodle_async_full.models.tool_lp_data_for_plan_page_response import ToolLpDataForPlanPageResponse as ToolLpDataForPlanPageResponse
from poodle_async_full.models.tool_lp_data_for_plan_page_response_competencies_inner import ToolLpDataForPlanPageResponseCompetenciesInner as ToolLpDataForPlanPageResponseCompetenciesInner
from poodle_async_full.models.tool_lp_data_for_plans_page_response import ToolLpDataForPlansPageResponse as ToolLpDataForPlansPageResponse
from poodle_async_full.models.tool_lp_data_for_related_competencies_section_response import ToolLpDataForRelatedCompetenciesSectionResponse as ToolLpDataForRelatedCompetenciesSectionResponse
from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response import ToolLpDataForTemplateCompetenciesPageResponse as ToolLpDataForTemplateCompetenciesPageResponse
from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response_statistics import ToolLpDataForTemplateCompetenciesPageResponseStatistics as ToolLpDataForTemplateCompetenciesPageResponseStatistics
from poodle_async_full.models.tool_lp_data_for_templates_manage_page_response import ToolLpDataForTemplatesManagePageResponse as ToolLpDataForTemplatesManagePageResponse
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response import ToolLpDataForUserCompetencySummaryInCourseResponse as ToolLpDataForUserCompetencySummaryInCourseResponse
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary as ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary_evidence_inner import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner as ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_plan_response import ToolLpDataForUserCompetencySummaryInPlanResponse as ToolLpDataForUserCompetencySummaryInPlanResponse
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_response import ToolLpDataForUserCompetencySummaryResponse as ToolLpDataForUserCompetencySummaryResponse
from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response import ToolLpDataForUserEvidenceListPageResponse as ToolLpDataForUserEvidenceListPageResponse
from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInner as ToolLpDataForUserEvidenceListPageResponseEvidenceInner
from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner_usercompetencies_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner as ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner
from poodle_async_full.models.tool_lp_data_for_user_evidence_page_response import ToolLpDataForUserEvidencePageResponse as ToolLpDataForUserEvidencePageResponse
from poodle_async_full.models.tool_lp_search_cohorts_response import ToolLpSearchCohortsResponse as ToolLpSearchCohortsResponse
from poodle_async_full.models.tool_lp_search_users_response import ToolLpSearchUsersResponse as ToolLpSearchUsersResponse
from poodle_async_full.models.tool_mobile_call_external_functions_parameters_requests_inner import ToolMobileCallExternalFunctionsParametersRequestsInner as ToolMobileCallExternalFunctionsParametersRequestsInner
from poodle_async_full.models.tool_mobile_call_external_functions_response import ToolMobileCallExternalFunctionsResponse as ToolMobileCallExternalFunctionsResponse
from poodle_async_full.models.tool_mobile_call_external_functions_response_responses_inner import ToolMobileCallExternalFunctionsResponseResponsesInner as ToolMobileCallExternalFunctionsResponseResponsesInner
from poodle_async_full.models.tool_mobile_get_autologin_key_response import ToolMobileGetAutologinKeyResponse as ToolMobileGetAutologinKeyResponse
from poodle_async_full.models.tool_mobile_get_config_response import ToolMobileGetConfigResponse as ToolMobileGetConfigResponse
from poodle_async_full.models.tool_mobile_get_config_response_settings_inner import ToolMobileGetConfigResponseSettingsInner as ToolMobileGetConfigResponseSettingsInner
from poodle_async_full.models.tool_mobile_get_content_parameters_args_inner import ToolMobileGetContentParametersArgsInner as ToolMobileGetContentParametersArgsInner
from poodle_async_full.models.tool_mobile_get_content_response import ToolMobileGetContentResponse as ToolMobileGetContentResponse
from poodle_async_full.models.tool_mobile_get_content_response_otherdata_inner import ToolMobileGetContentResponseOtherdataInner as ToolMobileGetContentResponseOtherdataInner
from poodle_async_full.models.tool_mobile_get_content_response_restrict import ToolMobileGetContentResponseRestrict as ToolMobileGetContentResponseRestrict
from poodle_async_full.models.tool_mobile_get_content_response_templates_inner import ToolMobileGetContentResponseTemplatesInner as ToolMobileGetContentResponseTemplatesInner
from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response import ToolMobileGetPluginsSupportingMobileResponse as ToolMobileGetPluginsSupportingMobileResponse
from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response_plugins_inner import ToolMobileGetPluginsSupportingMobileResponsePluginsInner as ToolMobileGetPluginsSupportingMobileResponsePluginsInner
from poodle_async_full.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse as ToolMobileGetPublicConfigResponse
from poodle_async_full.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner as ToolMobileGetPublicConfigResponseIdentityprovidersInner
from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_parameters import ToolMobileGetTokensForQrLoginParameters as ToolMobileGetTokensForQrLoginParameters
from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_response import ToolMobileGetTokensForQrLoginResponse as ToolMobileGetTokensForQrLoginResponse
from poodle_async_full.models.tool_mobile_validate_subscription_key_parameters import ToolMobileValidateSubscriptionKeyParameters as ToolMobileValidateSubscriptionKeyParameters
from poodle_async_full.models.tool_mobile_validate_subscription_key_response import ToolMobileValidateSubscriptionKeyResponse as ToolMobileValidateSubscriptionKeyResponse
from poodle_async_full.models.tool_moodlenet_search_courses_response import ToolMoodlenetSearchCoursesResponse as ToolMoodlenetSearchCoursesResponse
from poodle_async_full.models.tool_moodlenet_search_courses_response_courses_inner import ToolMoodlenetSearchCoursesResponseCoursesInner as ToolMoodlenetSearchCoursesResponseCoursesInner
from poodle_async_full.models.tool_moodlenet_verify_webfinger_response import ToolMoodlenetVerifyWebfingerResponse as ToolMoodlenetVerifyWebfingerResponse
from poodle_async_full.models.tool_policy_get_policy_version_parameters import ToolPolicyGetPolicyVersionParameters as ToolPolicyGetPolicyVersionParameters
from poodle_async_full.models.tool_policy_get_policy_version_response import ToolPolicyGetPolicyVersionResponse as ToolPolicyGetPolicyVersionResponse
from poodle_async_full.models.tool_policy_get_policy_version_response_result import ToolPolicyGetPolicyVersionResponseResult as ToolPolicyGetPolicyVersionResponseResult
from poodle_async_full.models.tool_policy_get_policy_version_response_result_policy import ToolPolicyGetPolicyVersionResponseResultPolicy as ToolPolicyGetPolicyVersionResponseResultPolicy
from poodle_async_full.models.tool_policy_get_user_acceptances_response import ToolPolicyGetUserAcceptancesResponse as ToolPolicyGetUserAcceptancesResponse
from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner import ToolPolicyGetUserAcceptancesResponsePoliciesInner as ToolPolicyGetUserAcceptancesResponsePoliciesInner
from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner_acceptance import ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance as ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance
from poodle_async_full.models.tool_policy_set_acceptances_status_parameters_policies_inner import ToolPolicySetAcceptancesStatusParametersPoliciesInner as ToolPolicySetAcceptancesStatusParametersPoliciesInner
from poodle_async_full.models.tool_policy_set_acceptances_status_response import ToolPolicySetAcceptancesStatusResponse as ToolPolicySetAcceptancesStatusResponse
from poodle_async_full.models.tool_templatelibrary_list_templates_parameters import ToolTemplatelibraryListTemplatesParameters as ToolTemplatelibraryListTemplatesParameters
from poodle_async_full.models.tool_templatelibrary_load_canonical_template_parameters import ToolTemplatelibraryLoadCanonicalTemplateParameters as ToolTemplatelibraryLoadCanonicalTemplateParameters
from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response import ToolUsertoursFetchAndStartTourResponse as ToolUsertoursFetchAndStartTourResponse
from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig import ToolUsertoursFetchAndStartTourResponseTourconfig as ToolUsertoursFetchAndStartTourResponseTourconfig
from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig_steps_inner import ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner as ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner
from poodle_async_full.models.tool_usertours_reset_tour_response import ToolUsertoursResetTourResponse as ToolUsertoursResetTourResponse

""",
            name=__name__,
            doc=__doc__,
        )
    )
